/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { StreamingResponseBodyAsResponse } from "../definitions/StreamingResponseBodyAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { AvatarsAsResponse } from "../definitions/AvatarsAsResponse";
import { AvatarAsResponse } from "../definitions/AvatarAsResponse";
export interface GetAvatarImageByTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The icon type of the avatar.
     */
    type: "issuetype" | "project" | "priority";
    /**
     * The size of the avatar image. If not provided the default size is returned.
     */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /**
     * The format to return the avatar image in. If not provided the original content format is returned.
     */
    format?: "png" | "svg";
}
declare type GetAvatarImageByTypeResponseOKType = StreamingResponseBodyAsResponse;
export interface GetAvatarImageByTypeResponseOK extends GetAvatarImageByTypeResponseOKType {
}
declare type GetAvatarImageByTypeResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetAvatarImageByTypeResponseError extends GetAvatarImageByTypeResponseErrorType {
}
export interface GetAvatarImageByIdRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The icon type of the avatar.
     */
    type: "issuetype" | "project" | "priority";
    /**
     * The ID of the avatar.
     */
    id: number;
    /**
     * The size of the avatar image. If not provided the default size is returned.
     */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /**
     * The format to return the avatar image in. If not provided the original content format is returned.
     */
    format?: "png" | "svg";
}
declare type GetAvatarImageByIdResponseOKType = StreamingResponseBodyAsResponse;
export interface GetAvatarImageByIdResponseOK extends GetAvatarImageByIdResponseOKType {
}
declare type GetAvatarImageByIdResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetAvatarImageByIdResponseError extends GetAvatarImageByIdResponseErrorType {
}
export interface GetAvatarImageByOwnerRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The icon type of the avatar.
     */
    type: "issuetype" | "project" | "priority";
    /**
     * The ID of the project or issue type the avatar belongs to.
     */
    entityId: string;
    /**
     * The size of the avatar image. If not provided the default size is returned.
     */
    size?: "xsmall" | "small" | "medium" | "large" | "xlarge";
    /**
     * The format to return the avatar image in. If not provided the original content format is returned.
     */
    format?: "png" | "svg";
}
declare type GetAvatarImageByOwnerResponseOKType = StreamingResponseBodyAsResponse;
export interface GetAvatarImageByOwnerResponseOK extends GetAvatarImageByOwnerResponseOKType {
}
declare type GetAvatarImageByOwnerResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetAvatarImageByOwnerResponseError extends GetAvatarImageByOwnerResponseErrorType {
}
export interface GetAvatarsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The avatar type.
     */
    type: "project" | "issuetype" | "priority";
    /**
     * The ID of the item the avatar is associated with.
     */
    entityId: string;
}
declare type GetAvatarsResponseOKType = AvatarsAsResponse;
export interface GetAvatarsResponseOK extends GetAvatarsResponseOKType {
}
export declare type GetAvatarsResponseError = undefined;
export interface LoadAvatarRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The avatar type.
     */
    type: "project" | "issuetype";
    /**
     * The ID of the item the avatar is associated with.
     */
    entityId: string;
    /**
     * The X coordinate of the top-left corner of the crop region.
     */
    x?: number;
    /**
     * The Y coordinate of the top-left corner of the crop region.
     */
    y?: number;
    /**
     * The length of each side of the crop region.
     */
    size: number;
    body: {
        /**
         * Valid image types are JPEG, GIF, or PNG.
         */
        filetype: string;
        /**
         * File's content.
         */
        content: ArrayBuffer;
    };
}
export interface LoadAvatarResponseOK extends AvatarAsResponse {
}
export declare type LoadAvatarResponseError = undefined;
export interface DeleteAvatarRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The avatar type.
     */
    type: "project" | "issuetype" | "priority";
    /**
     * The ID of the item the avatar is associated with.
     */
    owningObjectId: string;
    /**
     * The ID of the avatar.
     */
    id: number;
}
export declare type DeleteAvatarResponseOK = undefined;
export declare type DeleteAvatarResponseError = undefined;
export {};
//# sourceMappingURL=avatar.d.ts.map