/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageOfDashboardsAsResponse } from "../definitions/PageOfDashboardsAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { DashboardDetails } from "../definitions/DashboardDetails";
import { DashboardAsResponse } from "../definitions/DashboardAsResponse";
import { PageBeanDashboardAsResponse } from "../definitions/PageBeanDashboardAsResponse";
import { SharePermission } from "../definitions/SharePermission";
export interface GetDashboardsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * The filter applied to the list of dashboards. Valid values are:
  
   *  `favourite` Returns dashboards the user has marked as favorite.
   *  `my` Returns dashboards owned by the user.
  */
    filter?: "my" | "favourite";
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetDashboardsResponseOKType = PageOfDashboardsAsResponse;
export interface GetDashboardsResponseOK extends GetDashboardsResponseOKType {
}
declare type GetDashboardsResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetDashboardsResponseError extends GetDashboardsResponseErrorType {
}
export interface CreateDashboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Whether admin level permissions are used. It should only be true if the user has *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
     */
    extendAdminPermissions?: boolean;
    body: DashboardDetails;
}
declare type CreateDashboardResponseOKType = DashboardAsResponse;
export interface CreateDashboardResponseOK extends CreateDashboardResponseOKType {
}
declare type CreateDashboardResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface CreateDashboardResponseError extends CreateDashboardResponseErrorType {
}
export interface SearchDashboardsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * String used to perform a case-insensitive partial match with `name`.
     */
    dashboardName?: string;
    /**
     * User account ID used to return dashboards with the matching `owner.accountId`. This parameter cannot be used with the `owner` parameter.
     */
    accountId?: string;
    /**
     * As a group's name can change, use of `groupId` is recommended. Group name used to return dashboards that are shared with a group that matches `sharePermissions.group.name`. This parameter cannot be used with the `groupId` parameter.
     */
    groupname?: string;
    /**
     * Group ID used to return dashboards that are shared with a group that matches `sharePermissions.group.groupId`. This parameter cannot be used with the `groupname` parameter.
     */
    groupId?: string;
    /**
     * Project ID used to returns dashboards that are shared with a project that matches `sharePermissions.project.id`.
     */
    projectId?: number;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `description` Sorts by dashboard description. Note that this sort works independently of whether the expand to display the description field is in use.
   *  `favourite_count` Sorts by dashboard popularity.
   *  `id` Sorts by dashboard ID.
   *  `is_favourite` Sorts by whether the dashboard is marked as a favorite.
   *  `name` Sorts by dashboard name.
   *  `owner` Sorts by dashboard owner name.
  */
    orderBy?: "description" | "-description" | "+description" | "favorite_count" | "-favorite_count" | "+favorite_count" | "id" | "-id" | "+id" | "is_favorite" | "-is_favorite" | "+is_favorite" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner";
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The status to filter by. It may be active, archived or deleted.
     */
    status?: "active" | "archived" | "deleted";
    /**
  * Use [expand](#expansion) to include additional information about dashboard in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `description` Returns the description of the dashboard.
   *  `owner` Returns the owner of the dashboard.
   *  `viewUrl` Returns the URL that is used to view the dashboard.
   *  `favourite` Returns `isFavourite`, an indicator of whether the user has set the dashboard as a favorite.
   *  `favouritedCount` Returns `popularity`, a count of how many users have set this dashboard as a favorite.
   *  `sharePermissions` Returns details of the share permissions defined for the dashboard.
   *  `editPermissions` Returns details of the edit permissions defined for the dashboard.
   *  `isWritable` Returns whether the current user has permission to edit the dashboard.
  */
    expand?: string;
}
declare type SearchDashboardsResponseOKType = PageBeanDashboardAsResponse;
export interface SearchDashboardsResponseOK extends SearchDashboardsResponseOKType {
}
declare type SearchDashboardsResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface SearchDashboardsResponseError extends SearchDashboardsResponseErrorType {
}
export interface GetDashboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the dashboard.
     */
    id: string;
}
declare type GetDashboardResponseOKType = DashboardAsResponse;
export interface GetDashboardResponseOK extends GetDashboardResponseOKType {
}
declare type GetDashboardResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetDashboardResponseError extends GetDashboardResponseErrorType {
}
export interface UpdateDashboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the dashboard to update.
     */
    id: string;
    body: {
        /**
         * The name of the dashboard.
         */
        name?: string;
        /**
         * The description of the dashboard.
         */
        description?: string;
        /**
         * The details of any share permissions for the dashboard.
         */
        sharePermissions?: Array<SharePermission>;
    };
}
declare type UpdateDashboardResponseOKType = DashboardAsResponse;
export interface UpdateDashboardResponseOK extends UpdateDashboardResponseOKType {
}
declare type UpdateDashboardResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface UpdateDashboardResponseError extends UpdateDashboardResponseErrorType {
}
export interface DeleteDashboardRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the dashboard.
     */
    id: string;
}
export declare type DeleteDashboardResponseOK = undefined;
declare type DeleteDashboardResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface DeleteDashboardResponseError extends DeleteDashboardResponseErrorType {
}
export interface CopyDashboardRequest extends HeadersOption, ErrorStrategyOption {
    id: string;
    /**
     * Whether admin level permissions are used. It should only be true if the user has *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
     */
    extendAdminPermissions?: boolean;
    body: DashboardDetails;
}
declare type CopyDashboardResponseOKType = DashboardAsResponse;
export interface CopyDashboardResponseOK extends CopyDashboardResponseOKType {
}
declare type CopyDashboardResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface CopyDashboardResponseError extends CopyDashboardResponseErrorType {
}
export {};
//# sourceMappingURL=dashboard.d.ts.map