/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Filter } from "../definitions/Filter";
import { FilterAsResponse } from "../definitions/FilterAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageBeanFilterDetailsAsResponse } from "../definitions/PageBeanFilterDetailsAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
export interface CreateFilterRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
   *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
  */
    expand?: string;
    /**
     * EXPERIMENTAL: Whether share permissions are overridden to enable filters with any share permissions to be created. Available to users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideSharePermissions?: boolean;
    body: Filter;
}
declare type CreateFilterResponseOKType = FilterAsResponse;
export interface CreateFilterResponseOK extends CreateFilterResponseOKType {
}
export declare type CreateFilterResponseError = undefined;
export interface GetMyFiltersRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
   *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
  */
    expand?: string;
    /**
     * Include the user's favorite filters in the response.
     */
    includeFavourites?: boolean;
}
declare type GetMyFiltersResponseOKType = Array<FilterAsResponse>;
export interface GetMyFiltersResponseOK extends GetMyFiltersResponseOKType {
}
export declare type GetMyFiltersResponseError = undefined;
export interface SearchFiltersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * String used to perform a case-insensitive partial match with `name`.
     */
    filterName?: string;
    /**
     * User account ID used to return filters with the matching `owner.accountId`. This parameter cannot be used with `owner`.
     */
    accountId?: string;
    /**
     * This parameter is deprecated because of privacy changes. Use `accountId` instead. See the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details. User name used to return filters with the matching `owner.name`. This parameter cannot be used with `accountId`.
     */
    owner?: string;
    /**
     * As a group's name can change, use of `groupId` is recommended to identify a group. Group name used to returns filters that are shared with a group that matches `sharePermissions.group.groupname`. This parameter cannot be used with the `groupId` parameter.
     */
    groupname?: string;
    /**
     * Group ID used to returns filters that are shared with a group that matches `sharePermissions.group.groupId`. This parameter cannot be used with the `groupname` parameter.
     */
    groupId?: string;
    /**
     * Project ID used to returns filters that are shared with a project that matches `sharePermissions.project.id`.
     */
    projectId?: number;
    /**
     * The list of filter IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`. Do not exceed 200 filter IDs.
     */
    id?: Array<number>;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `description` Sorts by filter description. Note that this sorting works independently of whether the expand to display the description field is in use.
   *  `favourite_count` Sorts by the count of how many users have this filter as a favorite.
   *  `is_favourite` Sorts by whether the filter is marked as a favorite.
   *  `id` Sorts by filter ID.
   *  `name` Sorts by filter name.
   *  `owner` Sorts by the ID of the filter owner.
   *  `is_shared` Sorts by whether the filter is shared.
  */
    orderBy?: "description" | "-description" | "+description" | "favourite_count" | "-favourite_count" | "+favourite_count" | "id" | "-id" | "+id" | "is_favourite" | "-is_favourite" | "+is_favourite" | "name" | "-name" | "+name" | "owner" | "-owner" | "+owner" | "is_shared" | "-is_shared" | "+is_shared";
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
  * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `description` Returns the description of the filter.
   *  `favourite` Returns an indicator of whether the user has set the filter as a favorite.
   *  `favouritedCount` Returns a count of how many users have set this filter as a favorite.
   *  `jql` Returns the JQL query that the filter uses.
   *  `owner` Returns the owner of the filter.
   *  `searchUrl` Returns a URL to perform the filter's JQL query.
   *  `sharePermissions` Returns the share permissions defined for the filter.
   *  `editPermissions` Returns the edit permissions defined for the filter.
   *  `isWritable` Returns whether the current user has permission to edit the filter.
   *  `approximateLastUsed` \[Experimental\] Returns the approximate date and time when the filter was last evaluated.
   *  `subscriptions` Returns the users that are subscribed to the filter.
   *  `viewUrl` Returns a URL to view the filter.
  */
    expand?: string;
    /**
     * EXPERIMENTAL: Whether share permissions are overridden to enable filters with any share permissions to be returned. Available to users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideSharePermissions?: boolean;
    /**
     * When `true` this will perform a case-insensitive substring match for the provided `filterName`. When `false` the filter name will be searched using [full text search syntax](https://support.atlassian.com/jira-software-cloud/docs/search-for-issues-using-the-text-field/).
     */
    isSubstringMatch?: boolean;
}
declare type SearchFiltersResponseOKType = PageBeanFilterDetailsAsResponse;
export interface SearchFiltersResponseOK extends SearchFiltersResponseOKType {
}
declare type SearchFiltersResponseErrorType = ErrorCollectionAsResponse;
export interface SearchFiltersResponseError extends SearchFiltersResponseErrorType {
}
export interface GetFilterRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the filter to return.
     */
    id: number;
    /**
  * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
   *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
  */
    expand?: string;
    /**
     * EXPERIMENTAL: Whether share permissions are overridden to enable filters with any share permissions to be returned. Available to users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideSharePermissions?: boolean;
}
declare type GetFilterResponseOKType = FilterAsResponse;
export interface GetFilterResponseOK extends GetFilterResponseOKType {
}
export declare type GetFilterResponseError = undefined;
export interface UpdateFilterRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the filter to update.
     */
    id: number;
    /**
  * Use [expand](#expansion) to include additional information about filter in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `sharedUsers` Returns the users that the filter is shared with. This includes users that can browse projects that the filter is shared with. If you don't specify `sharedUsers`, then the `sharedUsers` object is returned but it doesn't list any users. The list of users returned is limited to 1000, to access additional users append `[start-index:end-index]` to the expand request. For example, to access the next 1000 users, use `?expand=sharedUsers[1001:2000]`.
   *  `subscriptions` Returns the users that are subscribed to the filter. If you don't specify `subscriptions`, the `subscriptions` object is returned but it doesn't list any subscriptions. The list of subscriptions returned is limited to 1000, to access additional subscriptions append `[start-index:end-index]` to the expand request. For example, to access the next 1000 subscriptions, use `?expand=subscriptions[1001:2000]`.
  */
    expand?: string;
    /**
     * EXPERIMENTAL: Whether share permissions are overridden to enable the addition of any share permissions to filters. Available to users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideSharePermissions?: boolean;
    body: Filter;
}
declare type UpdateFilterResponseOKType = FilterAsResponse;
export interface UpdateFilterResponseOK extends UpdateFilterResponseOKType {
}
export declare type UpdateFilterResponseError = undefined;
export interface DeleteFilterRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the filter to delete.
     */
    id: number;
}
export declare type DeleteFilterResponseOK = undefined;
export declare type DeleteFilterResponseError = undefined;
export {};
//# sourceMappingURL=filter.d.ts.map