/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { AddGroupBean } from "../definitions/AddGroupBean";
import { GroupAsResponse } from "../definitions/GroupAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { FoundGroupsAsResponse } from "../definitions/FoundGroupsAsResponse";
export interface CreateGroupRequest extends HeadersOption, ErrorStrategyOption {
    body: AddGroupBean;
}
declare type CreateGroupResponseOKType = GroupAsResponse;
export interface CreateGroupResponseOK extends CreateGroupResponseOKType {
}
export declare type CreateGroupResponseError = undefined;
export interface RemoveGroupRequest extends HeadersOption, ErrorStrategyOption {
    groupname?: string;
    /**
     * The ID of the group. This parameter cannot be used with the `groupname` parameter.
     */
    groupId?: string;
    /**
  * As a group's name can change, use of `swapGroupId` is recommended to identify a group.
  The group to transfer restrictions to. Only comments and worklogs are transferred. If restrictions are not transferred, comments and worklogs are inaccessible after the deletion. This parameter cannot be used with the `swapGroupId` parameter.
  */
    swapGroup?: string;
    /**
     * The ID of the group to transfer restrictions to. Only comments and worklogs are transferred. If restrictions are not transferred, comments and worklogs are inaccessible after the deletion. This parameter cannot be used with the `swapGroup` parameter.
     */
    swapGroupId?: string;
}
export declare type RemoveGroupResponseOK = undefined;
export declare type RemoveGroupResponseError = undefined;
export interface FindGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * This parameter is deprecated, setting it does not affect the results. To find groups containing a particular user, use [Get user groups](#api-rest-api-3-user-groups-get).
     */
    accountId?: string;
    /**
     * The string to find in group names.
     */
    query?: string;
    /**
  * As a group's name can change, use of `excludeGroupIds` is recommended to identify a group.
  A group to exclude from the result. To exclude multiple groups, provide an ampersand-separated list. For example, `exclude=group1&exclude=group2`. This parameter cannot be used with the `excludeGroupIds` parameter.
  */
    exclude?: Array<string>;
    /**
     * A group ID to exclude from the result. To exclude multiple groups, provide an ampersand-separated list. For example, `excludeId=group1-id&excludeId=group2-id`. This parameter cannot be used with the `excludeGroups` parameter.
     */
    excludeId?: Array<string>;
    /**
     * The maximum number of groups to return. The maximum number of groups that can be returned is limited by the system property `jira.ajax.autocomplete.limit`.
     */
    maxResults?: number;
    /**
     * Whether the search for groups should be case insensitive.
     */
    caseInsensitive?: boolean;
    /**
     * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
     */
    userName?: string;
}
declare type FindGroupsResponseOKType = FoundGroupsAsResponse;
export interface FindGroupsResponseOK extends FindGroupsResponseOKType {
}
export declare type FindGroupsResponseError = undefined;
export {};
//# sourceMappingURL=group.d.ts.map