/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanUserDetailsAsResponse } from "../../definitions/PageBeanUserDetailsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { UpdateUserToGroupBean } from "../../definitions/UpdateUserToGroupBean";
import { GroupAsResponse } from "../../definitions/GroupAsResponse";
export interface GetUsersFromGroupRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * As a group's name can change, use of `groupId` is recommended to identify a group.
  The name of the group. This parameter cannot be used with the `groupId` parameter.
  */
    groupname?: string;
    /**
     * The ID of the group. This parameter cannot be used with the `groupName` parameter.
     */
    groupId?: string;
    /**
     * Include inactive users.
     */
    includeInactiveUsers?: boolean;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page (number should be between 1 and 50).
     */
    maxResults?: number;
}
declare type GetUsersFromGroupResponseOKType = PageBeanUserDetailsAsResponse;
export interface GetUsersFromGroupResponseOK extends GetUsersFromGroupResponseOKType {
}
export declare type GetUsersFromGroupResponseError = undefined;
export interface AddUserToGroupRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * As a group's name can change, use of `groupId` is recommended to identify a group.
  The name of the group. This parameter cannot be used with the `groupId` parameter.
  */
    groupname?: string;
    /**
     * The ID of the group. This parameter cannot be used with the `groupName` parameter.
     */
    groupId?: string;
    body: UpdateUserToGroupBean;
}
declare type AddUserToGroupResponseOKType = GroupAsResponse;
export interface AddUserToGroupResponseOK extends AddUserToGroupResponseOKType {
}
export declare type AddUserToGroupResponseError = undefined;
export interface RemoveUserFromGroupRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * As a group's name can change, use of `groupId` is recommended to identify a group.
  The name of the group. This parameter cannot be used with the `groupId` parameter.
  */
    groupname?: string;
    /**
     * The ID of the group. This parameter cannot be used with the `groupName` parameter.
     */
    groupId?: string;
    /**
     * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
     */
    username?: string;
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId: string;
}
export declare type RemoveUserFromGroupResponseOK = undefined;
export declare type RemoveUserFromGroupResponseError = undefined;
export {};
//# sourceMappingURL=user.d.ts.map