/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { IssueCommentListRequestBean } from "../../definitions/IssueCommentListRequestBean";
import { PageBeanCommentAsResponse } from "../../definitions/PageBeanCommentAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageOfCommentsAsResponse } from "../../definitions/PageOfCommentsAsResponse";
import { Visibility } from "../../definitions/Visibility";
import { EntityProperty } from "../../definitions/EntityProperty";
import { CommentAsResponse } from "../../definitions/CommentAsResponse";
import { AtlassianDocumentFormat } from "@sr-connect/jira-cloud/types/adf";
import { Comment } from "../../definitions/Comment";
export interface GetIssueCommentsByIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `renderedBody` Returns the comment body rendered in HTML.
   *  `properties` Returns the comment's properties.
  */
    expand?: string;
    body: IssueCommentListRequestBean;
}
declare type GetIssueCommentsByIdsResponseOKType = PageBeanCommentAsResponse;
export interface GetIssueCommentsByIdsResponseOK extends GetIssueCommentsByIdsResponseOKType {
}
export declare type GetIssueCommentsByIdsResponseError = undefined;
export interface GetIssueCommentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * [Order](#ordering) the results by a field. Accepts *created* to sort comments by their created date.
     */
    orderBy?: "created" | "-created" | "+created";
    /**
     * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML.
     */
    expand?: string;
}
declare type GetIssueCommentsResponseOKType = PageOfCommentsAsResponse;
export interface GetIssueCommentsResponseOK extends GetIssueCommentsResponseOKType {
}
export declare type GetIssueCommentsResponseError = undefined;
export interface AddIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML.
     */
    expand?: string;
    body: {
        /**
         * The comment text in [Atlassian Document Format](https://developer.atlassian.com/cloud/jira/platform/apis/document/structure/).
         */
        body: AtlassianDocumentFormat;
        /**
         * The group or role to which this comment is visible. Optional on create and update.
         */
        visibility?: Visibility;
        /**
         * A list of comment properties. Optional on create and update.
         */
        properties?: Array<EntityProperty>;
        [x: string]: any;
    };
}
export interface AddIssueCommentResponseOK extends CommentAsResponse {
}
export declare type AddIssueCommentResponseError = undefined;
export interface GetIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the comment.
     */
    id: string;
    /**
     * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML.
     */
    expand?: string;
}
declare type GetIssueCommentResponseOKType = CommentAsResponse;
export interface GetIssueCommentResponseOK extends GetIssueCommentResponseOKType {
}
export declare type GetIssueCommentResponseError = undefined;
export interface UpdateIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the comment.
     */
    id: string;
    /**
     * Whether users are notified when a comment is updated.
     */
    notifyUsers?: boolean;
    /**
     * Whether screen security is overridden to enable uneditable fields to be edited. Available to Connect app users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideEditableFlag?: boolean;
    /**
     * Use [expand](#expansion) to include additional information about comments in the response. This parameter accepts `renderedBody`, which returns the comment body rendered in HTML.
     */
    expand?: string;
    body: Comment;
}
declare type UpdateIssueCommentResponseOKType = CommentAsResponse;
export interface UpdateIssueCommentResponseOK extends UpdateIssueCommentResponseOKType {
}
export declare type UpdateIssueCommentResponseError = undefined;
export interface DeleteIssueCommentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the comment.
     */
    id: string;
}
export declare type DeleteIssueCommentResponseOK = undefined;
export declare type DeleteIssueCommentResponseError = undefined;
export {};
//# sourceMappingURL=comment.d.ts.map