/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { FieldDetailsAsResponse } from "../../definitions/FieldDetailsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageBeanFieldAsResponse } from "../../definitions/PageBeanFieldAsResponse";
import { ErrorCollectionAsResponse } from "../../definitions/ErrorCollectionAsResponse";
import { PageBeanContextAsResponse } from "../../definitions/PageBeanContextAsResponse";
export interface GetIssueFieldsRequest extends HeadersOption, ErrorStrategyOption {
}
declare type GetIssueFieldsResponseOKType = Array<FieldDetailsAsResponse>;
export interface GetIssueFieldsResponseOK extends GetIssueFieldsResponseOKType {
}
export declare type GetIssueFieldsResponseError = undefined;
export interface GetFieldsPaginatedRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The type of fields to search.
     */
    type?: Array<"custom" | "system">;
    /**
     * The IDs of the custom fields to return or, where `query` is specified, filter.
     */
    id?: Array<string>;
    /**
     * String used to perform a case-insensitive partial match with field names or descriptions.
     */
    query?: string;
    /**
  * [Order](#ordering) the results by:
  
   *  `contextsCount` sorts by the number of contexts related to a field
   *  `lastUsed` sorts by the date when the value of the field last changed
   *  `name` sorts by the field name
   *  `screensCount` sorts by the number of screens related to a field
  */
    orderBy?: "contextsCount" | "-contextsCount" | "+contextsCount" | "lastUsed" | "-lastUsed" | "+lastUsed" | "name" | "-name" | "+name" | "screensCount" | "-screensCount" | "+screensCount" | "projectsCount" | "-projectsCount" | "+projectsCount";
    /**
  * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `key` returns the key for each field
   *  `stableId` returns the stableId for each field
   *  `lastUsed` returns the date when the value of the field last changed
   *  `screensCount` returns the number of screens related to a field
   *  `contextsCount` returns the number of contexts related to a field
   *  `isLocked` returns information about whether the field is locked
   *  `searcherKey` returns the searcher key for each custom field
  */
    expand?: string;
}
declare type GetFieldsPaginatedResponseOKType = PageBeanFieldAsResponse;
export interface GetFieldsPaginatedResponseOK extends GetFieldsPaginatedResponseOKType {
}
declare type GetFieldsPaginatedResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface GetFieldsPaginatedResponseError extends GetFieldsPaginatedResponseErrorType {
}
export interface GetFieldContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the field to return contexts for.
     */
    fieldId: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetFieldContextsResponseOKType = PageBeanContextAsResponse;
export interface GetFieldContextsResponseOK extends GetFieldContextsResponseOKType {
}
export declare type GetFieldContextsResponseError = undefined;
export {};
//# sourceMappingURL=field.d.ts.map