/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ProjectIssueTypeMappings } from "../../../../definitions/ProjectIssueTypeMappings";
import { PageBeanContextForProjectAndIssueTypeAsResponse } from "../../../../definitions/PageBeanContextForProjectAndIssueTypeAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { CustomFieldContextUpdateDetails } from "../../../../definitions/CustomFieldContextUpdateDetails";
import { PageBeanCustomFieldContextAsResponse } from "../../../../definitions/PageBeanCustomFieldContextAsResponse";
import { CreateCustomFieldContext } from "../../../../definitions/CreateCustomFieldContext";
import { CreateCustomFieldContextAsResponse } from "../../../../definitions/CreateCustomFieldContextAsResponse";
import { PageBeanCustomFieldContextDefaultValueAsResponse } from "../../../../definitions/PageBeanCustomFieldContextDefaultValueAsResponse";
import { CustomFieldContextDefaultValueUpdate } from "../../../../definitions/CustomFieldContextDefaultValueUpdate";
import { PageBeanIssueTypeToContextMappingAsResponse } from "../../../../definitions/PageBeanIssueTypeToContextMappingAsResponse";
import { PageBeanCustomFieldContextProjectMappingAsResponse } from "../../../../definitions/PageBeanCustomFieldContextProjectMappingAsResponse";
import { IssueTypeIds } from "../../../../definitions/IssueTypeIds";
import { ProjectIds } from "../../../../definitions/ProjectIds";
export interface GetIssueCustomFieldContextsForProjectsAndIssueTypeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    body: ProjectIssueTypeMappings;
}
declare type GetIssueCustomFieldContextsForProjectsAndIssueTypeResponseOKType = PageBeanContextForProjectAndIssueTypeAsResponse;
export interface GetIssueCustomFieldContextsForProjectsAndIssueTypeResponseOK extends GetIssueCustomFieldContextsForProjectsAndIssueTypeResponseOKType {
}
export declare type GetIssueCustomFieldContextsForProjectsAndIssueTypeResponseError = undefined;
export interface DeleteIssueCustomFieldContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
}
export declare type DeleteIssueCustomFieldContextResponseOK = any;
export declare type DeleteIssueCustomFieldContextResponseError = undefined;
export interface UpdateIssueCustomFieldContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
    body: CustomFieldContextUpdateDetails;
}
export declare type UpdateIssueCustomFieldContextResponseOK = any;
export declare type UpdateIssueCustomFieldContextResponseError = undefined;
export interface GetIssueCustomFieldContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * Whether to return contexts that apply to all issue types.
     */
    isAnyIssueType?: boolean;
    /**
     * Whether to return contexts that apply to all projects.
     */
    isGlobalContext?: boolean;
    /**
     * The list of context IDs. To include multiple contexts, separate IDs with ampersand: `contextId=10000&contextId=10001`.
     */
    contextId?: Array<number>;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetIssueCustomFieldContextsResponseOKType = PageBeanCustomFieldContextAsResponse;
export interface GetIssueCustomFieldContextsResponseOK extends GetIssueCustomFieldContextsResponseOKType {
}
export declare type GetIssueCustomFieldContextsResponseError = undefined;
export interface CreateIssueCustomFieldContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    body: CreateCustomFieldContext;
}
declare type CreateIssueCustomFieldContextResponseOKType = CreateCustomFieldContextAsResponse;
export interface CreateIssueCustomFieldContextResponseOK extends CreateIssueCustomFieldContextResponseOKType {
}
export declare type CreateIssueCustomFieldContextResponseError = undefined;
export interface GetIssueCustomFieldDefaultContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field, for example `customfield\_10000`.
     */
    fieldId: string;
    /**
     * The IDs of the contexts.
     */
    contextId?: Array<number>;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetIssueCustomFieldDefaultContextsResponseOKType = PageBeanCustomFieldContextDefaultValueAsResponse;
export interface GetIssueCustomFieldDefaultContextsResponseOK extends GetIssueCustomFieldDefaultContextsResponseOKType {
}
export declare type GetIssueCustomFieldDefaultContextsResponseError = undefined;
export interface SetIssueCustomFieldDefaultContextsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    body: CustomFieldContextDefaultValueUpdate;
}
export declare type SetIssueCustomFieldDefaultContextsResponseOK = any;
export declare type SetIssueCustomFieldDefaultContextsResponseError = undefined;
export interface GetIssueCustomFieldIssueTypesForContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context. To include multiple contexts, provide an ampersand-separated list. For example, `contextId=10001&contextId=10002`.
     */
    contextId?: Array<number>;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetIssueCustomFieldIssueTypesForContextResponseOKType = PageBeanIssueTypeToContextMappingAsResponse;
export interface GetIssueCustomFieldIssueTypesForContextResponseOK extends GetIssueCustomFieldIssueTypesForContextResponseOKType {
}
export declare type GetIssueCustomFieldIssueTypesForContextResponseError = undefined;
export interface GetIssueCustomFieldContextToProjectMappingsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field, for example `customfield\_10000`.
     */
    fieldId: string;
    /**
     * The list of context IDs. To include multiple context, separate IDs with ampersand: `contextId=10000&contextId=10001`.
     */
    contextId?: Array<number>;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetIssueCustomFieldContextToProjectMappingsResponseOKType = PageBeanCustomFieldContextProjectMappingAsResponse;
export interface GetIssueCustomFieldContextToProjectMappingsResponseOK extends GetIssueCustomFieldContextToProjectMappingsResponseOKType {
}
export declare type GetIssueCustomFieldContextToProjectMappingsResponseError = undefined;
export interface AddIssueTypesToIssueCustomFieldContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
    body: IssueTypeIds;
}
export declare type AddIssueTypesToIssueCustomFieldContextResponseOK = any;
export declare type AddIssueTypesToIssueCustomFieldContextResponseError = undefined;
export interface RemoveIssueTypesFromIssueCustomFieldContextRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
    body: IssueTypeIds;
}
export declare type RemoveIssueTypesFromIssueCustomFieldContextResponseOK = any;
export declare type RemoveIssueTypesFromIssueCustomFieldContextResponseError = undefined;
export interface AssignIssueCustomFieldContextToProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
    body: ProjectIds;
}
export declare type AssignIssueCustomFieldContextToProjectsResponseOK = any;
export declare type AssignIssueCustomFieldContextToProjectsResponseError = undefined;
export interface RemoveIssueCustomFieldContextFromProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the custom field.
     */
    fieldId: string;
    /**
     * The ID of the context.
     */
    contextId: number;
    body: ProjectIds;
}
export declare type RemoveIssueCustomFieldContextFromProjectsResponseOK = any;
export declare type RemoveIssueCustomFieldContextFromProjectsResponseError = undefined;
export {};
//# sourceMappingURL=context.d.ts.map