/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { IssueCreateMetadataAsResponse } from "../../definitions/IssueCreateMetadataAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { IssueUpdateMetadataAsResponse } from "../../definitions/IssueUpdateMetadataAsResponse";
export interface GetCreateIssueMetadataRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * List of project IDs. This parameter accepts a comma-separated list. Multiple project IDs can also be provided using an ampersand-separated list. For example, `projectIds=10000,10001&projectIds=10020,10021`. This parameter may be provided with `projectKeys`.
     */
    projectIds?: Array<string>;
    /**
     * List of project keys. This parameter accepts a comma-separated list. Multiple project keys can also be provided using an ampersand-separated list. For example, `projectKeys=proj1,proj2&projectKeys=proj3`. This parameter may be provided with `projectIds`.
     */
    projectKeys?: Array<string>;
    /**
     * List of issue type IDs. This parameter accepts a comma-separated list. Multiple issue type IDs can also be provided using an ampersand-separated list. For example, `issuetypeIds=10000,10001&issuetypeIds=10020,10021`. This parameter may be provided with `issuetypeNames`.
     */
    issuetypeIds?: Array<string>;
    /**
     * List of issue type names. This parameter accepts a comma-separated list. Multiple issue type names can also be provided using an ampersand-separated list. For example, `issuetypeNames=name1,name2&issuetypeNames=name3`. This parameter may be provided with `issuetypeIds`.
     */
    issuetypeNames?: Array<string>;
    /**
     * Use [expand](#expansion) to include additional information about issue metadata in the response. This parameter accepts `projects.issuetypes.fields`, which returns information about the fields in the issue creation screen for each issue type. Fields hidden from the screen are not returned. Use the information to populate the `fields` and `update` fields in [Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
     */
    expand?: string;
}
declare type GetCreateIssueMetadataResponseOKType = IssueCreateMetadataAsResponse;
export interface GetCreateIssueMetadataResponseOK extends GetCreateIssueMetadataResponseOKType {
}
export declare type GetCreateIssueMetadataResponseError = undefined;
export interface GetEditIssueMetadataRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * Whether hidden fields are returned. Available to Connect app users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideScreenSecurity?: boolean;
    /**
     * Whether non-editable fields are returned. Available to Connect app users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
     */
    overrideEditableFlag?: boolean;
}
declare type GetEditIssueMetadataResponseOKType = IssueUpdateMetadataAsResponse;
export interface GetEditIssueMetadataResponseOK extends GetEditIssueMetadataResponseOKType {
}
export declare type GetEditIssueMetadataResponseError = undefined;
export {};
//# sourceMappingURL=metadata.d.ts.map