/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { TransitionsAsResponse } from "../../definitions/TransitionsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { IssueFieldsUpdate } from "../../definitions/IssueFields";
import { HistoryMetadata } from "../../definitions/HistoryMetadata";
import { FieldUpdateOperation } from "../../definitions/FieldUpdateOperation";
export interface GetIssueTransitionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * Use [expand](#expansion) to include additional information about transitions in the response. This parameter accepts `transitions.fields`, which returns information about the fields in the transition screen for each transition. Fields hidden from the screen are not returned. Use this information to populate the `fields` and `update` fields in [Transition issue](#api-rest-api-3-issue-issueIdOrKey-transitions-post).
     */
    expand?: string;
    /**
     * The ID of the transition.
     */
    transitionId?: string;
    /**
     * Whether transitions with the condition *Hide From User Condition* are included in the response.
     */
    skipRemoteOnlyCondition?: boolean;
    /**
     * Whether details of transitions that fail a condition are included in the response
     */
    includeUnavailableTransitions?: boolean;
    /**
     * Whether the transitions are sorted by ops-bar sequence value first then category order (Todo, In Progress, Done) or only by ops-bar sequence value.
     */
    sortByOpsBarAndStatus?: boolean;
}
declare type GetIssueTransitionsResponseOKType = TransitionsAsResponse;
export interface GetIssueTransitionsResponseOK extends GetIssueTransitionsResponseOKType {
}
export declare type GetIssueTransitionsResponseError = undefined;
export interface PerformIssueTransitionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    body: {
        /**
         * Details of a transition. Required when performing a transition, optional when creating or editing an issue.
         */
        transition: {
            /**
             * The ID of the issue transition. Required when specifying a transition to undertake.
             */
            id: string;
        };
        /**
         * List of issue screen fields to update, specifying the sub-field to update and its value for each field. This field provides a straightforward option when setting a sub-field. When multiple sub-fields or other operations are required, use `update`. Fields included in here cannot be included in `update`.
         */
        fields?: IssueFieldsUpdate;
        /**
         * List of operations to perform on issue screen fields. Note that fields included in here cannot be included in `fields`.
         */
        update?: {
            [x: string]: Array<FieldUpdateOperation>;
        };
        /**
         * Additional issue history details.
         */
        historyMetadata?: HistoryMetadata;
        /**
         * Details of issue properties to be add or update.
         */
        properties?: {
            /**
             * The key of the property.
             */
            key: string;
            /**
             * The value of the property.
             */
            value: any;
        }[];
        [x: string]: any;
    };
}
export declare type PerformIssueTransitionResponseOK = any;
export declare type PerformIssueTransitionResponseError = undefined;
export {};
//# sourceMappingURL=transition.d.ts.map