/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanIssueTypeSchemeAsResponse } from "../../../definitions/PageBeanIssueTypeSchemeAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { IssueTypeSchemeDetails } from "../../../definitions/IssueTypeSchemeDetails";
import { IssueTypeSchemeIDAsResponse } from "../../../definitions/IssueTypeSchemeIDAsResponse";
import { PageBeanIssueTypeSchemeMappingAsResponse } from "../../../definitions/PageBeanIssueTypeSchemeMappingAsResponse";
import { PageBeanIssueTypeSchemeProjectsAsResponse } from "../../../definitions/PageBeanIssueTypeSchemeProjectsAsResponse";
import { IssueTypeSchemeProjectAssociation } from "../../../definitions/IssueTypeSchemeProjectAssociation";
import { IssueTypeIds } from "../../../definitions/IssueTypeIds";
import { IssueTypeSchemeUpdateDetails } from "../../../definitions/IssueTypeSchemeUpdateDetails";
import { OrderOfIssueTypes } from "../../../definitions/OrderOfIssueTypes";
export interface GetIssueTypeSchemesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of issue type schemes IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
     */
    id?: Array<number>;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `name` Sorts by issue type scheme name.
   *  `id` Sorts by issue type scheme ID.
  */
    orderBy?: "name" | "-name" | "+name" | "id" | "-id" | "+id";
    /**
  * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `projects` For each issue type schemes, returns information about the projects the issue type scheme is assigned to.
   *  `issueTypes` For each issue type schemes, returns information about the issueTypes the issue type scheme have.
  */
    expand?: string;
    /**
     * String used to perform a case-insensitive partial match with issue type scheme name.
     */
    queryString?: string;
}
declare type GetIssueTypeSchemesResponseOKType = PageBeanIssueTypeSchemeAsResponse;
export interface GetIssueTypeSchemesResponseOK extends GetIssueTypeSchemesResponseOKType {
}
export declare type GetIssueTypeSchemesResponseError = undefined;
export interface CreateIssueTypeSchemeRequest extends HeadersOption, ErrorStrategyOption {
    body: IssueTypeSchemeDetails;
}
declare type CreateIssueTypeSchemeResponseOKType = IssueTypeSchemeIDAsResponse;
export interface CreateIssueTypeSchemeResponseOK extends CreateIssueTypeSchemeResponseOKType {
}
export declare type CreateIssueTypeSchemeResponseError = undefined;
export interface GetIssueTypeSchemeItemsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of issue type scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `issueTypeSchemeId=10000&issueTypeSchemeId=10001`.
     */
    issueTypeSchemeId?: Array<number>;
}
declare type GetIssueTypeSchemeItemsResponseOKType = PageBeanIssueTypeSchemeMappingAsResponse;
export interface GetIssueTypeSchemeItemsResponseOK extends GetIssueTypeSchemeItemsResponseOKType {
}
export declare type GetIssueTypeSchemeItemsResponseError = undefined;
export interface GetIssueTypeSchemesForProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of project IDs. To include multiple project IDs, provide an ampersand-separated list. For example, `projectId=10000&projectId=10001`.
     */
    projectId: Array<number>;
}
declare type GetIssueTypeSchemesForProjectsResponseOKType = PageBeanIssueTypeSchemeProjectsAsResponse;
export interface GetIssueTypeSchemesForProjectsResponseOK extends GetIssueTypeSchemesForProjectsResponseOKType {
}
export declare type GetIssueTypeSchemesForProjectsResponseError = undefined;
export interface AssignIssueTypeSchemeToProjectRequest extends HeadersOption, ErrorStrategyOption {
    body: IssueTypeSchemeProjectAssociation;
}
export declare type AssignIssueTypeSchemeToProjectResponseOK = any;
export declare type AssignIssueTypeSchemeToProjectResponseError = undefined;
export interface AddIssueTypesToIssueTypeSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type scheme.
     */
    issueTypeSchemeId: number;
    body: IssueTypeIds;
}
export declare type AddIssueTypesToIssueTypeSchemeResponseOK = any;
export declare type AddIssueTypesToIssueTypeSchemeResponseError = undefined;
export interface UpdateIssueTypeSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type scheme.
     */
    issueTypeSchemeId: number;
    body: IssueTypeSchemeUpdateDetails;
}
export declare type UpdateIssueTypeSchemeResponseOK = any;
export declare type UpdateIssueTypeSchemeResponseError = undefined;
export interface DeleteIssueTypeSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type scheme.
     */
    issueTypeSchemeId: number;
}
export declare type DeleteIssueTypeSchemeResponseOK = any;
export declare type DeleteIssueTypeSchemeResponseError = undefined;
export interface ChangeIssueTypeSchemeIssueTypesOrderRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type scheme.
     */
    issueTypeSchemeId: number;
    body: OrderOfIssueTypes;
}
export declare type ChangeIssueTypeSchemeIssueTypesOrderResponseOK = any;
export declare type ChangeIssueTypeSchemeIssueTypesOrderResponseError = undefined;
export interface RemoveIssueTypesFromIssueTypeSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type scheme.
     */
    issueTypeSchemeId: number;
    /**
     * The ID of the issue type.
     */
    issueTypeId: number;
}
export declare type RemoveIssueTypesFromIssueTypeSchemeResponseOK = any;
export declare type RemoveIssueTypesFromIssueTypeSchemeResponseError = undefined;
export {};
//# sourceMappingURL=scheme.d.ts.map