/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanProjectDetailsAsResponse } from "../../../../definitions/PageBeanProjectDetailsAsResponse";
import { ErrorStrategyOption } from "../../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageBeanIssueTypeScreenSchemeAsResponse } from "../../../../definitions/PageBeanIssueTypeScreenSchemeAsResponse";
import { IssueTypeScreenSchemeDetails } from "../../../../definitions/IssueTypeScreenSchemeDetails";
import { IssueTypeScreenSchemeIdAsResponse } from "../../../../definitions/IssueTypeScreenSchemeIdAsResponse";
import { PageBeanIssueTypeScreenSchemeItemAsResponse } from "../../../../definitions/PageBeanIssueTypeScreenSchemeItemAsResponse";
import { PageBeanIssueTypeScreenSchemesProjectsAsResponse } from "../../../../definitions/PageBeanIssueTypeScreenSchemesProjectsAsResponse";
import { IssueTypeScreenSchemeProjectAssociation } from "../../../../definitions/IssueTypeScreenSchemeProjectAssociation";
import { IssueTypeScreenSchemeUpdateDetails } from "../../../../definitions/IssueTypeScreenSchemeUpdateDetails";
import { IssueTypeScreenSchemeMappingDetails } from "../../../../definitions/IssueTypeScreenSchemeMappingDetails";
import { UpdateDefaultScreenScheme } from "../../../../definitions/UpdateDefaultScreenScheme";
import { IssueTypeIds } from "../../../../definitions/IssueTypeIds";
export interface GetIssueTypeScreenSchemeProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: number;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    query?: string;
}
declare type GetIssueTypeScreenSchemeProjectsResponseOKType = PageBeanProjectDetailsAsResponse;
export interface GetIssueTypeScreenSchemeProjectsResponseOK extends GetIssueTypeScreenSchemeProjectsResponseOKType {
}
export declare type GetIssueTypeScreenSchemeProjectsResponseError = undefined;
export interface GetIssueTypeScreenSchemesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of issue type screen scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
     */
    id?: Array<number>;
    /**
     * String used to perform a case-insensitive partial match with issue type screen scheme name.
     */
    queryString?: string;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `name` Sorts by issue type screen scheme name.
   *  `id` Sorts by issue type screen scheme ID.
  */
    orderBy?: "name" | "-name" | "+name" | "id" | "-id" | "+id";
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts `projects` that, for each issue type screen schemes, returns information about the projects the issue type screen scheme is assigned to.
     */
    expand?: string;
}
declare type GetIssueTypeScreenSchemesResponseOKType = PageBeanIssueTypeScreenSchemeAsResponse;
export interface GetIssueTypeScreenSchemesResponseOK extends GetIssueTypeScreenSchemesResponseOKType {
}
export declare type GetIssueTypeScreenSchemesResponseError = undefined;
export interface CreateIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    body: IssueTypeScreenSchemeDetails;
}
declare type CreateIssueTypeScreenSchemeResponseOKType = IssueTypeScreenSchemeIdAsResponse;
export interface CreateIssueTypeScreenSchemeResponseOK extends CreateIssueTypeScreenSchemeResponseOKType {
}
export declare type CreateIssueTypeScreenSchemeResponseError = undefined;
export interface GetIssueTypeScreenSchemeItemsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of issue type screen scheme IDs. To include multiple issue type screen schemes, separate IDs with ampersand: `issueTypeScreenSchemeId=10000&issueTypeScreenSchemeId=10001`.
     */
    issueTypeScreenSchemeId?: Array<number>;
}
declare type GetIssueTypeScreenSchemeItemsResponseOKType = PageBeanIssueTypeScreenSchemeItemAsResponse;
export interface GetIssueTypeScreenSchemeItemsResponseOK extends GetIssueTypeScreenSchemeItemsResponseOKType {
}
export declare type GetIssueTypeScreenSchemeItemsResponseError = undefined;
export interface GetIssueTypeScreenSchemesForProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of project IDs. To include multiple projects, separate IDs with ampersand: `projectId=10000&projectId=10001`.
     */
    projectId: Array<number>;
}
declare type GetIssueTypeScreenSchemesForProjectsResponseOKType = PageBeanIssueTypeScreenSchemesProjectsAsResponse;
export interface GetIssueTypeScreenSchemesForProjectsResponseOK extends GetIssueTypeScreenSchemesForProjectsResponseOKType {
}
export declare type GetIssueTypeScreenSchemesForProjectsResponseError = undefined;
export interface AssignIssueTypeScreenSchemeToProjectRequest extends HeadersOption, ErrorStrategyOption {
    body: IssueTypeScreenSchemeProjectAssociation;
}
export declare type AssignIssueTypeScreenSchemeToProjectResponseOK = any;
export declare type AssignIssueTypeScreenSchemeToProjectResponseError = undefined;
export interface UpdateIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: string;
    body: IssueTypeScreenSchemeUpdateDetails;
}
export declare type UpdateIssueTypeScreenSchemeResponseOK = any;
export declare type UpdateIssueTypeScreenSchemeResponseError = undefined;
export interface DeleteIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: string;
}
export declare type DeleteIssueTypeScreenSchemeResponseOK = any;
export declare type DeleteIssueTypeScreenSchemeResponseError = undefined;
export interface AppendMappingsToIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: string;
    body: IssueTypeScreenSchemeMappingDetails;
}
export declare type AppendMappingsToIssueTypeScreenSchemeResponseOK = any;
export declare type AppendMappingsToIssueTypeScreenSchemeResponseError = undefined;
export interface UpdateDefaultIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: string;
    body: UpdateDefaultScreenScheme;
}
export declare type UpdateDefaultIssueTypeScreenSchemeResponseOK = any;
export declare type UpdateDefaultIssueTypeScreenSchemeResponseError = undefined;
export interface RemoveMappingsFromIssueTypeScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the issue type screen scheme.
     */
    issueTypeScreenSchemeId: string;
    body: IssueTypeIds;
}
export declare type RemoveMappingsFromIssueTypeScreenSchemeResponseOK = any;
export declare type RemoveMappingsFromIssueTypeScreenSchemeResponseError = undefined;
export {};
//# sourceMappingURL=scheme.d.ts.map