/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageOfWorklogsAsResponse } from "../../definitions/PageOfWorklogsAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { Visibility } from "../../definitions/Visibility";
import { EntityProperty } from "../../definitions/EntityProperty";
import { WorklogAsResponse } from "../../definitions/WorklogAsResponse";
import { AtlassianDocumentFormat } from "@sr-connect/jira-cloud/types/adf";
import { Worklog } from "../../definitions/Worklog";
import { ChangedWorklogsAsResponse } from "../../definitions/ChangedWorklogsAsResponse";
import { WorklogIdsRequestBean } from "../../definitions/WorklogIdsRequestBean";
export interface GetIssueWorklogsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The worklog start date and time, as a UNIX timestamp in milliseconds, after which worklogs are returned.
     */
    startedAfter?: number;
    /**
     * The worklog start date and time, as a UNIX timestamp in milliseconds, before which worklogs are returned.
     */
    startedBefore?: number;
    /**
     * Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts`properties`, which returns worklog properties.
     */
    expand?: string;
}
declare type GetIssueWorklogsResponseOKType = PageOfWorklogsAsResponse;
export interface GetIssueWorklogsResponseOK extends GetIssueWorklogsResponseOKType {
}
export declare type GetIssueWorklogsResponseError = undefined;
export interface AddIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key the issue.
     */
    issueIdOrKey: string;
    /**
     * Whether users watching the issue are notified by email.
     */
    notifyUsers?: boolean;
    /**
     * Defines how to update the issue's time estimate, the options are:
     *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
     *  `leave` Leaves the estimate unchanged.
     *  `manual` Reduces the estimate by amount specified in `reduceBy`.
     *  `auto` Reduces the estimate by the value of `timeSpent` in the worklog.
     */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /**
     * The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`.
     */
    newEstimate?: string;
    /**
     * The amount to reduce the issue's remaining estimate by, as days (\#d), hours (\#h), or minutes (\#m). For example, *2d*. Required when `adjustEstimate` is `manual`.
     */
    reduceBy?: string;
    /**
     * Use [expand](#expansion) to include additional information about work logs in the response. This parameter accepts `properties`, which returns worklog properties.
     */
    expand?: string;
    /**
     * Whether the worklog entry should be added to the issue even if the issue is not editable, because jira.issue.editable set to false or missing. For example, the issue is closed. Only connect app users with admin scope permission can use this flag.
     */
    overrideEditableFlag?: boolean;
    body: {
        /**
         * A comment about the worklog in [Atlassian Document Format](https://developer.atlassian.com/cloud/jira/platform/apis/document/structure/). Optional when creating or updating a worklog.
         */
        comment?: AtlassianDocumentFormat;
        /**
         * Details about any restrictions in the visibility of the worklog. Optional when creating or updating a worklog.
         */
        visibility?: Visibility;
        /**
         * The datetime on which the worklog effort was started. Required when creating a worklog. Optional when updating a worklog.
         */
        started: string;
        /**
         * The time spent working on the issue as days (\#d), hours (\#h), or minutes (\#m or \#). Required when creating a worklog if `timeSpentSeconds` isn't provided. Optional when updating a worklog. Cannot be provided if `timeSpentSecond` is provided.
         */
        timeSpent?: string;
        /**
         * The time in seconds spent working on the issue. Required when creating a worklog if `timeSpent` isn't provided. Optional when updating a worklog. Cannot be provided if `timeSpent` is provided.
         */
        timeSpentSeconds?: number;
        /**
         * Details of properties for the worklog. Optional when creating or updating a worklog.
         */
        properties?: Array<EntityProperty>;
        [x: string]: any;
    };
}
export interface AddIssueWorklogResponseOK extends WorklogAsResponse {
}
export declare type AddIssueWorklogResponseError = undefined;
export interface GetIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the worklog.
     */
    id: string;
    /**
  * Use [expand](#expansion) to include additional information about work logs in the response. This parameter accepts
  
  `properties`, which returns worklog properties.
  */
    expand?: string;
}
declare type GetIssueWorklogResponseOKType = WorklogAsResponse;
export interface GetIssueWorklogResponseOK extends GetIssueWorklogResponseOKType {
}
export declare type GetIssueWorklogResponseError = undefined;
export interface UpdateIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the worklog.
     */
    id: string;
    /**
     * Whether users watching the issue are notified by email.
     */
    notifyUsers?: boolean;
    /**
  * Defines how to update the issue's time estimate, the options are:
  
   *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
   *  `leave` Leaves the estimate unchanged.
   *  `auto` Updates the estimate by the difference between the original and updated value of `timeSpent` or `timeSpentSeconds`.
  */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /**
     * The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`.
     */
    newEstimate?: string;
    /**
     * Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties`, which returns worklog properties.
     */
    expand?: string;
    /**
     * Whether the worklog should be added to the issue even if the issue is not editable. For example, because the issue is closed. Connect and Forge app users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) can use this flag.
     */
    overrideEditableFlag?: boolean;
    body: Worklog;
}
declare type UpdateIssueWorklogResponseOKType = WorklogAsResponse;
export interface UpdateIssueWorklogResponseOK extends UpdateIssueWorklogResponseOKType {
}
export declare type UpdateIssueWorklogResponseError = undefined;
export interface DeleteIssueWorklogRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID or key of the issue.
     */
    issueIdOrKey: string;
    /**
     * The ID of the worklog.
     */
    id: string;
    /**
     * Whether users watching the issue are notified by email.
     */
    notifyUsers?: boolean;
    /**
  * Defines how to update the issue's time estimate, the options are:
  
   *  `new` Sets the estimate to a specific value, defined in `newEstimate`.
   *  `leave` Leaves the estimate unchanged.
   *  `manual` Increases the estimate by amount specified in `increaseBy`.
   *  `auto` Reduces the estimate by the value of `timeSpent` in the worklog.
  */
    adjustEstimate?: "new" | "leave" | "manual" | "auto";
    /**
     * The value to set as the issue's remaining time estimate, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `new`.
     */
    newEstimate?: string;
    /**
     * The amount to increase the issue's remaining estimate by, as days (\#d), hours (\#h), or minutes (\#m or \#). For example, *2d*. Required when `adjustEstimate` is `manual`.
     */
    increaseBy?: string;
    /**
     * Whether the work log entry should be added to the issue even if the issue is not editable, because jira.issue.editable set to false or missing. For example, the issue is closed. Connect and Forge app users with admin permission can use this flag.
     */
    overrideEditableFlag?: boolean;
}
export declare type DeleteIssueWorklogResponseOK = undefined;
export declare type DeleteIssueWorklogResponseError = undefined;
export interface GetDeletedIssueWorklogIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The date and time, as a UNIX timestamp in milliseconds, after which deleted worklogs are returned.
     */
    since?: number;
}
declare type GetDeletedIssueWorklogIdsResponseOKType = ChangedWorklogsAsResponse;
export interface GetDeletedIssueWorklogIdsResponseOK extends GetDeletedIssueWorklogIdsResponseOKType {
}
export declare type GetDeletedIssueWorklogIdsResponseError = undefined;
export interface GetIssueWorklogsFromIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties` that returns the properties of each worklog.
     */
    expand?: string;
    body: WorklogIdsRequestBean;
}
declare type GetIssueWorklogsFromIdsResponseOKType = Array<WorklogAsResponse>;
export interface GetIssueWorklogsFromIdsResponseOK extends GetIssueWorklogsFromIdsResponseOKType {
}
export declare type GetIssueWorklogsFromIdsResponseError = undefined;
export interface GetUpdatedIssueWorklogIdsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The date and time, as a UNIX timestamp in milliseconds, after which updated worklogs are returned.
     */
    since?: number;
    /**
     * Use [expand](#expansion) to include additional information about worklogs in the response. This parameter accepts `properties` that returns the properties of each worklog.
     */
    expand?: string;
}
declare type GetUpdatedIssueWorklogIdsResponseOKType = ChangedWorklogsAsResponse;
export interface GetUpdatedIssueWorklogIdsResponseOK extends GetUpdatedIssueWorklogIdsResponseOKType {
}
export declare type GetUpdatedIssueWorklogIdsResponseError = undefined;
export {};
//# sourceMappingURL=worklog.d.ts.map