/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PermissionSchemesAsResponse } from "../../definitions/PermissionSchemesAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PermissionScheme } from "../../definitions/PermissionScheme";
import { PermissionSchemeAsResponse } from "../../definitions/PermissionSchemeAsResponse";
import { Scope } from "../../definitions/Scope";
import { PermissionGrant } from "../../definitions/PermissionGrant";
export interface GetPermissionSchemesRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
  
   *  `all` Returns all expandable information.
   *  `field` Returns information about the custom field granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `user` Returns information about the user who is granted the permission.
  */
    expand?: string;
}
declare type GetPermissionSchemesResponseOKType = PermissionSchemesAsResponse;
export interface GetPermissionSchemesResponseOK extends GetPermissionSchemesResponseOKType {
}
export declare type GetPermissionSchemesResponseError = undefined;
export interface CreatePermissionSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
  
   *  `all` Returns all expandable information.
   *  `field` Returns information about the custom field granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `user` Returns information about the user who is granted the permission.
  */
    expand?: string;
    body: PermissionScheme;
}
declare type CreatePermissionSchemeResponseOKType = PermissionSchemeAsResponse;
export interface CreatePermissionSchemeResponseOK extends CreatePermissionSchemeResponseOKType {
}
export declare type CreatePermissionSchemeResponseError = undefined;
export interface GetPermissionSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme to return.
     */
    schemeId: number;
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are included when you specify any value. Expand options include:
  
   *  `all` Returns all expandable information.
   *  `field` Returns information about the custom field granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `user` Returns information about the user who is granted the permission.
  */
    expand?: string;
}
declare type GetPermissionSchemeResponseOKType = PermissionSchemeAsResponse;
export interface GetPermissionSchemeResponseOK extends GetPermissionSchemeResponseOKType {
}
export declare type GetPermissionSchemeResponseError = undefined;
export interface UpdatePermissionSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme to update.
     */
    schemeId: number;
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
  
   *  `all` Returns all expandable information.
   *  `field` Returns information about the custom field granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `user` Returns information about the user who is granted the permission.
  */
    expand?: string;
    body: {
        /**
         * The name of the permission scheme. Must be unique.
         */
        name?: string;
        /**
         * A description for the permission scheme.
         */
        description?: string;
        /**
         * The scope of the permission scheme.
         */
        scope?: Scope;
        /**
         * The permission scheme to create or update. See [About permission schemes and grants](#about-permission-schemes-and-grants) for more information.
         */
        permissions?: Array<PermissionGrant>;
        [x: string]: any;
    };
}
declare type UpdatePermissionSchemeResponseOKType = PermissionSchemeAsResponse;
export interface UpdatePermissionSchemeResponseOK extends UpdatePermissionSchemeResponseOKType {
}
export declare type UpdatePermissionSchemeResponseError = undefined;
export interface DeletePermissionSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme being deleted.
     */
    schemeId: number;
}
export declare type DeletePermissionSchemeResponseOK = undefined;
export declare type DeletePermissionSchemeResponseError = undefined;
export {};
//# sourceMappingURL=scheme.d.ts.map