/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PermissionGrantsAsResponse } from "../../../definitions/PermissionGrantsAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PermissionGrant } from "../../../definitions/PermissionGrant";
import { PermissionGrantAsResponse } from "../../../definitions/PermissionGrantAsResponse";
export interface GetPermissionSchemeGrantsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme.
     */
    schemeId: number;
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
  
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `user` Returns information about the user who is granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `field` Returns information about the custom field granted the permission.
   *  `all` Returns all expandable information.
  */
    expand?: string;
}
declare type GetPermissionSchemeGrantsResponseOKType = PermissionGrantsAsResponse;
export interface GetPermissionSchemeGrantsResponseOK extends GetPermissionSchemeGrantsResponseOKType {
}
export declare type GetPermissionSchemeGrantsResponseError = undefined;
export interface CreatePermissionSchemeGrantRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme in which to create a new permission grant.
     */
    schemeId: number;
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
  
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `user` Returns information about the user who is granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `field` Returns information about the custom field granted the permission.
   *  `all` Returns all expandable information.
  */
    expand?: string;
    body: PermissionGrant;
}
declare type CreatePermissionSchemeGrantResponseOKType = PermissionGrantAsResponse;
export interface CreatePermissionSchemeGrantResponseOK extends CreatePermissionSchemeGrantResponseOKType {
}
export declare type CreatePermissionSchemeGrantResponseError = undefined;
export interface GetPermissionSchemeGrantRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme.
     */
    schemeId: number;
    /**
     * The ID of the permission grant.
     */
    permissionId: number;
    /**
  * Use expand to include additional information in the response. This parameter accepts a comma-separated list. Note that permissions are always included when you specify any value. Expand options include:
  
   *  `all` Returns all expandable information.
   *  `field` Returns information about the custom field granted the permission.
   *  `group` Returns information about the group that is granted the permission.
   *  `permissions` Returns all permission grants for each permission scheme.
   *  `projectRole` Returns information about the project role granted the permission.
   *  `user` Returns information about the user who is granted the permission.
  */
    expand?: string;
}
declare type GetPermissionSchemeGrantResponseOKType = PermissionGrantAsResponse;
export interface GetPermissionSchemeGrantResponseOK extends GetPermissionSchemeGrantResponseOKType {
}
export declare type GetPermissionSchemeGrantResponseError = undefined;
export interface DeletePermissionSchemeGrantRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the permission scheme to delete the permission grant from.
     */
    schemeId: number;
    /**
     * The ID of the permission grant to delete.
     */
    permissionId: number;
}
export declare type DeletePermissionSchemeGrantResponseOK = undefined;
export declare type DeletePermissionSchemeGrantResponseError = undefined;
export {};
//# sourceMappingURL=grant.d.ts.map