/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ProjectComponentAsResponse } from "../../definitions/ProjectComponentAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ComponentAsResponse } from "../../definitions/ComponentAsResponse";
import { ComponentIssuesCountAsResponse } from "../../definitions/ComponentIssuesCountAsResponse";
import { PageBeanComponentWithIssueCountAsResponse } from "../../definitions/PageBeanComponentWithIssueCountAsResponse";
export interface CreateProjectComponentRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
    * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
    
     *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
     *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
     *  `UNASSIGNED` an assignee is not set for issues created with this component.
     *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
    
    Default value: `PROJECT_DEFAULT`.
    Optional when creating or updating a component.
    */
        assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
        /**
         * The description for the component. Optional when creating or updating a component.
         */
        description?: string;
        /**
         * The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
         */
        leadAccountId?: string;
        /**
         * This property is no longer available and will be removed from the documentation soon. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
         */
        leadUserName?: string;
        /**
         * The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters.
         */
        name: string;
        /**
         * The key of the project the component is assigned to. Required when creating a component. Can't be updated.
         */
        project: string;
    };
}
declare type CreateProjectComponentResponseOKType = ProjectComponentAsResponse;
export interface CreateProjectComponentResponseOK extends CreateProjectComponentResponseOKType {
}
export declare type CreateProjectComponentResponseError = undefined;
export interface GetProjectComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the component.
     */
    id: string;
}
declare type GetProjectComponentResponseOKType = ProjectComponentAsResponse;
export interface GetProjectComponentResponseOK extends GetProjectComponentResponseOKType {
}
export declare type GetProjectComponentResponseError = undefined;
export interface UpdateProjectComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the component.
     */
    id: string;
    body: {
        /**
         * The unique name for the component in the project. Required when creating a component. Optional when updating a component. The maximum length is 255 characters.
         */
        name?: string;
        /**
         * The description for the component. Optional when creating or updating a component.
         */
        description?: string;
        /**
         * The accountId of the component's lead user. The accountId uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
         */
        leadAccountId?: string;
        /**
    * The nominal user type used to determine the assignee for issues created with this component. See `realAssigneeType` for details on how the type of the user, and hence the user, assigned to issues is determined. Can take the following values:
    
     *  `PROJECT_LEAD` the assignee to any issues created with this component is nominally the lead for the project the component is in.
     *  `COMPONENT_LEAD` the assignee to any issues created with this component is nominally the lead for the component.
     *  `UNASSIGNED` an assignee is not set for issues created with this component.
     *  `PROJECT_DEFAULT` the assignee to any issues created with this component is nominally the default assignee for the project that the component is in.
    
    Default value: `PROJECT_DEFAULT`.
    Optional when creating or updating a component.
    */
        assigneeType?: "PROJECT_DEFAULT" | "COMPONENT_LEAD" | "PROJECT_LEAD" | "UNASSIGNED";
    };
}
declare type UpdateProjectComponentResponseOKType = ComponentAsResponse;
export interface UpdateProjectComponentResponseOK extends UpdateProjectComponentResponseOKType {
}
export declare type UpdateProjectComponentResponseError = undefined;
export interface DeleteProjectComponentRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the component.
     */
    id: string;
    /**
     * The ID of the component to replace the deleted component. If this value is null no replacement is made.
     */
    moveIssuesTo?: string;
}
export declare type DeleteProjectComponentResponseOK = undefined;
export declare type DeleteProjectComponentResponseError = undefined;
export interface GetProjectComponentIssueCountRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the component.
     */
    id: string;
}
declare type GetProjectComponentIssueCountResponseOKType = ComponentIssuesCountAsResponse;
export interface GetProjectComponentIssueCountResponseOK extends GetProjectComponentIssueCountResponseOKType {
}
export declare type GetProjectComponentIssueCountResponseError = undefined;
export interface GetProjectComponentsPaginatedRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `description` Sorts by the component description.
   *  `issueCount` Sorts by the count of issues associated with the component.
   *  `lead` Sorts by the user key of the component's project lead.
   *  `name` Sorts by component name.
  */
    orderBy?: "description" | "-description" | "+description" | "issueCount" | "-issueCount" | "+issueCount" | "lead" | "-lead" | "+lead" | "name" | "-name" | "+name";
    /**
     * The source of the components to return. Can be `jira` (default), `compass` or `auto`. When `auto` is specified, the API will return connected Compass components if the project is opted into Compass, otherwise it will return Jira components. Defaults to `jira`.
     */
    componentSource?: "jira" | "compass" | "auto";
    /**
     * Filter the results using a literal string. Components with a matching `name` or `description` are returned (case insensitive).
     */
    query?: string;
}
declare type GetProjectComponentsPaginatedResponseOKType = PageBeanComponentWithIssueCountAsResponse;
export interface GetProjectComponentsPaginatedResponseOK extends GetProjectComponentsPaginatedResponseOKType {
}
export declare type GetProjectComponentsPaginatedResponseError = undefined;
export interface GetProjectComponentsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * The source of the components to return. Can be `jira` (default), `compass` or `auto`. When `auto` is specified, the API will return connected Compass components if the project is opted into Compass, otherwise it will return Jira components. Defaults to `jira`.
     */
    componentSource?: "jira" | "compass" | "auto";
}
declare type GetProjectComponentsResponseOKType = Array<ProjectComponentAsResponse>;
export interface GetProjectComponentsResponseOK extends GetProjectComponentsResponseOKType {
}
export declare type GetProjectComponentsResponseError = undefined;
export {};
//# sourceMappingURL=component.d.ts.map