/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ProjectRoleAsResponse } from "../../definitions/ProjectRoleAsResponse";
import { ProjectRoleDetailsAsResponse } from "../../definitions/ProjectRoleDetailsAsResponse";
import { CreateUpdateRoleRequestBean } from "../../definitions/CreateUpdateRoleRequestBean";
export interface GetProjectRolesForProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
}
declare type GetProjectRolesForProjectResponseOKType = {
    [x: string]: string;
};
export interface GetProjectRolesForProjectResponseOK extends GetProjectRolesForProjectResponseOKType {
}
export declare type GetProjectRolesForProjectResponseError = undefined;
export interface GetProjectRoleForProjectRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
     */
    id: number;
    /**
     * Exclude inactive users.
     */
    excludeInactiveUsers?: boolean;
}
declare type GetProjectRoleForProjectResponseOKType = ProjectRoleAsResponse;
export interface GetProjectRoleForProjectResponseOK extends GetProjectRoleForProjectResponseOKType {
}
export declare type GetProjectRoleForProjectResponseError = undefined;
export interface GetProjectRoleDetailsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * Whether the roles should be filtered to include only those the user is assigned to.
     */
    currentMember?: boolean;
    excludeConnectAddons?: boolean;
}
declare type GetProjectRoleDetailsResponseOKType = Array<ProjectRoleDetailsAsResponse>;
export interface GetProjectRoleDetailsResponseOK extends GetProjectRoleDetailsResponseOKType {
}
export declare type GetProjectRoleDetailsResponseError = undefined;
export interface GetProjectRolesRequest extends HeadersOption, ErrorStrategyOption {
}
declare type GetProjectRolesResponseOKType = Array<ProjectRoleAsResponse>;
export interface GetProjectRolesResponseOK extends GetProjectRolesResponseOKType {
}
export declare type GetProjectRolesResponseError = undefined;
export interface CreateProjectRoleRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * A description of the project role. Required when fully updating a project role. Optional when creating or partially updating a project role.
         */
        description?: string;
        /**
         * The name of the project role. Must be unique. Cannot begin or end with whitespace. The maximum length is 255 characters. Required when creating a project role. Optional when partially updating a project role.
         */
        name: string;
    };
}
declare type CreateProjectRoleResponseOKType = ProjectRoleAsResponse;
export interface CreateProjectRoleResponseOK extends CreateProjectRoleResponseOKType {
}
export declare type CreateProjectRoleResponseError = undefined;
export interface GetProjectRoleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
     */
    id: number;
}
declare type GetProjectRoleResponseOKType = ProjectRoleAsResponse;
export interface GetProjectRoleResponseOK extends GetProjectRoleResponseOKType {
}
export declare type GetProjectRoleResponseError = undefined;
export interface FullyUpdateProjectRoleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
     */
    id: number;
    body: {
        /**
         * A description of the project role. Required when fully updating a project role. Optional when creating or partially updating a project role.
         */
        description: string;
        /**
         * The name of the project role. Must be unique. Cannot begin or end with whitespace. The maximum length is 255 characters. Required when creating a project role. Optional when partially updating a project role.
         */
        name: string;
    };
}
declare type FullyUpdateProjectRoleResponseOKType = ProjectRoleAsResponse;
export interface FullyUpdateProjectRoleResponseOK extends FullyUpdateProjectRoleResponseOKType {
}
export declare type FullyUpdateProjectRoleResponseError = undefined;
export interface PartiallyUpdateProjectRoleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the project role. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
     */
    id: number;
    body: CreateUpdateRoleRequestBean;
}
declare type PartiallyUpdateProjectRoleResponseOKType = ProjectRoleAsResponse;
export interface PartiallyUpdateProjectRoleResponseOK extends PartiallyUpdateProjectRoleResponseOKType {
}
export declare type PartiallyUpdateProjectRoleResponseError = undefined;
export interface DeleteProjectRoleRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the project role to delete. Use [Get all project roles](#api-rest-api-3-role-get) to get a list of project role IDs.
     */
    id: number;
    /**
     * The ID of the project role that will replace the one being deleted. The swap will attempt to swap the role in schemes (notifications, permissions, issue security), workflows, worklogs and comments.
     */
    swap?: number;
}
export declare type DeleteProjectRoleResponseOK = undefined;
export declare type DeleteProjectRoleResponseError = undefined;
export {};
//# sourceMappingURL=role.d.ts.map