/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanVersionAsResponse } from "../../definitions/PageBeanVersionAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { VersionAsResponse } from "../../definitions/VersionAsResponse";
import { VersionMoveBean } from "../../definitions/VersionMoveBean";
import { DeleteAndReplaceVersionBean } from "../../definitions/DeleteAndReplaceVersionBean";
export interface GetProjectVersionsPaginatedRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `description` Sorts by version description.
   *  `name` Sorts by version name.
   *  `releaseDate` Sorts by release date, starting with the oldest date. Versions with no release date are listed last.
   *  `sequence` Sorts by the order of appearance in the user interface.
   *  `startDate` Sorts by start date, starting with the oldest date. Versions with no start date are listed last.
  */
    orderBy?: "description" | "-description" | "+description" | "name" | "-name" | "+name" | "releaseDate" | "-releaseDate" | "+releaseDate" | "sequence" | "-sequence" | "+sequence" | "startDate" | "-startDate" | "+startDate";
    /**
     * Filter the results using a literal string. Versions with matching `name` or `description` are returned (case insensitive).
     */
    query?: string;
    /**
     * A list of status values used to filter the results by version status. This parameter accepts a comma-separated list. The status values are `released`, `unreleased`, and `archived`.
     */
    status?: string;
    /**
  * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `issuesstatus` Returns the number of issues in each status category for each version.
   *  `operations` Returns actions that can be performed on the specified version.
   *  `driver` Returns the Atlassian account ID of the version driver.
   *  `approvers` Returns a list containing the approvers for this version.
  */
    expand?: string;
}
declare type GetProjectVersionsPaginatedResponseOKType = PageBeanVersionAsResponse;
export interface GetProjectVersionsPaginatedResponseOK extends GetProjectVersionsPaginatedResponseOKType {
}
export declare type GetProjectVersionsPaginatedResponseError = undefined;
export interface GetProjectVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The project ID or project key (case sensitive).
     */
    projectIdOrKey: string;
    /**
     * Use [expand](#expansion) to include additional information in the response. This parameter accepts `operations`, which returns actions that can be performed on the version.
     */
    expand?: string;
}
declare type GetProjectVersionsResponseOKType = Array<VersionAsResponse>;
export interface GetProjectVersionsResponseOK extends GetProjectVersionsResponseOKType {
}
export declare type GetProjectVersionsResponseError = undefined;
export interface CreateProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
    * Use [expand](em>#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
    
     *  `operations` Returns the list of operations available for this version.
     *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*.
    
    Optional for create and update.
    */
        expand?: string;
        /**
         * The description of the version. Optional when creating or updating a version.
         */
        description?: string;
        /**
         * The unique name of the version. Required when creating a version. Optional when updating a version. The maximum length is 255 characters.
         */
        name: string;
        /**
         * Indicates that the version is archived. Optional when creating or updating a version.
         */
        archived?: boolean;
        /**
         * The start date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
         */
        startDate?: string;
        /**
         * The release date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
         */
        releaseDate?: string;
        /**
         * The ID of the project to which this version is attached. Required when creating a version. Not applicable when updating a version.
         */
        projectId: number;
    };
}
declare type CreateProjectVersionResponseOKType = VersionAsResponse;
export interface CreateProjectVersionResponseOK extends CreateProjectVersionResponseOKType {
}
export declare type CreateProjectVersionResponseError = undefined;
export interface GetProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the version.
     */
    id: string;
    /**
  * Use [expand](#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `operations` Returns the list of operations available for this version.
   *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property represents the number of issues with a status other than *to do*, *in progress*, and *done*.
   *  `driver` Returns the Atlassian account ID of the version driver.
   *  `approvers` Returns a list containing the Atlassian account IDs of approvers for this version.
  */
    expand?: string;
}
declare type GetProjectVersionResponseOKType = VersionAsResponse;
export interface GetProjectVersionResponseOK extends GetProjectVersionResponseOKType {
}
export declare type GetProjectVersionResponseError = undefined;
export interface UpdateProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the version.
     */
    id: string;
    body: {
        /**
    * Use [expand](em>#expansion) to include additional information about version in the response. This parameter accepts a comma-separated list. Expand options include:
    
     *  `operations` Returns the list of operations available for this version.
     *  `issuesstatus` Returns the count of issues in this version for each of the status categories *to do*, *in progress*, *done*, and *unmapped*. The *unmapped* property contains a count of issues with a status other than *to do*, *in progress*, and *done*.
    
    Optional for create and update.
    */
        expand?: string;
        /**
         * The description of the version. Optional when creating or updating a version.
         */
        description?: string;
        /**
         * The unique name of the version. Required when creating a version. Optional when updating a version. The maximum length is 255 characters.
         */
        name?: string;
        /**
         * Indicates that the version is archived. Optional when creating or updating a version.
         */
        archived?: boolean;
        /**
         * Indicates that the version is released. If the version is released a request to release again is ignored. Not applicable when creating a version. Optional when updating a version.
         */
        released?: boolean;
        /**
         * The start date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
         */
        startDate?: string;
        /**
         * The release date of the version. Expressed in ISO 8601 format (yyyy-mm-dd). Optional when creating or updating a version.
         */
        releaseDate?: string;
        /**
         * The URL of the self link to the version to which all unfixed issues are moved when a version is released. Not applicable when creating a version. Optional when updating a version.
         */
        moveUnfixedIssuesTo?: string;
    };
}
declare type UpdateProjectVersionResponseOKType = VersionAsResponse;
export interface UpdateProjectVersionResponseOK extends UpdateProjectVersionResponseOKType {
}
export declare type UpdateProjectVersionResponseError = undefined;
export interface MergeProjectVersionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the version to delete.
     */
    id: string;
    /**
     * The ID of the version to merge into.
     */
    moveIssuesTo: string;
}
export declare type MergeProjectVersionsResponseOK = any;
export declare type MergeProjectVersionsResponseError = undefined;
export interface MoveProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the version to be moved.
     */
    id: string;
    body: VersionMoveBean;
}
declare type MoveProjectVersionResponseOKType = VersionAsResponse;
export interface MoveProjectVersionResponseOK extends MoveProjectVersionResponseOKType {
}
export declare type MoveProjectVersionResponseError = undefined;
export interface DeleteAndReplaceProjectVersionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the version.
     */
    id: string;
    body: DeleteAndReplaceVersionBean;
}
export declare type DeleteAndReplaceProjectVersionResponseOK = any;
export declare type DeleteAndReplaceProjectVersionResponseError = undefined;
export {};
//# sourceMappingURL=version.d.ts.map