/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanScreenWithTabAsResponse } from "../definitions/PageBeanScreenWithTabAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageBeanScreenAsResponse } from "../definitions/PageBeanScreenAsResponse";
import { ScreenDetails } from "../definitions/ScreenDetails";
import { ScreenAsResponse } from "../definitions/ScreenAsResponse";
import { ScreenableFieldAsResponse } from "../definitions/ScreenableFieldAsResponse";
import { UpdateScreenDetails } from "../definitions/UpdateScreenDetails";
export interface GetScreensForFieldRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the field to return screens for.
     */
    fieldId: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * Use [expand](#expansion) to include additional information about screens in the response. This parameter accepts `tab` which returns details about the screen tabs the field is used in.
     */
    expand?: string;
}
declare type GetScreensForFieldResponseOKType = PageBeanScreenWithTabAsResponse;
export interface GetScreensForFieldResponseOK extends GetScreensForFieldResponseOKType {
}
export declare type GetScreensForFieldResponseError = undefined;
export interface GetScreensRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of screen IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
     */
    id?: Array<number>;
    /**
     * String used to perform a case-insensitive partial match with screen name.
     */
    queryString?: string;
    /**
     * The scope filter string. To filter by multiple scope, provide an ampersand-separated list. For example, `scope=GLOBAL&scope=PROJECT`.
     */
    scope?: Array<"GLOBAL" | "TEMPLATE" | "PROJECT">;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `id` Sorts by screen ID.
   *  `name` Sorts by screen name.
  */
    orderBy?: "name" | "-name" | "+name" | "id" | "-id" | "+id";
}
declare type GetScreensResponseOKType = PageBeanScreenAsResponse;
export interface GetScreensResponseOK extends GetScreensResponseOKType {
}
export declare type GetScreensResponseError = undefined;
export interface CreateScreenRequest extends HeadersOption, ErrorStrategyOption {
    body: ScreenDetails;
}
declare type CreateScreenResponseOKType = ScreenAsResponse;
export interface CreateScreenResponseOK extends CreateScreenResponseOKType {
}
export declare type CreateScreenResponseError = undefined;
export interface AddFieldToDefaultScreenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the field.
     */
    fieldId: string;
}
export declare type AddFieldToDefaultScreenResponseOK = "CREATED";
export declare type AddFieldToDefaultScreenResponseError = undefined;
export interface GetAvailableScreenFieldsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the screen.
     */
    screenId: number;
}
declare type GetAvailableScreenFieldsResponseOKType = Array<ScreenableFieldAsResponse>;
export interface GetAvailableScreenFieldsResponseOK extends GetAvailableScreenFieldsResponseOKType {
}
export declare type GetAvailableScreenFieldsResponseError = undefined;
export interface UpdateScreenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the screen.
     */
    screenId: number;
    body: UpdateScreenDetails;
}
declare type UpdateScreenResponseOKType = ScreenAsResponse;
export interface UpdateScreenResponseOK extends UpdateScreenResponseOKType {
}
export declare type UpdateScreenResponseError = undefined;
export interface DeleteScreenRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the screen.
     */
    screenId: number;
}
export declare type DeleteScreenResponseOK = undefined;
export declare type DeleteScreenResponseError = undefined;
export {};
//# sourceMappingURL=screen.d.ts.map