/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanScreenSchemeAsResponse } from "../../definitions/PageBeanScreenSchemeAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ScreenSchemeDetails } from "../../definitions/ScreenSchemeDetails";
import { ScreenSchemeIdAsResponse } from "../../definitions/ScreenSchemeIdAsResponse";
import { UpdateScreenSchemeDetails } from "../../definitions/UpdateScreenSchemeDetails";
export interface GetScreenSchemesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The list of screen scheme IDs. To include multiple IDs, provide an ampersand-separated list. For example, `id=10000&id=10001`.
     */
    id?: Array<number>;
    /**
     * Use [expand](#expansion) include additional information in the response. This parameter accepts `issueTypeScreenSchemes` that, for each screen schemes, returns information about the issue type screen scheme the screen scheme is assigned to.
     */
    expand?: string;
    /**
     * String used to perform a case-insensitive partial match with screen scheme name.
     */
    queryString?: string;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `id` Sorts by screen scheme ID.
   *  `name` Sorts by screen scheme name.
  */
    orderBy?: "name" | "-name" | "+name" | "id" | "-id" | "+id";
}
declare type GetScreenSchemesResponseOKType = PageBeanScreenSchemeAsResponse;
export interface GetScreenSchemesResponseOK extends GetScreenSchemesResponseOKType {
}
export declare type GetScreenSchemesResponseError = undefined;
export interface CreateScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    body: ScreenSchemeDetails;
}
declare type CreateScreenSchemeResponseOKType = ScreenSchemeIdAsResponse;
export interface CreateScreenSchemeResponseOK extends CreateScreenSchemeResponseOKType {
}
export declare type CreateScreenSchemeResponseError = undefined;
export interface UpdateScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the screen scheme.
     */
    screenSchemeId: string;
    body: UpdateScreenSchemeDetails;
}
export declare type UpdateScreenSchemeResponseOK = any;
export declare type UpdateScreenSchemeResponseError = undefined;
export interface DeleteScreenSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the screen scheme.
     */
    screenSchemeId: string;
}
export declare type DeleteScreenSchemeResponseOK = undefined;
export declare type DeleteScreenSchemeResponseError = undefined;
export {};
//# sourceMappingURL=scheme.d.ts.map