/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserAsResponse } from "../definitions/UserAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { ColumnItemAsResponse } from "../definitions/ColumnItemAsResponse";
import { NewUserDetails } from "../definitions/NewUserDetails";
import { UserMigrationBeanAsResponse } from "../definitions/UserMigrationBeanAsResponse";
import { UnrestrictedUserEmailAsResponse } from "../definitions/UnrestrictedUserEmailAsResponse";
import { GroupNameAsResponse } from "../definitions/GroupNameAsResponse";
export interface GetUsersDefaultRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return.
     */
    startAt?: number;
    /**
     * The maximum number of items to return.
     */
    maxResults?: number;
}
declare type GetUsersDefaultResponseOKType = Array<UserAsResponse>;
export interface GetUsersDefaultResponseOK extends GetUsersDefaultResponseOKType {
}
export declare type GetUsersDefaultResponseError = undefined;
export interface GetUserDefaultColumnsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId?: string;
}
declare type GetUserDefaultColumnsResponseOKType = Array<ColumnItemAsResponse>;
export interface GetUserDefaultColumnsResponseOK extends GetUserDefaultColumnsResponseOKType {
}
export declare type GetUserDefaultColumnsResponseError = undefined;
export interface SetUserDefaultColumnsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId?: string;
    body: {
        /**
         * The ID of a column
         */
        columns: Array<string>;
    };
}
export declare type SetUserDefaultColumnsResponseOK = any;
export declare type SetUserDefaultColumnsResponseError = undefined;
export interface ResetUserDefaultColumnsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId?: string;
}
export declare type ResetUserDefaultColumnsResponseOK = undefined;
export declare type ResetUserDefaultColumnsResponseError = undefined;
export interface GetUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*. Required.
     */
    accountId?: string;
    /**
  * Use [expand](#expansion) to include additional information about users in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `groups` includes all groups and nested groups to which the user belongs.
   *  `applicationRoles` includes details of all the applications to which the user has access.
  */
    expand?: string;
}
declare type GetUserResponseOKType = UserAsResponse;
export interface GetUserResponseOK extends GetUserResponseOKType {
}
export declare type GetUserResponseError = undefined;
export interface CreateUserRequest extends HeadersOption, ErrorStrategyOption {
    body: NewUserDetails;
}
declare type CreateUserResponseOKType = UserAsResponse;
export interface CreateUserResponseOK extends CreateUserResponseOKType {
}
export declare type CreateUserResponseError = undefined;
export interface DeleteUserRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId: string;
}
export declare type DeleteUserResponseOK = undefined;
export declare type DeleteUserResponseError = undefined;
export interface GetAccountIdsForUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * Username of a user. To specify multiple users, pass multiple copies of this parameter. For example, `username=fred&username=barney`. Required if `key` isn't provided. Cannot be provided if `key` is present.
     */
    username?: Array<string>;
    /**
     * Key of a user. To specify multiple users, pass multiple copies of this parameter. For example, `key=fred&key=barney`. Required if `username` isn't provided. Cannot be provided if `username` is present.
     */
    key?: Array<string>;
}
declare type GetAccountIdsForUsersResponseOKType = Array<UserMigrationBeanAsResponse>;
export interface GetAccountIdsForUsersResponseOK extends GetAccountIdsForUsersResponseOKType {
}
export declare type GetAccountIdsForUsersResponseError = undefined;
export interface GetUserEmailRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, `5b10ac8d82e05b22cc7d4ef5`.
     */
    accountId: string;
}
declare type GetUserEmailResponseOKType = UnrestrictedUserEmailAsResponse;
export interface GetUserEmailResponseOK extends GetUserEmailResponseOKType {
}
export declare type GetUserEmailResponseError = undefined;
export interface GetUserGroupsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The account ID of the user, which uniquely identifies the user across all Atlassian products. For example, *5b10ac8d82e05b22cc7d4ef5*.
     */
    accountId: string;
    /**
     * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
     */
    username?: string;
    /**
     * This parameter is no longer available. See the [deprecation notice](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/) for details.
     */
    key?: string;
}
declare type GetUserGroupsResponseOKType = Array<GroupNameAsResponse>;
export interface GetUserGroupsResponseOK extends GetUserGroupsResponseOKType {
}
export declare type GetUserGroupsResponseError = undefined;
export interface GetUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return.
     */
    startAt?: number;
    /**
     * The maximum number of items to return.
     */
    maxResults?: number;
}
declare type GetUsersResponseOKType = Array<UserAsResponse>;
export interface GetUsersResponseOK extends GetUsersResponseOKType {
}
export declare type GetUsersResponseError = undefined;
export {};
//# sourceMappingURL=user.d.ts.map