/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { UserAsResponse } from "../../definitions/UserAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { FoundUsersAsResponse } from "../../definitions/FoundUsersAsResponse";
import { PageBeanUserAsResponse } from "../../definitions/PageBeanUserAsResponse";
import { ErrorCollectionAsResponse } from "../../definitions/ErrorCollectionAsResponse";
import { PageBeanUserKeyAsResponse } from "../../definitions/PageBeanUserKeyAsResponse";
export interface FindUsersAssignableToProjectsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified.
     */
    query?: string;
    /**
     * A query string that is matched exactly against user `accountId`. Required, unless `query` is specified.
     */
    accountId?: string;
    /**
     * A list of project keys (case sensitive). This parameter accepts a comma-separated list.
     */
    projectKeys: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type FindUsersAssignableToProjectsResponseOKType = Array<UserAsResponse>;
export interface FindUsersAssignableToProjectsResponseOK extends FindUsersAssignableToProjectsResponseOKType {
}
export declare type FindUsersAssignableToProjectsResponseError = undefined;
export interface FindUsersAssignableToIssuesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes, such as `displayName`, and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `username` or `accountId` is specified.
     */
    query?: string;
    /**
     * The sessionId of this request. SessionId is the same until the assignee is set.
     */
    sessionId?: string;
    /**
     * A query string that is matched exactly against user `accountId`. Required, unless `query` is specified.
     */
    accountId?: string;
    /**
     * The project ID or project key (case sensitive). Required, unless `issueKey` is specified.
     */
    project?: string;
    /**
     * The key of the issue. Required, unless `project` is specified.
     */
    issueKey?: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return. This operation may return less than the maximum number of items even if more are available. The operation fetches users up to the maximum and then, from the fetched users, returns only the users that can be assigned to the issue.
     */
    maxResults?: number;
    /**
     * The ID of the transition.
     */
    actionDescriptorId?: number;
    recommend?: boolean;
}
declare type FindUsersAssignableToIssuesResponseOKType = Array<UserAsResponse>;
export interface FindUsersAssignableToIssuesResponseOK extends FindUsersAssignableToIssuesResponseOKType {
}
export declare type FindUsersAssignableToIssuesResponseError = undefined;
export interface FindUsersWithPermissionsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified.
     */
    query?: string;
    /**
     * A query string that is matched exactly against user `accountId`. Required, unless `query` is specified.
     */
    accountId?: string;
    /**
  * A comma separated list of permissions. Permissions can be specified as any:
  
   *  permission returned by [Get all permissions](#api-rest-api-3-permissions-get).
   *  custom project permission added by Connect apps.
   *  (deprecated) one of the following:
      
       *  ASSIGNABLE\_USER
       *  ASSIGN\_ISSUE
       *  ATTACHMENT\_DELETE\_ALL
       *  ATTACHMENT\_DELETE\_OWN
       *  BROWSE
       *  CLOSE\_ISSUE
       *  COMMENT\_DELETE\_ALL
       *  COMMENT\_DELETE\_OWN
       *  COMMENT\_EDIT\_ALL
       *  COMMENT\_EDIT\_OWN
       *  COMMENT\_ISSUE
       *  CREATE\_ATTACHMENT
       *  CREATE\_ISSUE
       *  DELETE\_ISSUE
       *  EDIT\_ISSUE
       *  LINK\_ISSUE
       *  MANAGE\_WATCHER\_LIST
       *  MODIFY\_REPORTER
       *  MOVE\_ISSUE
       *  PROJECT\_ADMIN
       *  RESOLVE\_ISSUE
       *  SCHEDULE\_ISSUE
       *  SET\_ISSUE\_SECURITY
       *  TRANSITION\_ISSUE
       *  VIEW\_VERSION\_CONTROL
       *  VIEW\_VOTERS\_AND\_WATCHERS
       *  VIEW\_WORKFLOW\_READONLY
       *  WORKLOG\_DELETE\_ALL
       *  WORKLOG\_DELETE\_OWN
       *  WORKLOG\_EDIT\_ALL
       *  WORKLOG\_EDIT\_OWN
       *  WORK\_ISSUE
  */
    permissions: string;
    /**
     * The issue key for the issue.
     */
    issueKey?: string;
    /**
     * The project key for the project (case sensitive).
     */
    projectKey?: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type FindUsersWithPermissionsResponseOKType = Array<UserAsResponse>;
export interface FindUsersWithPermissionsResponseOK extends FindUsersWithPermissionsResponseOKType {
}
export declare type FindUsersWithPermissionsResponseError = undefined;
export interface FindUsersForPickerRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes, such as `displayName`, and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*.
     */
    query: string;
    /**
     * The maximum number of items to return. The total number of matched users is returned in `total`.
     */
    maxResults?: number;
    /**
     * Include the URI to the user's avatar.
     */
    showAvatar?: boolean;
    /**
     * A list of account IDs to exclude from the search results. This parameter accepts a comma-separated list. Multiple account IDs can also be provided using an ampersand-separated list. For example, `excludeAccountIds=5b10a2844c20165700ede21g,5b10a0effa615349cb016cd8&excludeAccountIds=5b10ac8d82e05b22cc7d4ef5`. Cannot be provided with `exclude`.
     */
    excludeAccountIds?: Array<string>;
    avatarSize?: string;
    excludeConnectUsers?: boolean;
}
declare type FindUsersForPickerResponseOKType = FoundUsersAsResponse;
export interface FindUsersForPickerResponseOK extends FindUsersForPickerResponseOKType {
}
export declare type FindUsersForPickerResponseError = undefined;
export interface FindUsersRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes ( `displayName`, and `emailAddress`) to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` or `property` is specified.
     */
    query?: string;
    /**
     * A query string that is matched exactly against a user `accountId`. Required, unless `query` or `property` is specified.
     */
    accountId?: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * A query string used to search properties. Property keys are specified by path, so property keys containing dot (.) or equals (=) characters cannot be used. The query string cannot be specified using a JSON object. Example: To search for the value of `nested` from `{"something":{"nested":1,"other":2}}` use `thepropertykey.something.nested=1`. Required, unless `accountId` or `query` is specified.
     */
    property?: string;
}
declare type FindUsersResponseOKType = Array<UserAsResponse>;
export interface FindUsersResponseOK extends FindUsersResponseOKType {
}
export declare type FindUsersResponseError = undefined;
export interface FindUsersByQueryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The search query.
     */
    query: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type FindUsersByQueryResponseOKType = PageBeanUserAsResponse;
export interface FindUsersByQueryResponseOK extends FindUsersByQueryResponseOKType {
}
declare type FindUsersByQueryResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface FindUsersByQueryResponseError extends FindUsersByQueryResponseErrorType {
}
export interface FindUserKeysByQueryRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The search query.
     */
    query: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResult?: number;
}
declare type FindUserKeysByQueryResponseOKType = PageBeanUserKeyAsResponse;
export interface FindUserKeysByQueryResponseOK extends FindUserKeysByQueryResponseOKType {
}
declare type FindUserKeysByQueryResponseErrorType = ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse & ErrorCollectionAsResponse;
export interface FindUserKeysByQueryResponseError extends FindUserKeysByQueryResponseErrorType {
}
export interface FindUsersWithBrowsePermissionRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * A query string that is matched against user attributes, such as `displayName` and `emailAddress`, to find relevant users. The string can match the prefix of the attribute's value. For example, *query=john* matches a user with a `displayName` of *John Smith* and a user with an `emailAddress` of *johnson@example.com*. Required, unless `accountId` is specified.
     */
    query?: string;
    /**
     * A query string that is matched exactly against user `accountId`. Required, unless `query` is specified.
     */
    accountId?: string;
    /**
     * The issue key for the issue. Required, unless `projectKey` is specified.
     */
    issueKey?: string;
    /**
     * The project key for the project (case sensitive). Required, unless `issueKey` is specified.
     */
    projectKey?: string;
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type FindUsersWithBrowsePermissionResponseOKType = Array<UserAsResponse>;
export interface FindUsersWithBrowsePermissionResponseOK extends FindUsersWithBrowsePermissionResponseOKType {
}
export declare type FindUsersWithBrowsePermissionResponseError = undefined;
export {};
//# sourceMappingURL=search.d.ts.map