/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { CreateWorkflowDetails } from "../definitions/CreateWorkflowDetails";
import { WorkflowIDsAsResponse } from "../definitions/WorkflowIDsAsResponse";
import { ErrorStrategyOption } from "../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { PageBeanWorkflowAsResponse } from "../definitions/PageBeanWorkflowAsResponse";
import { ErrorCollectionAsResponse } from "../definitions/ErrorCollectionAsResponse";
export interface CreateWorkflowRequest extends HeadersOption, ErrorStrategyOption {
    body: CreateWorkflowDetails;
}
declare type CreateWorkflowResponseOKType = WorkflowIDsAsResponse;
export interface CreateWorkflowResponseOK extends CreateWorkflowResponseOKType {
}
export declare type CreateWorkflowResponseError = undefined;
export interface DeleteWorkflowRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The entity ID of the workflow.
     */
    entityId: string;
}
export declare type DeleteWorkflowResponseOK = undefined;
export declare type DeleteWorkflowResponseError = undefined;
export interface GetWorkflowsRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
    /**
     * The name of a workflow to return. To include multiple workflows, provide an ampersand-separated list. For example, `workflowName=name1&workflowName=name2`.
     */
    workflowName?: Array<string>;
    /**
  * Use [expand](#expansion) to include additional information in the response. This parameter accepts a comma-separated list. Expand options include:
  
   *  `transitions` For each workflow, returns information about the transitions inside the workflow.
   *  `transitions.rules` For each workflow transition, returns information about its rules. Transitions are included automatically if this expand is requested.
   *  `transitions.properties` For each workflow transition, returns information about its properties. Transitions are included automatically if this expand is requested.
   *  `statuses` For each workflow, returns information about the statuses inside the workflow.
   *  `statuses.properties` For each workflow status, returns information about its properties. Statuses are included automatically if this expand is requested.
   *  `default` For each workflow, returns information about whether this is the default workflow.
   *  `schemes` For each workflow, returns information about the workflow schemes the workflow is assigned to.
   *  `projects` For each workflow, returns information about the projects the workflow is assigned to, through workflow schemes.
   *  `hasDraftWorkflow` For each workflow, returns information about whether the workflow has a draft version.
   *  `operations` For each workflow, returns information about the actions that can be undertaken on the workflow.
  */
    expand?: string;
    /**
     * String used to perform a case-insensitive partial match with workflow name.
     */
    queryString?: string;
    /**
  * [Order](#ordering) the results by a field:
  
   *  `name` Sorts by workflow name.
   *  `created` Sorts by create time.
   *  `updated` Sorts by update time.
  */
    orderBy?: "name" | "-name" | "+name" | "created" | "-created" | "+created" | "updated" | "+updated" | "-updated";
    /**
     * Filters active and inactive workflows.
     */
    isActive?: boolean;
}
declare type GetWorkflowsResponseOKType = PageBeanWorkflowAsResponse;
export interface GetWorkflowsResponseOK extends GetWorkflowsResponseOKType {
}
declare type GetWorkflowsResponseErrorType = ErrorCollectionAsResponse;
export interface GetWorkflowsResponseError extends GetWorkflowsResponseErrorType {
}
export {};
//# sourceMappingURL=workflow.d.ts.map