/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { PageBeanWorkflowSchemeAsResponse } from "../../definitions/PageBeanWorkflowSchemeAsResponse";
import { ErrorStrategyOption } from "../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { WorkflowSchemeAsResponse } from "../../definitions/WorkflowSchemeAsResponse";
import { WorkflowScheme } from "../../definitions/WorkflowScheme";
import { IssueTypeWorkflowMappingAsResponse } from "../../definitions/IssueTypeWorkflowMappingAsResponse";
import { IssueTypeWorkflowMapping } from "../../definitions/IssueTypeWorkflowMapping";
import { IssueTypesWorkflowMappingAsResponse } from "../../definitions/IssueTypesWorkflowMappingAsResponse";
import { IssueTypesWorkflowMapping } from "../../definitions/IssueTypesWorkflowMapping";
import { DefaultWorkflowAsResponse } from "../../definitions/DefaultWorkflowAsResponse";
import { DefaultWorkflow } from "../../definitions/DefaultWorkflow";
export interface GetWorkflowSchemesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The index of the first item to return in a page of results (page offset).
     */
    startAt?: number;
    /**
     * The maximum number of items to return per page.
     */
    maxResults?: number;
}
declare type GetWorkflowSchemesResponseOKType = PageBeanWorkflowSchemeAsResponse;
export interface GetWorkflowSchemesResponseOK extends GetWorkflowSchemesResponseOKType {
}
export declare type GetWorkflowSchemesResponseError = undefined;
export interface CreateWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    body: {
        /**
         * The name of the default workflow for the workflow scheme. The default workflow has *All Unassigned Issue Types* assigned to it in Jira. If `defaultWorkflow` is not specified when creating a workflow scheme, it is set to *Jira Workflow (jira)*.
         */
        defaultWorkflow?: string;
        /**
         * The description of the workflow scheme.
         */
        description?: string;
        /**
         * The issue type to workflow mappings, where each mapping is an issue type ID and workflow name pair. Note that an issue type can only be mapped to one workflow in a workflow scheme.
         */
        issueTypeMappings?: {
            [x: string]: string;
        };
        /**
         * The name of the workflow scheme. The name must be unique. The maximum length is 255 characters. Required when creating a workflow scheme.
         */
        name: string;
        /**
    * Whether to create or update a draft workflow scheme when updating an active workflow scheme. An active workflow scheme is a workflow scheme that is used by at least one project. The following examples show how this property works:
    
     *  Update an active workflow scheme with `updateDraftIfNeeded` set to `true`: If a draft workflow scheme exists, it is updated. Otherwise, a draft workflow scheme is created.
     *  Update an active workflow scheme with `updateDraftIfNeeded` set to `false`: An error is returned, as active workflow schemes cannot be updated.
     *  Update an inactive workflow scheme with `updateDraftIfNeeded` set to `true`: The workflow scheme is updated, as inactive workflow schemes do not require drafts to update.
    
    Defaults to `false`.
    */
        updateDraftIfNeeded?: boolean;
    };
}
declare type CreateWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface CreateWorkflowSchemeResponseOK extends CreateWorkflowSchemeResponseOKType {
}
export declare type CreateWorkflowSchemeResponseError = undefined;
export interface GetWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*.
     */
    id: number;
    /**
     * Returns the workflow scheme's draft rather than scheme itself, if set to true. If the workflow scheme does not have a draft, then the workflow scheme is returned.
     */
    returnDraftIfExists?: boolean;
}
declare type GetWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface GetWorkflowSchemeResponseOK extends GetWorkflowSchemeResponseOKType {
}
export declare type GetWorkflowSchemeResponseError = undefined;
export interface UpdateWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*.
     */
    id: number;
    body: WorkflowScheme;
}
declare type UpdateWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface UpdateWorkflowSchemeResponseOK extends UpdateWorkflowSchemeResponseOKType {
}
export declare type UpdateWorkflowSchemeResponseError = undefined;
export interface DeleteWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme. Find this ID by editing the desired workflow scheme in Jira. The ID is shown in the URL as `schemeId`. For example, *schemeId=10301*.
     */
    id: number;
}
export declare type DeleteWorkflowSchemeResponseOK = any;
export declare type DeleteWorkflowSchemeResponseError = undefined;
export interface GetWorkflowForIssueTypeInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The ID of the issue type.
     */
    issueType: string;
    /**
     * Returns the mapping from the workflow scheme's draft rather than the workflow scheme, if set to true. If no draft exists, the mapping from the workflow scheme is returned.
     */
    returnDraftIfExists?: boolean;
}
declare type GetWorkflowForIssueTypeInWorkflowSchemeResponseOKType = IssueTypeWorkflowMappingAsResponse;
export interface GetWorkflowForIssueTypeInWorkflowSchemeResponseOK extends GetWorkflowForIssueTypeInWorkflowSchemeResponseOKType {
}
export declare type GetWorkflowForIssueTypeInWorkflowSchemeResponseError = undefined;
export interface SetWorkflowForIssueTypeInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The ID of the issue type.
     */
    issueType: string;
    body: IssueTypeWorkflowMapping;
}
declare type SetWorkflowForIssueTypeInWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface SetWorkflowForIssueTypeInWorkflowSchemeResponseOK extends SetWorkflowForIssueTypeInWorkflowSchemeResponseOKType {
}
export declare type SetWorkflowForIssueTypeInWorkflowSchemeResponseError = undefined;
export interface DeleteWorkflowForIssueTypeInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The ID of the issue type.
     */
    issueType: string;
    /**
     * Set to true to create or update the draft of a workflow scheme and update the mapping in the draft, when the workflow scheme cannot be edited. Defaults to `false`.
     */
    updateDraftIfNeeded?: boolean;
}
declare type DeleteWorkflowForIssueTypeInWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface DeleteWorkflowForIssueTypeInWorkflowSchemeResponseOK extends DeleteWorkflowForIssueTypeInWorkflowSchemeResponseOKType {
}
export declare type DeleteWorkflowForIssueTypeInWorkflowSchemeResponseError = undefined;
export interface GetIssueTypesForWorkflowInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The name of a workflow in the scheme. Limits the results to the workflow-issue type mapping for the specified workflow.
     */
    workflowName?: string;
    /**
     * Returns the mapping from the workflow scheme's draft rather than the workflow scheme, if set to true. If no draft exists, the mapping from the workflow scheme is returned.
     */
    returnDraftIfExists?: boolean;
}
declare type GetIssueTypesForWorkflowInWorkflowSchemeResponseOKType = Array<IssueTypesWorkflowMappingAsResponse>;
export interface GetIssueTypesForWorkflowInWorkflowSchemeResponseOK extends GetIssueTypesForWorkflowInWorkflowSchemeResponseOKType {
}
export declare type GetIssueTypesForWorkflowInWorkflowSchemeResponseError = undefined;
export interface SetIssueTypesForWorkflowInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The name of the workflow.
     */
    workflowName: string;
    body: IssueTypesWorkflowMapping;
}
declare type SetIssueTypesForWorkflowInWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface SetIssueTypesForWorkflowInWorkflowSchemeResponseOK extends SetIssueTypesForWorkflowInWorkflowSchemeResponseOKType {
}
export declare type SetIssueTypesForWorkflowInWorkflowSchemeResponseError = undefined;
export interface DeleteIssueTypesForWorkflowInWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * The name of the workflow.
     */
    workflowName: string;
    /**
     * Set to true to create or update the draft of a workflow scheme and delete the mapping from the draft, when the workflow scheme cannot be edited. Defaults to `false`.
     */
    updateDraftIfNeeded?: boolean;
}
export declare type DeleteIssueTypesForWorkflowInWorkflowSchemeResponseOK = undefined;
export declare type DeleteIssueTypesForWorkflowInWorkflowSchemeResponseError = undefined;
export interface GetDefaultWorkflowForWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * Set to `true` to return the default workflow for the workflow scheme's draft rather than scheme itself. If the workflow scheme does not have a draft, then the default workflow for the workflow scheme is returned.
     */
    returnDraftIfExists?: boolean;
}
declare type GetDefaultWorkflowForWorkflowSchemeResponseOKType = DefaultWorkflowAsResponse;
export interface GetDefaultWorkflowForWorkflowSchemeResponseOK extends GetDefaultWorkflowForWorkflowSchemeResponseOKType {
}
export declare type GetDefaultWorkflowForWorkflowSchemeResponseError = undefined;
export interface UpdateDefaultWorkflowForWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    body: DefaultWorkflow;
}
declare type UpdateDefaultWorkflowForWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface UpdateDefaultWorkflowForWorkflowSchemeResponseOK extends UpdateDefaultWorkflowForWorkflowSchemeResponseOKType {
}
export declare type UpdateDefaultWorkflowForWorkflowSchemeResponseError = undefined;
export interface DeleteDefaultWorkflowForWorkflowSchemeRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the workflow scheme.
     */
    id: number;
    /**
     * Set to true to create or update the draft of a workflow scheme and delete the mapping from the draft, when the workflow scheme cannot be edited. Defaults to `false`.
     */
    updateDraftIfNeeded?: boolean;
}
declare type DeleteDefaultWorkflowForWorkflowSchemeResponseOKType = WorkflowSchemeAsResponse;
export interface DeleteDefaultWorkflowForWorkflowSchemeResponseOK extends DeleteDefaultWorkflowForWorkflowSchemeResponseOKType {
}
export declare type DeleteDefaultWorkflowForWorkflowSchemeResponseError = undefined;
export {};
//# sourceMappingURL=scheme.d.ts.map