/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { WorkflowTransitionPropertyAsResponse } from "../../../definitions/WorkflowTransitionPropertyAsResponse";
import { ErrorStrategyOption } from "../../../errorStrategy";
import { HeadersOption } from "@managed-api/commons-core";
import { WorkflowTransitionProperty } from "../../../definitions/WorkflowTransitionProperty";
export interface GetWorkflowTransitionPropertiesRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the transition. To get the ID, view the workflow in text mode in the Jira administration console. The ID is shown next to the transition.
     */
    transitionId: number;
    /**
     * Some properties with keys that have the *jira.* prefix are reserved, which means they are not editable. To include these properties in the results, set this parameter to *true*.
     */
    includeReservedKeys?: boolean;
    /**
     * The key of the property being returned, also known as the name of the property. If this parameter is not specified, all properties on the transition are returned.
     */
    key?: string;
    /**
     * The name of the workflow that the transition belongs to.
     */
    workflowName: string;
    /**
     * The workflow status. Set to *live* for active and inactive workflows, or *draft* for draft workflows.
     */
    workflowMode?: "live" | "draft";
}
declare type GetWorkflowTransitionPropertiesResponseOKType = WorkflowTransitionPropertyAsResponse;
export interface GetWorkflowTransitionPropertiesResponseOK extends GetWorkflowTransitionPropertiesResponseOKType {
}
export declare type GetWorkflowTransitionPropertiesResponseError = undefined;
export interface UpdateWorkflowTransitionPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition.
     */
    transitionId: number;
    /**
     * The key of the property being updated, also known as the name of the property. Set this to the same value as the `key` defined in the request body.
     */
    key: string;
    /**
     * The name of the workflow that the transition belongs to.
     */
    workflowName: string;
    /**
     * The workflow status. Set to `live` for inactive workflows or `draft` for draft workflows. Active workflows cannot be edited.
     */
    workflowMode?: "live" | "draft";
    body: WorkflowTransitionProperty;
}
declare type UpdateWorkflowTransitionPropertyResponseOKType = WorkflowTransitionPropertyAsResponse;
export interface UpdateWorkflowTransitionPropertyResponseOK extends UpdateWorkflowTransitionPropertyResponseOKType {
}
export declare type UpdateWorkflowTransitionPropertyResponseError = undefined;
export interface CreateWorkflowTransitionPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition.
     */
    transitionId: number;
    /**
     * The key of the property being added, also known as the name of the property. Set this to the same value as the `key` defined in the request body.
     */
    key: string;
    /**
     * The name of the workflow that the transition belongs to.
     */
    workflowName: string;
    /**
     * The workflow status. Set to *live* for inactive workflows or *draft* for draft workflows. Active workflows cannot be edited.
     */
    workflowMode?: "live" | "draft";
    body: WorkflowTransitionProperty;
}
declare type CreateWorkflowTransitionPropertyResponseOKType = WorkflowTransitionPropertyAsResponse;
export interface CreateWorkflowTransitionPropertyResponseOK extends CreateWorkflowTransitionPropertyResponseOKType {
}
export declare type CreateWorkflowTransitionPropertyResponseError = undefined;
export interface DeleteWorkflowTransitionPropertyRequest extends HeadersOption, ErrorStrategyOption {
    /**
     * The ID of the transition. To get the ID, view the workflow in text mode in the Jira admin settings. The ID is shown next to the transition.
     */
    transitionId: number;
    /**
     * The name of the transition property to delete, also known as the name of the property.
     */
    key: string;
    /**
     * The name of the workflow that the transition belongs to.
     */
    workflowName: string;
    /**
     * The workflow status. Set to `live` for inactive workflows or `draft` for draft workflows. Active workflows cannot be edited.
     */
    workflowMode?: "live" | "draft";
}
export declare type DeleteWorkflowTransitionPropertyResponseOK = undefined;
export declare type DeleteWorkflowTransitionPropertyResponseError = undefined;
export {};
//# sourceMappingURL=property.d.ts.map