/*!
 * Copyright Adaptavist 2022 (c) All rights reserved
 */
import { Blob, FormData } from "@managed-api/commons-core";
import { BaseApiCore, constructUrl, executeHttpCall, Request, Response } from "@managed-api/commons-core";
import { constructHeaders, errorMessageBuilder } from "./common";
import { customErrorHandlers, errorStrategyBuilderConstructor } from "./errorStrategy";
export class JiraCloudApiCore extends BaseApiCore {
    constructor(options) {
        var _a, _b;
        super();
        this.options = options;
        if (!((_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy) && ((_b = this.options) === null || _b === void 0 ? void 0 : _b.errorStrategy) !== null) {
            this.setGlobalErrorStrategy((builder) => builder.retryOnRateLimiting(-1));
        }
        this.Issue = new IssueGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Avatar = new AvatarGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Project = new ProjectGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.User = new UserGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Workflow = new WorkflowGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Dashboard = new DashboardGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Application = new ApplicationGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Instance = new InstanceGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Filter = new FilterGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Group = new GroupGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.GroupAndUserPicker = new GroupAndUserPickerGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Jql = new JqlGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Label = new LabelGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Permission = new PermissionGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Myself = new MyselfGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.Screen = new ScreenGroup(this.implementation, () => this.getGlobalErrorStrategy());
        this.All = new AllGroup(this.Issue, this.Avatar, this.Project, this.User, this.Workflow, this.Dashboard, this.Application, this.Instance, this.Filter, this.Group, this.GroupAndUserPicker, this.Jql, this.Label, this.Permission, this.Myself, this.Screen);
    }
    setGlobalErrorStrategy(errorStrategy) {
        var _a;
        this.options = {
            ...(_a = this.options, (_a !== null && _a !== void 0 ? _a : {})),
            errorStrategy,
        };
    }
    buildResponse(url, status, statusText, headers, body) {
        const response = new Response(url, status, statusText, headers, body);
        response.setBufferImplementation(this.implementation);
        return response;
    }
    getGlobalErrorStrategy() {
        var _a;
        return (_a = this.options) === null || _a === void 0 ? void 0 : _a.errorStrategy;
    }
}
class AllGroup {
    constructor(Issue, Avatar, Project, User, Workflow, Dashboard, Application, Instance, Filter, Group, GroupAndUserPicker, Jql, Label, Permission, Myself, Screen) {
        this.Issue = Issue;
        this.Avatar = Avatar;
        this.Project = Project;
        this.User = User;
        this.Workflow = Workflow;
        this.Dashboard = Dashboard;
        this.Application = Application;
        this.Instance = Instance;
        this.Filter = Filter;
        this.Group = Group;
        this.GroupAndUserPicker = GroupAndUserPicker;
        this.Jql = Jql;
        this.Label = Label;
        this.Permission = Permission;
        this.Myself = Myself;
        this.Screen = Screen;
    }
    /**
  * Creates an issue or, where the option to create subtasks is enabled in Jira, a subtask. A transition may be applied, to move the issue or subtask to a workflow step other than the default start step, and issue properties set.
  
  The content of the issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issue's create screen. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` must contain the ID or key of the parent issue.
  
  In a next-gen project any issue may be made a child providing that the parent and child are members of the same project.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which the issue or subtask is created.
  * Alternative usage: Issue.createIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-post
  * @param options Request options.
  */
    async createIssue(options) {
        return this.Issue.createIssue(options);
    }
    /**
  * Creates upto **50** issues and, where the option to create subtasks is enabled in Jira, subtasks. Transitions may be applied, to move the issues or subtasks to a workflow step other than the default start step, and issue properties set.
  
  The content of each issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issues' create screens. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` the must contain the ID or key of the parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which each issue or subtask is created.
  * Alternative usage: Issue.createIssues
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-bulk-post
  * @param options Request options.
  */
    async createIssues(options) {
        return this.Issue.createIssues(options);
    }
    /**
  * Returns the details for an issue.
  
  The issue is identified by its ID or key, however, if the identifier doesn't match an issue, a case-insensitive search and check for moved issues is performed. If a matching issue is found its details are returned, a 302 or other redirect is **not** returned. The issue key returned in the response is the key of the issue found.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.getIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-get
  * @param options Request options.
  */
    async getIssue(options) {
        return this.Issue.getIssue(options);
    }
    /**
  * Edits an issue. Issue properties may be updated as part of the edit. Please note that issue transition is not supported and is ignored here. To transition an issue, please use [Transition issue](#api-rest-api-3-issue-issueIdOrKey-transitions-post).
  
  The edits to the issue's fields are defined using `update` and `fields`. The fields that can be edited are determined using [ Get edit issue metadata](#api-rest-api-3-issue-issueIdOrKey-editmeta-get).
  
  The parent field may be set by key or ID. For standard issue types, the parent may be removed by setting `update.parent.set.none` to *true*. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Connect apps having an app user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.editIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-put
  * @param options Request options.
  */
    async editIssue(options) {
        return this.Issue.editIssue(options);
    }
    /**
  * Deletes an issue.
  
  An issue cannot be deleted if it has one or more subtasks. To delete an issue with subtasks, set `deleteSubtasks`. This causes the issue's subtasks to be deleted with the issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Delete issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.deleteIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-delete
  * @param options Request options.
  */
    async deleteIssue(options) {
        return this.Issue.deleteIssue(options);
    }
    /**
  * Assigns an issue to a user. Use this operation when the calling user does not have the *Edit Issues* permission but has the *Assign issue* permission for the project that the issue is in.
  
  If `name` or `accountId` is set to:
  
   *  `"-1"`, the issue is assigned to the default assignee for the project.
   *  `null`, the issue is set to unassigned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Assign Issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.assignIssue
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-assignee-put
  * @param options Request options.
  */
    async assignIssue(options) {
        return this.Issue.assignIssue(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all changelogs for an issue sorted by date, starting from the oldest.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.getChangeLogs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-get
  * @param options Request options.
  */
    async getIssueChangeLogs(options) {
        return this.Issue.getChangeLogs(options);
    }
    /**
  * Returns changelogs for an issue specified by a list of changelog IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.getChangeLogsById
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-list-post
  * @param options Request options.
  */
    async getIssueChangeLogsById(options) {
        return this.Issue.getChangeLogsById(options);
    }
    /**
  * Creates an email notification for an issue and adds it to the mail queue.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.sendNotification
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-notify-post
  * @param options Request options.
  */
    async sendNotificationForIssue(options) {
        return this.Issue.sendNotification(options);
    }
    /**
  * Returns a [paginated](#pagination) list of priorities. The list can contain all priorities or a subset determined by any combination of these criteria:
  
   *  a list of priority IDs. Any invalid priority IDs are ignored.
   *  a list of project IDs. Only priorities that are available in these projects will be returned. Any invalid project IDs are ignored.
   *  whether the field configuration is a default. This returns priorities from company-managed (classic) projects only, as there is no concept of default priorities in team-managed projects.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Priority.searchPriorities
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-search-get
  * @param options Request options.
  */
    async searchIssuePriorities(options) {
        return this.Issue.Priority.searchPriorities(options);
    }
    /**
  * Returns the list of all issue priorities.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Priority.getPriorities
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-get
  * @param options Request options.
  * @deprecated
  */
    async getIssuePriorities(options) {
        return this.Issue.Priority.getPriorities(options);
    }
    /**
  * Returns an issue priority.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Priority.getPriority
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-id-get
  * @param options Request options.
  */
    async getIssuePriority(options) {
        return this.Issue.Priority.getPriority(options);
    }
    /**
  * Returns system and custom issue fields according to the following rules:
  
   *  Fields that cannot be added to the issue navigator are always returned.
   *  Fields that cannot be placed on an issue screen are always returned.
   *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
   *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Issue.Field.getFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-get
  * @param options Request options.
  */
    async getIssueFields(options) {
        return this.Issue.Field.getFields(options);
    }
    /**
  * Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:
  
   *  all fields
   *  specific fields, by defining `id`
   *  fields that contain a string in the field name or description, by defining `query`
   *  specific fields that contain a string in the field name or description, by defining `id` and `query`
  
  Use `type` must be set to `custom` to show custom fields only.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.getFieldsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-search-get
  * @param options Request options.
  */
    async getFieldsPaginated(options) {
        return this.Issue.Field.getFieldsPaginated(options);
    }
    /**
  * Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.getContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-contexts-get
  * @param options Request options.
  * @deprecated
  */
    async getFieldContexts(options) {
        return this.Issue.Field.getContexts(options);
    }
    /**
  * Creates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.createField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-post
  * @param options Request options.
  */
    async createIssueCustomField(options) {
        return this.Issue.Field.Custom.createField(options);
    }
    /**
  * Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.deleteField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-delete
  * @param options Request options.
  */
    async deleteIssueCustomField(options) {
        return this.Issue.Field.Custom.deleteField(options);
    }
    /**
  * Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.restoreField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-restore-post
  * @param options Request options.
  */
    async restoreIssueCustomField(options) {
        return this.Issue.Field.Custom.restoreField(options);
    }
    /**
  * Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.moveToTrash
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-trash-post
  * @param options Request options.
  */
    async moveIssueCustomFieldToTrash(options) {
        return this.Issue.Field.Custom.moveToTrash(options);
    }
    /**
  * Updates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.updateField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-put
  * @param options Request options.
  */
    async updateIssueCustomField(options) {
        return this.Issue.Field.Custom.updateField(options);
    }
    /**
  * Returns a [paginated](#pagination) list of project and issue type mappings and, for each mapping, the ID of a [custom field context](https://confluence.atlassian.com/x/k44fOw) that applies to the project and issue type.
  
  If there is no custom field context assigned to the project then, if present, the custom field context that applies to all projects is returned if it also applies to the issue type or all issue types. If a custom field context is not found, the returned custom field context ID is `null`.
  
  Duplicate project and issue type mappings cannot be provided in the request.
  
  The order of the returned values is the same as provided in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.getForProjectsAndIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-mapping-post
  * @param options Request options.
  */
    async getIssueCustomFieldContextsForProjectsAndIssueType(options) {
        return this.Issue.Field.Custom.Context.getForProjectsAndIssueType(options);
    }
    /**
  * Deletes a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.deleteContext
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-delete
  * @param options Request options.
  */
    async deleteIssueCustomFieldContext(options) {
        return this.Issue.Field.Custom.Context.deleteContext(options);
    }
    /**
  * Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.updateContext
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-put
  * @param options Request options.
  */
    async updateIssueCustomFieldContext(options) {
        return this.Issue.Field.Custom.Context.updateContext(options);
    }
    /**
  * Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:
  
   *  With no other parameters set, all contexts.
   *  By defining `id` only, all contexts from the list of IDs.
   *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
   *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.getContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-get
  * @param options Request options.
  */
    async getIssueCustomFieldContexts(options) {
        return this.Issue.Field.Custom.Context.getContexts(options);
    }
    /**
  * Creates a custom field context.
  
  If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.createContext
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-post
  * @param options Request options.
  */
    async createIssueCustomFieldContext(options) {
        return this.Issue.Field.Custom.Context.createContext(options);
    }
    /**
  * Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
  The returned object depends on type of the custom field:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group pickers.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group pickers.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URLs.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project pickers.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for floats (floating-point numbers).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text fields.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area fields.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) fields.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version pickers.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version pickers.
  
  Forge custom fields [types](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field-type/#data-types) are also supported, returning:
  
   *  `CustomFieldContextDefaultValueForgeStringFieldBean` (type `forge.string`) for Forge string fields.
   *  `CustomFieldContextDefaultValueForgeMultiStringFieldBean` (type `forge.string.list`) for Forge string collection fields.
   *  `CustomFieldContextDefaultValueForgeObjectFieldBean` (type `forge.object`) for Forge object fields.
   *  `CustomFieldContextDefaultValueForgeDateTimeFieldBean` (type `forge.datetime`) for Forge date-time fields.
   *  `CustomFieldContextDefaultValueForgeGroupFieldBean` (type `forge.group`) for Forge group fields.
   *  `CustomFieldContextDefaultValueForgeMultiGroupFieldBean` (type `forge.group.list`) for Forge group collection fields.
   *  `CustomFieldContextDefaultValueForgeNumberFieldBean` (type `forge.number`) for Forge number fields.
   *  `CustomFieldContextDefaultValueForgeUserFieldBean` (type `forge.user`) for Forge user fields.
   *  `CustomFieldContextDefaultValueForgeMultiUserFieldBean` (type `forge.user.list`) for Forge user collection fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.getDefaultContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-get
  * @param options Request options.
  */
    async getIssueCustomFieldDefaultContexts(options) {
        return this.Issue.Field.Custom.Context.getDefaultContexts(options);
    }
    /**
  * Sets default for contexts of a custom field. Default are defined using these objects:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group pickers.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group pickers.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URLs.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project pickers.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for floats (floating-point numbers).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text fields.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area fields.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) fields.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version pickers.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version pickers.
  
  Forge custom fields [types](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field-type/#data-types) are also supported, returning:
  
   *  `CustomFieldContextDefaultValueForgeStringFieldBean` (type `forge.string`) for Forge string fields.
   *  `CustomFieldContextDefaultValueForgeMultiStringFieldBean` (type `forge.string.list`) for Forge string collection fields.
   *  `CustomFieldContextDefaultValueForgeObjectFieldBean` (type `forge.object`) for Forge object fields.
   *  `CustomFieldContextDefaultValueForgeDateTimeFieldBean` (type `forge.datetime`) for Forge date-time fields.
   *  `CustomFieldContextDefaultValueForgeGroupFieldBean` (type `forge.group`) for Forge group fields.
   *  `CustomFieldContextDefaultValueForgeMultiGroupFieldBean` (type `forge.group.list`) for Forge group collection fields.
   *  `CustomFieldContextDefaultValueForgeNumberFieldBean` (type `forge.number`) for Forge number fields.
   *  `CustomFieldContextDefaultValueForgeUserFieldBean` (type `forge.user`) for Forge user fields.
   *  `CustomFieldContextDefaultValueForgeMultiUserFieldBean` (type `forge.user.list`) for Forge user collection fields.
  
  Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.setDefaultContexts
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-put
  * @param options Request options.
  */
    async setIssueCustomFieldDefaultContexts(options) {
        return this.Issue.Field.Custom.Context.setDefaultContexts(options);
    }
    /**
  * Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.getIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-issuetypemapping-get
  * @param options Request options.
  */
    async getIssueCustomFieldIssueTypesForContext(options) {
        return this.Issue.Field.Custom.Context.getIssueTypes(options);
    }
    /**
  * Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.getProjectMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-projectmapping-get
  * @param options Request options.
  */
    async getIssueCustomFieldContextToProjectMappings(options) {
        return this.Issue.Field.Custom.Context.getProjectMappings(options);
    }
    /**
  * Adds issue types to a custom field context, appending the issue types to the issue types list.
  
  A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.
  
  If any of the issue types exists in the custom field context, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.addIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-put
  * @param options Request options.
  */
    async addIssueTypesToIssueCustomFieldContext(options) {
        return this.Issue.Field.Custom.Context.addIssueTypes(options);
    }
    /**
  * Removes issue types from a custom field context.
  
  A custom field context without any issue types applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.removeIssueTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-remove-post
  * @param options Request options.
  */
    async removeIssueTypesFromIssueCustomFieldContext(options) {
        return this.Issue.Field.Custom.Context.removeIssueTypes(options);
    }
    /**
  * Assigns a custom field context to projects.
  
  If any project in the request is assigned to any context of the custom field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.assignToProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-put
  * @param options Request options.
  */
    async assignIssueCustomFieldContextToProjects(options) {
        return this.Issue.Field.Custom.Context.assignToProjects(options);
    }
    /**
  * Removes a custom field context from projects.
  
  A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.
  
  If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.removeFromProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-remove-post
  * @param options Request options.
  */
    async removeIssueCustomFieldContextFromProjects(options) {
        return this.Issue.Field.Custom.Context.removeFromProjects(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.Option.getOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-get
  * @param options Request options.
  */
    async getIssueCustomFieldContextOptions(options) {
        return this.Issue.Field.Custom.Context.Option.getOptions(options);
    }
    /**
  * Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.
  
  The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.Option.createOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-post
  * @param options Request options.
  */
    async createIssueCustomFieldContextOptions(options) {
        return this.Issue.Field.Custom.Context.Option.createOptions(options);
    }
    /**
  * Updates the options of a custom field.
  
  If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.Option.updateOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-put
  * @param options Request options.
  */
    async updateIssueCustomFieldContextOptions(options) {
        return this.Issue.Field.Custom.Context.Option.updateOptions(options);
    }
    /**
  * Changes the order of custom field options or cascading options in a context.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.Option.reorderOptions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-move-put
  * @param options Request options.
  */
    async reorderIssueCustomFieldContextOptions(options) {
        return this.Issue.Field.Custom.Context.Option.reorderOptions(options);
    }
    /**
  * Deletes a custom field option.
  
  Options with cascading options cannot be deleted without deleting the cascading options first.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Custom.Context.Option.deleteOption
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-optionid-delete
  * @param options Request options.
  */
    async deleteIssueCustomFieldContextOption(options) {
        return this.Issue.Field.Custom.Context.Option.deleteOption(options);
    }
    /**
  * Returns a custom field option. For example, an option in a select list.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The custom field option is returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the custom field is used in, and the field is visible in at least one layout the user has permission to view.
  * Alternative usage: Issue.Field.Custom.Option.getOption
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-customfieldoption-id-get
  * @param options Request options.
  */
    async getIssueCustomFieldOption(options) {
        return this.Issue.Field.Custom.Option.getOption(options);
    }
    /**
  * Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.
  
  This operation can only create configurations for use in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.createConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
  * @param options Request options.
  */
    async createIssueFieldConfiguration(options) {
        return this.Issue.Field.Configuration.createConfiguration(options);
    }
    /**
  * Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:
  
   *  a list of field configuration item IDs.
   *  whether the field configuration is a default.
   *  whether the field configuration name or description contains a query string.
  
  Only field configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.getConfigurations
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-get
  * @param options Request options.
  */
    async getIssueFieldConfigurations(options) {
        return this.Issue.Field.Configuration.getConfigurations(options);
    }
    /**
  * Updates a field configuration. The name and the description provided in the request override the existing values.
  
  This operation can only update configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.updateConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
  * @param options Request options.
  */
    async updateIssueFieldConfiguration(options) {
        return this.Issue.Field.Configuration.updateConfiguration(options);
    }
    /**
  * Deletes a field configuration.
  
  This operation can only delete configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.deleteConfiguration
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
  * @param options Request options.
  */
    async deleteIssueFieldConfiguration(options) {
        return this.Issue.Field.Configuration.deleteConfiguration(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all fields for a configuration.
  
  Only the fields from configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.getConfigurationItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-fields-get
  * @param options Request options.
  */
    async getIssueFieldConfigurationItems(options) {
        return this.Issue.Field.Configuration.getConfigurationItems(options);
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration issue type items.
  
  Only items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.getConfigurationIssueTypeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-mapping-get
  * @param options Request options.
  */
    async getIssueFieldConfigurationIssueTypeItems(options) {
        return this.Issue.Field.Configuration.getConfigurationIssueTypeItems(options);
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
  * @param options Request options.
  */
    async getIssueFieldConfigurationSchemes(options) {
        return this.Issue.Field.Configuration.getSchemes(options);
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.
  
  The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-get
  * @param options Request options.
  */
    async getIssueFieldConfigurationSchemesForProjects(options) {
        return this.Issue.Field.Configuration.Scheme.getSchemesForProjects(options);
    }
    /**
  * Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.
  
  Field configuration schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Field.Configuration.Scheme.assignSchemeToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-put
  * @param options Request options.
  */
    async assignIssueFieldConfigurationSchemeToProject(options) {
        return this.Issue.Field.Configuration.Scheme.assignSchemeToProject(options);
    }
    /**
  * Returns all issue types.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issue types are only returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
  * Alternative usage: Issue.Type.getTypesForUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-get
  * @param options Request options.
  */
    async getIssueTypesForUser(options) {
        return this.Issue.Type.getTypesForUser(options);
    }
    /**
  * Creates an issue type and adds it to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.createType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-post
  * @param options Request options.
  */
    async createIssueType(options) {
        return this.Issue.Type.createType(options);
    }
    /**
  * Returns issue types for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.getTypesForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-project-get
  * @param options Request options.
  */
    async getIssueTypesForProject(options) {
        return this.Issue.Type.getTypesForProject(options);
    }
    /**
  * Returns an issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.getType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-get
  * @param options Request options.
  */
    async getIssueType(options) {
        return this.Issue.Type.getType(options);
    }
    /**
  * Updates the issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.updateType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-put
  * @param options Request options.
  */
    async updateIssueType(options) {
        return this.Issue.Type.updateType(options);
    }
    /**
  * Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.deleteType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-delete
  * @param options Request options.
  */
    async deleteIssueType(options) {
        return this.Issue.Type.deleteType(options);
    }
    /**
  * Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Issue.Type.getAlternativeTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-alternatives-get
  * @param options Request options.
  */
    async getAlternativeIssueTypes(options) {
        return this.Issue.Type.getAlternativeTypes(options);
    }
    /**
  * Loads an avatar for the issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Issue.Type.loadTypeAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-avatar2-post
  * @param options Request options.
  */
    async loadIssueTypeAvatar(options) {
        return this.Issue.Type.loadTypeAvatar(options);
    }
    /**
  * Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.
  
  Only company-managed projects associated with an issue type screen scheme are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.getProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
  * @param options Request options.
  */
    async getIssueTypeScreenSchemeProjects(options) {
        return this.Issue.Type.Screen.Scheme.getProjects(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-get
  * @param options Request options.
  */
    async getIssueTypeScreenSchemes(options) {
        return this.Issue.Type.Screen.Scheme.getSchemes(options);
    }
    /**
  * Creates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
  * @param options Request options.
  */
    async createIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.createScheme(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen scheme items.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.getSchemeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-mapping-get
  * @param options Request options.
  */
    async getIssueTypeScreenSchemeItems(options) {
        return this.Issue.Type.Screen.Scheme.getSchemeItems(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-get
  * @param options Request options.
  */
    async getIssueTypeScreenSchemesForProjects(options) {
        return this.Issue.Type.Screen.Scheme.getSchemesForProjects(options);
    }
    /**
  * Assigns an issue type screen scheme to a project.
  
  Issue type screen schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.assignSchemeToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
  * @param options Request options.
  */
    async assignIssueTypeScreenSchemeToProject(options) {
        return this.Issue.Type.Screen.Scheme.assignSchemeToProject(options);
    }
    /**
  * Updates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
  * @param options Request options.
  */
    async updateIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.updateScheme(options);
    }
    /**
  * Deletes an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
  * @param options Request options.
  */
    async deleteIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.deleteScheme(options);
    }
    /**
  * Appends issue type to screen scheme mappings to an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.appendMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
  * @param options Request options.
  */
    async appendMappingsToIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.appendMappings(options);
    }
    /**
  * Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.updateDefaultScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
  * @param options Request options.
  */
    async updateDefaultIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.updateDefaultScheme(options);
    }
    /**
  * Removes issue type to screen scheme mappings from an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Screen.Scheme.removeMappings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
  * @param options Request options.
  */
    async removeMappingsFromIssueTypeScreenScheme(options) {
        return this.Issue.Type.Screen.Scheme.removeMappings(options);
    }
    /**
  * Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
  * Alternative usage: Issue.Type.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-get
  * @param options Request options.
  */
    async getIssueTypePropertyKeys(options) {
        return this.Issue.Type.Property.getPropertyKeys(options);
    }
    /**
  * Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
  * Alternative usage: Issue.Type.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-get
  * @param options Request options.
  */
    async getIssueTypeProperty(options) {
        return this.Issue.Type.Property.getProperty(options);
    }
    /**
  * Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-put
  * @param options Request options.
  */
    async setIssueTypeProperty(options) {
        return this.Issue.Type.Property.setProperty(options);
    }
    /**
  * Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteIssueTypeProperty(options) {
        return this.Issue.Type.Property.deleteProperty(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type schemes.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-get
  * @param options Request options.
  */
    async getIssueTypeSchemes(options) {
        return this.Issue.Type.Scheme.getSchemes(options);
    }
    /**
  * Creates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
  * @param options Request options.
  */
    async createIssueTypeScheme(options) {
        return this.Issue.Type.Scheme.createScheme(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type scheme items.
  
  Only issue type scheme items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.getSchemeItems
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-mapping-get
  * @param options Request options.
  */
    async getIssueTypeSchemeItems(options) {
        return this.Issue.Type.Scheme.getSchemeItems(options);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.getSchemesForProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-get
  * @param options Request options.
  */
    async getIssueTypeSchemesForProjects(options) {
        return this.Issue.Type.Scheme.getSchemesForProjects(options);
    }
    /**
  * Assigns an issue type scheme to a project.
  
  If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.
  
  Issue type schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.assignToProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
  * @param options Request options.
  */
    async assignIssueTypeSchemeToProject(options) {
        return this.Issue.Type.Scheme.assignToProject(options);
    }
    /**
  * Adds issue types to an issue type scheme.
  
  The added issue types are appended to the issue types list.
  
  If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.addIssueTypesToScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
  * @param options Request options.
  */
    async addIssueTypesToIssueTypeScheme(options) {
        return this.Issue.Type.Scheme.addIssueTypesToScheme(options);
    }
    /**
  * Updates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
  * @param options Request options.
  */
    async updateIssueTypeScheme(options) {
        return this.Issue.Type.Scheme.updateScheme(options);
    }
    /**
  * Deletes an issue type scheme.
  
  Only issue type schemes used in classic projects can be deleted.
  
  Any projects assigned to the scheme are reassigned to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
  * @param options Request options.
  */
    async deleteIssueTypeScheme(options) {
        return this.Issue.Type.Scheme.deleteScheme(options);
    }
    /**
  * Changes the order of issue types in an issue type scheme.
  
  The request body parameters must meet the following requirements:
  
   *  all of the issue types must belong to the issue type scheme.
   *  either `after` or `position` must be provided.
   *  the issue type in `after` must not be in the issue type list.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.changeIssueTypesOrder
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
  * @param options Request options.
  */
    async changeIssueTypeSchemeIssueTypesOrder(options) {
        return this.Issue.Type.Scheme.changeIssueTypesOrder(options);
    }
    /**
  * Removes an issue type from an issue type scheme.
  
  This operation cannot remove:
  
   *  any issue type used by issues.
   *  any issue types from the default issue type scheme.
   *  the last standard issue type from an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Type.Scheme.removeIssueTypesFromScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
  * @param options Request options.
  */
    async removeIssueTypesFromIssueTypeScheme(options) {
        return this.Issue.Type.Scheme.removeIssueTypesFromScheme(options);
    }
    /**
  * Returns worklogs for an issue (ordered by created time), starting from the oldest worklog or from the worklog started on or after a date and time.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Workloads are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.getWorklogs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-get
  * @param options Request options.
  */
    async getIssueWorklogs(options) {
        return this.Issue.Worklog.getWorklogs(options);
    }
    /**
  * Adds a worklog to an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Worklog.addWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-post
  * @param options Request options.
  */
    async addIssueWorklog(options) {
        return this.Issue.Worklog.addWorklog(options);
    }
    /**
  * Returns a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.getWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-get
  * @param options Request options.
  */
    async getIssueWorklog(options) {
        return this.Issue.Worklog.getWorklog(options);
    }
    /**
  * Updates a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.updateWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-put
  * @param options Request options.
  */
    async updateIssueWorklog(options) {
        return this.Issue.Worklog.updateWorklog(options);
    }
    /**
  * Deletes a worklog from an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.deleteWorklog
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-delete
  * @param options Request options.
  */
    async deleteIssueWorklog(options) {
        return this.Issue.Worklog.deleteWorklog(options);
    }
    /**
  * Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs deleted during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Worklog.getDeletedIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-deleted-get
  * @param options Request options.
  */
    async getDeletedIssueWorklogIds(options) {
        return this.Issue.Worklog.getDeletedIds(options);
    }
    /**
  * Returns worklog details for a list of worklog IDs.
  
  The returned list of worklogs is limited to 1000 items.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Alternative usage: Issue.Worklog.getFromIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-list-post
  * @param options Request options.
  */
    async getIssueWorklogsFromIds(options) {
        return this.Issue.Worklog.getFromIds(options);
    }
    /**
  * Returns a list of IDs and update timestamps for worklogs updated after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs updated during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Alternative usage: Issue.Worklog.getUpdatedIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-updated-get
  * @param options Request options.
  */
    async getUpdatedIssueWorklogIds(options) {
        return this.Issue.Worklog.getUpdatedIds(options);
    }
    /**
  * Returns the keys of all properties for a worklog.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
  * @param options Request options.
  */
    async getWorklogPropertyKeys(options) {
        return this.Issue.Worklog.Property.getKeys(options);
    }
    /**
  * Returns the value of a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
  * @param options Request options.
  */
    async getWorklogProperty(options) {
        return this.Issue.Worklog.Property.getProperty(options);
    }
    /**
  * Sets the value of a worklog property. Use this operation to store custom data against the worklog.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
  * @param options Request options.
  */
    async setWorklogProperty(options) {
        return this.Issue.Worklog.Property.setProperty(options);
    }
    /**
  * Deletes a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Worklog.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteWorklogProperty(options) {
        return this.Issue.Worklog.Property.deleteProperty(options);
    }
    /**
  * Deletes an attachment from an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the project holding the issue containing the attachment:
  
   *  *Delete own attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by the calling user.
   *  *Delete all attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by any user.
  * Alternative usage: Issue.Attachment.deleteAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-delete
  * @param options Request options.
  */
    async deleteIssueAttachment(options) {
        return this.Issue.Attachment.deleteAttachment(options);
    }
    /**
  * Adds one or more attachments to an issue. Attachments are posted as multipart/form-data ([RFC 1867](https://www.ietf.org/rfc/rfc1867.txt)).
  
  Note that:
  
   *  The request must have a `X-Atlassian-Token: no-check` header, if not it is blocked. See [Special headers](#special-request-headers) for more information.
   *  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  The following examples upload a file called *myfile.txt* to the issue *TEST-123*:
  
  #### curl ####
  
      curl --location --request POST 'https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments'
       -u 'email@example.com:<api_token>'
       -H 'X-Atlassian-Token: no-check'
       --form 'file=@"myfile.txt"'
  
  #### Node.js ####
  
      // This code sample uses the 'node-fetch' and 'form-data' libraries:
       // https://www.npmjs.com/package/node-fetch
       // https://www.npmjs.com/package/form-data
       const fetch = require('node-fetch');
       const FormData = require('form-data');
       const fs = require('fs');
      
       const filePath = 'myfile.txt';
       const form = new FormData();
       const stats = fs.statSync(filePath);
       const fileSizeInBytes = stats.size;
       const fileStream = fs.createReadStream(filePath);
      
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       fetch('https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Authorization': `Basic ${Buffer.from(
                   'email@example.com:'
               ).toString('base64')}`,
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       })
           .then(response => {
               console.log(
                   `Response: ${response.status} ${response.statusText}`
               );
               return response.text();
           })
           .then(text => console.log(text))
           .catch(err => console.error(err));
  
  #### Java ####
  
      // This code sample uses the  'Unirest' library:
       // http://unirest.io/java.html
       HttpResponse response = Unirest.post("https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments")
               .basicAuth("email@example.com", "")
               .header("Accept", "application/json")
               .header("X-Atlassian-Token", "no-check")
               .field("file", new File("myfile.txt"))
               .asJson();
      
               System.out.println(response.getBody());
  
  #### Python ####
  
      # This code sample uses the 'requests' library:
       # http://docs.python-requests.org
       import requests
       from requests.auth import HTTPBasicAuth
       import json
      
       url = "https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments"
      
       auth = HTTPBasicAuth("email@example.com", "")
      
       headers = {
          "Accept": "application/json",
          "X-Atlassian-Token": "no-check"
       }
      
       response = requests.request(
          "POST",
          url,
          headers = headers,
          auth = auth,
          files = {
               "file": ("myfile.txt", open("myfile.txt","rb"), "application-type")
          }
       )
      
       print(json.dumps(json.loads(response.text), sort_keys=True, indent=4, separators=(",", ": ")))
  
  #### PHP ####
  
      // This code sample uses the 'Unirest' library:
       // http://unirest.io/php.html
       Unirest\Request::auth('email@example.com', '');
      
       $headers = array(
         'Accept' => 'application/json',
         'X-Atlassian-Token' => 'no-check'
       );
      
       $parameters = array(
         'file' => File::add('myfile.txt')
       );
      
       $response = Unirest\Request::post(
         'https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments',
         $headers,
         $parameters
       );
      
       var_dump($response)
  
  #### Forge ####
  
      // This sample uses Atlassian Forge and the `form-data` library.
       // https://developer.atlassian.com/platform/forge/
       // https://www.npmjs.com/package/form-data
       import api from "@forge/api";
       import FormData from "form-data";
      
       const form = new FormData();
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       const response = await api.asApp().requestJira('/rest/api/2/issue/{issueIdOrKey}/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       });
      
       console.log(`Response: ${response.status} ${response.statusText}`);
       console.log(await response.json());
  
  Tip: Use a client library. Many client libraries have classes for handling multipart POST operations. For example, in Java, the Apache HTTP Components library provides a [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html) class for multipart POST operations.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Create attachments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-attachments-post
  * @param options Request options.
  */
    async addIssueAttachments(options) {
        return this.Issue.Attachment.addAttachments(options);
    }
    /**
  * Returns the contents of an attachment. A `Range` header can be set to define a range of bytes within the attachment to download. See the [HTTP Range header standard](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Range) for details.
  
  To return a thumbnail of the attachment, use [Get attachment thumbnail](#api-rest-api-3-attachment-thumbnail-id-get).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Alternative usage: Issue.Attachment.getAttachmentContent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-content-id-get
  * @param options Request options.
  */
    async getIssueAttachmentContent(options) {
        return this.Issue.Attachment.getAttachmentContent(options);
    }
    /**
  * Returns the metadata for an attachment. Note that the attachment itself is not returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Alternative usage: Issue.Attachment.Metadata.getMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-get
  * @param options Request options.
  */
    async getIssueAttachmentMetadata(options) {
        return this.Issue.Attachment.Metadata.getMetadata(options);
    }
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.
  
  Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Alternative usage: Issue.Attachment.Metadata.getMetadataForExpandedAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-expand-human-get
  * @param options Request options.
  */
    async getMetadataForExpandedIssueAttachment(options) {
        return this.Issue.Attachment.Metadata.getMetadataForExpandedAttachment(options);
    }
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.
  
  Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Alternative usage: Issue.Attachment.Metadata.getContentsMetadataForExpandedAttachment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-expand-raw-get
  * @param options Request options.
  */
    async getContentsMetadataForExpandedIssueAttachment(options) {
        return this.Issue.Attachment.Metadata.getContentsMetadataForExpandedAttachment(options);
    }
    /**
  * Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are returned where the user:
  
   *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.getCommentsByIds
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-comment-list-post
  * @param options Request options.
  */
    async getIssueCommentsByIds(options) {
        return this.Issue.Comment.getCommentsByIds(options);
    }
    /**
  * Returns all comments for an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
  * Alternative usage: Issue.Comment.getComments
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-get
  * @param options Request options.
  */
    async getIssueComments(options) {
        return this.Issue.Comment.getComments(options);
    }
    /**
  * Adds a comment to an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Comment.addComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-post
  * @param options Request options.
  */
    async addIssueComment(options) {
        return this.Issue.Comment.addComment(options);
    }
    /**
  * Returns a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.getComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-get
  * @param options Request options.
  */
    async getIssueComment(options) {
        return this.Issue.Comment.getComment(options);
    }
    /**
  * Updates a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.updateComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-put
  * @param options Request options.
  */
    async updateIssueComment(options) {
        return this.Issue.Comment.updateComment(options);
    }
    /**
  * Deletes a comment.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.deleteComment
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-delete
  * @param options Request options.
  */
    async deleteIssueComment(options) {
        return this.Issue.Comment.deleteComment(options);
    }
    /**
  * Returns the keys of all the properties of a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-get
  * @param options Request options.
  */
    async getIssueCommentPropertyKeys(options) {
        return this.Issue.Comment.Property.getKeys(options);
    }
    /**
  * Returns the value of a comment property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Comment.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-get
  * @param options Request options.
  */
    async getIssueCommentProperty(options) {
        return this.Issue.Comment.Property.getProperty(options);
    }
    /**
  * Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Alternative usage: Issue.Comment.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-put
  * @param options Request options.
  */
    async setIssueCommentProperty(options) {
        return this.Issue.Comment.Property.setProperty(options);
    }
    /**
  * Deletes a comment property.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Alternative usage: Issue.Comment.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteIssueCommentProperty(options) {
        return this.Issue.Comment.Property.deleteProperty(options);
    }
    /**
  * Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
  
  Deprecated, see [Create Issue Meta Endpoint Deprecation Notice](https://developer.atlassian.com/cloud/jira/platform/changelog/#CHANGE-1304).
  
  The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
  * Alternative usage: Issue.Metadata.getCreateMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-createmeta-get
  * @param options Request options.
  */
    async getCreateIssueMetadata(options) {
        return this.Issue.Metadata.getCreateMetadata(options);
    }
    /**
  * Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).
  
  This endpoint will check for these conditions:
  
  1.  Field is available on a field screen - through screen, screen scheme, issue type screen scheme, and issue type scheme configuration. `overrideScreenSecurity=true` skips this condition.
  2.  Field is visible in the [field configuration](https://support.atlassian.com/jira-cloud-administration/docs/change-a-field-configuration/). `overrideScreenSecurity=true` skips this condition.
  3.  Field is shown on the issue: each field has different conditions here. For example: Attachment field only shows if attachments are enabled. Assignee only shows if user has permissions to assign the issue.
  4.  If a field is custom then it must have valid custom field context, applicable for its project and issue type. All system fields are assumed to have context in all projects and all issue types.
  5.  Issue has a project, issue type, and status defined.
  6.  Issue is assigned to a valid workflow, and the current status has assigned a workflow step. `overrideEditableFlag=true` skips this condition.
  7.  The current workflow step is editable. This is true by default, but [can be disabled by setting](https://support.atlassian.com/jira-cloud-administration/docs/use-workflow-properties/) the `jira.issue.editable` property to `false`. `overrideEditableFlag=true` skips this condition.
  8.  User has [Edit issues permission](https://support.atlassian.com/jira-cloud-administration/docs/permissions-for-company-managed-projects/).
  9.  Workflow permissions allow editing a field. This is true by default but [can be modified](https://support.atlassian.com/jira-cloud-administration/docs/use-workflow-properties/) using `jira.permission.*` workflow properties.
  
  Fields hidden using [Issue layout settings page](https://support.atlassian.com/jira-software-cloud/docs/configure-field-layout-in-the-issue-view/) remain editable.
  
  Connect apps having an app user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), can return additional details using:
  
   *  `overrideScreenSecurity` When this flag is `true`, then this endpoint skips checking if fields are available through screens, and field configuration (conditions 1. and 2. from the list above).
   *  `overrideEditableFlag` When this flag is `true`, then this endpoint skips checking if workflow is present and if the current step is editable (conditions 6. and 7. from the list above).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
  * Alternative usage: Issue.Metadata.getEditMetadata
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-editmeta-get
  * @param options Request options.
  */
    async getEditIssueMetadata(options) {
        return this.Issue.Metadata.getEditMetadata(options);
    }
    /**
  * Returns the URLs and keys of an issue's properties.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Property details are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Property.getKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-get
  * @param options Request options.
  */
    async getIssuePropertyKeys(options) {
        return this.Issue.Property.getKeys(options);
    }
    /**
  * Returns the key and value of an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-get
  * @param options Request options.
  */
    async getIssueProperty(options) {
        return this.Issue.Property.getProperty(options);
    }
    /**
  * Sets the value of an issue's property. Use this resource to store custom data against an issue.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-put
  * @param options Request options.
  */
    async setIssueProperty(options) {
        return this.Issue.Property.setProperty(options);
    }
    /**
  * Deletes an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteIssueProperty(options) {
        return this.Issue.Property.deleteProperty(options);
    }
    /**
  * Creates a link between two issues. Use this operation to indicate a relationship between two issues and optionally add a comment to the from (outward) issue. To use this resource the site must have [Issue Linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This resource returns nothing on the creation of an issue link. To obtain the ID of the issue link, use `https://your-domain.atlassian.net/rest/api/3/issue/[linked issue key]?fields=issuelinks`.
  
  If the link request duplicates a link, the response indicates that the issue link was created. If the request included a comment, the comment is added.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues to be linked,
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) on the project containing the from (outward) issue,
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Alternative usage: Issue.Link.createLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-post
  * @param options Request options.
  */
    async createIssueLink(options) {
        return this.Issue.Link.createLink(options);
    }
    /**
  * Returns an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the linked issues.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Alternative usage: Issue.Link.getLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-linkid-get
  * @param options Request options.
  */
    async getIssueLink(options) {
        return this.Issue.Link.getLink(options);
    }
    /**
  * Deletes an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  Browse project [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues in the link.
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one of the projects containing issues in the link.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Alternative usage: Issue.Link.deleteLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-linkid-delete
  * @param options Request options.
  */
    async deleteIssueLink(options) {
        return this.Issue.Link.deleteLink(options);
    }
    /**
  * Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.getLinks
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-get
  * @param options Request options.
  */
    async getRemoteIssueLinks(options) {
        return this.Issue.Link.Remote.getLinks(options);
    }
    /**
  * Creates or updates a remote issue link for an issue.
  
  If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.createOrUpdateLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-post
  * @param options Request options.
  */
    async createOrUpdateRemoteIssueLink(options) {
        return this.Issue.Link.Remote.createOrUpdateLink(options);
    }
    /**
  * Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.deleteLinkByGlobalId
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-delete
  * @param options Request options.
  */
    async deleteRemoteIssueLinkByGlobalId(options) {
        return this.Issue.Link.Remote.deleteLinkByGlobalId(options);
    }
    /**
  * Returns a remote issue link for an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.getLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-get
  * @param options Request options.
  */
    async getRemoteIssueLink(options) {
        return this.Issue.Link.Remote.getLink(options);
    }
    /**
  * Updates a remote issue link for an issue.
  
  Note: Fields without values in the request are set to null.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.updateLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-put
  * @param options Request options.
  */
    async updateRemoteIssueLink(options) {
        return this.Issue.Link.Remote.updateLink(options);
    }
    /**
  * Deletes a remote issue link from an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Link.Remote.deleteLink
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-delete
  * @param options Request options.
  */
    async deleteRemoteIssueLink(options) {
        return this.Issue.Link.Remote.deleteLink(options);
    }
    /**
  * Returns a list of all issue link types.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Alternative usage: Issue.Link.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-get
  * @param options Request options.
  */
    async getIssueLinkTypes(options) {
        return this.Issue.Link.Type.getTypes(options);
    }
    /**
  * Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Link.Type.createType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-post
  * @param options Request options.
  */
    async createIssueLinkType(options) {
        return this.Issue.Link.Type.createType(options);
    }
    /**
  * Returns an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Alternative usage: Issue.Link.Type.getType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-get
  * @param options Request options.
  */
    async getIssueLinkType(options) {
        return this.Issue.Link.Type.getType(options);
    }
    /**
  * Updates an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Link.Type.updateType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-put
  * @param options Request options.
  */
    async updateIssueLinkType(options) {
        return this.Issue.Link.Type.updateType(options);
    }
    /**
  * Deletes an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Link.Type.deleteType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-delete
  * @param options Request options.
  */
    async deleteIssueLinkType(options) {
        return this.Issue.Link.Type.deleteType(options);
    }
    /**
  * Returns either all transitions or a transition that can be performed by the user on an issue, based on the issue's status.
  
  Note, if a request is made for a transition that does not exist or cannot be performed on the issue, given its status, the response will return any empty transitions list.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required: A list or transition is returned only when the user has:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  However, if the user does not have the *Transition issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) the response will not list any transitions.
  * Alternative usage: Issue.Transition.getTransitions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-transitions-get
  * @param options Request options.
  */
    async getIssueTransitions(options) {
        return this.Issue.Transition.getTransitions(options);
    }
    /**
  * Performs an issue transition and, if the transition has a screen, updates the fields from the transition screen.
  
  sortByCategory To update the fields on the transition screen, specify the fields in the `fields` or `update` parameters in the request body. Get details about the fields using [ Get transitions](#api-rest-api-3-issue-issueIdOrKey-transitions-get) with the `transitions.fields` expand.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Transition issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Transition.performTransition
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-transitions-post
  * @param options Request options.
  */
    async performIssueTransition(options) {
        return this.Issue.Transition.performTransition(options);
    }
    /**
  * Returns details about the votes on an issue.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
  * Alternative usage: Issue.Vote.getVotes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-get
  * @param options Request options.
  */
    async getIssueVotes(options) {
        return this.Issue.Vote.getVotes(options);
    }
    /**
  * Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Vote.addVote
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-post
  * @param options Request options.
  */
    async addIssueVote(options) {
        return this.Issue.Vote.addVote(options);
    }
    /**
  * Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Vote.deleteVote
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-delete
  * @param options Request options.
  */
    async deleteIssueVote(options) {
        return this.Issue.Vote.deleteVote(options);
    }
    /**
  * Returns the watchers for an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Alternative usage: Issue.Watcher.getWatchers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-get
  * @param options Request options.
  */
    async getIssueWatchers(options) {
        return this.Issue.Watcher.getWatchers(options);
    }
    /**
  * Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Alternative usage: Issue.Watcher.addWatcher
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-post
  * @param options Request options.
  */
    async addIssueWatcher(options) {
        return this.Issue.Watcher.addWatcher(options);
    }
    /**
  * Deletes a user as a watcher of an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Alternative usage: Issue.Watcher.deleteWatcher
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-delete
  * @param options Request options.
  */
    async deleteIssueWatcher(options) {
        return this.Issue.Watcher.deleteWatcher(options);
    }
    /**
  * Checks whether one or more issues would be returned by one or more JQL queries.
  
  **[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Search.checkAgainstJql
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-jql-match-post
  * @param options Request options.
  */
    async checkIssuesAgainstJql(options) {
        return this.Issue.Search.checkAgainstJql(options);
    }
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
  
  There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Search.searchByJql
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-search-get
  * @param options Request options.
  * @deprecated
  */
    async searchIssuesByJql(options) {
        return this.Issue.Search.searchByJql(options);
    }
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ). Recent updates might not be immediately visible in the returned search results. If you need [read-after-write](https://developer.atlassian.com/cloud/jira/platform/search-and-reconcile/) consistency, you can utilize the `reconcileIssues` parameter to ensure stronger consistency assurances. This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Alternative usage: Issue.Search.searchByJqlEnhancedSearch
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-search-jql-post
  * @param options Request options.
  */
    async searchIssuesByJqlEnhancedSearch(options) {
        return this.Issue.Search.searchByJqlEnhancedSearch(options);
    }
    /**
  * Returns a list of all issue resolution values.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Resolution.getResolutions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-resolutions/#api-rest-api-3-resolution-get
  * @param options Request options.
  * @deprecated
  */
    async getIssueResolutions(options) {
        return this.Issue.Resolution.getResolutions(options);
    }
    /**
  * Returns an issue resolution value.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Issue.Resolution.getResolution
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-resolutions/#api-rest-api-3-resolution-id-get
  * @param options Request options.
  */
    async getIssueResolution(options) {
        return this.Issue.Resolution.getResolution(options);
    }
    /**
  * Returns issue security level members.
  
  Only issue security level members in context of classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Security.getMembers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-issuesecurityschemes-issuesecurityschemeid-members-get
  * @param options Request options.
  */
    async getIssueSecurityMembers(options) {
        return this.Issue.Security.getMembers(options);
    }
    /**
  * Returns details of an issue security level.
  
  Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Issue.Security.getLevel
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
  * @param options Request options.
  */
    async getIssueSecurityLevel(options) {
        return this.Issue.Security.getLevel(options);
    }
    /**
  * Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Security.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
  * @param options Request options.
  */
    async getIssueSecuritySchemes(options) {
        return this.Issue.Security.Scheme.getSchemes(options);
    }
    /**
  * Returns an issue security scheme along with its security levels.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
  * Alternative usage: Issue.Security.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
  * @param options Request options.
  */
    async getIssueSecurityScheme(options) {
        return this.Issue.Security.Scheme.getScheme(options);
    }
    /**
  * Returns a [paginated](#pagination) list of [notification schemes](https://confluence.atlassian.com/x/8YdKLg) ordered by the display name.
  
  *Note that you should allow for events without recipients to appear in responses.*
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user must have permission to administer at least one project associated with a notification scheme for it to be returned.
  * Alternative usage: Issue.Notification.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-get
  * @param options Request options.
  */
    async getIssueNotificationSchemes(options) {
        return this.Issue.Notification.Scheme.getSchemes(options);
    }
    /**
  * Returns a [notification scheme](https://confluence.atlassian.com/x/8YdKLg), including the list of events and the recipients who will receive notifications for those events.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user must have permission to administer at least one project associated with the notification scheme.
  * Alternative usage: Issue.Notification.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-id-get
  * @param options Request options.
  */
    async getIssueNotificationScheme(options) {
        return this.Issue.Notification.Scheme.getScheme(options);
    }
    /**
  * Returns the default issue navigator columns.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Navigator.getDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-get
  * @param options Request options.
  */
    async getIssueNavigatorDefaultColumns(options) {
        return this.Issue.Navigator.getDefaultColumns(options);
    }
    /**
  * Sets the default issue navigator columns.
  
  The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`
  
  If no column details are sent, then all default columns are removed.
  
  A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Issue.Navigator.setDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-put
  * @param options Request options.
  */
    async setIssueNavigatorDefaultColumns(options) {
        return this.Issue.Navigator.setDefaultColumns(options);
    }
    /**
  * Returns the default project, issue type or priority avatar image.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Avatar.getImageByType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-get
  * @param options Request options.
  */
    async getAvatarImageByType(options) {
        return this.Avatar.getImageByType(options);
    }
    /**
  * Returns a project, issue type or priority avatar image by ID.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  For system avatars, none.
   *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  For priority avatars, none.
  * Alternative usage: Avatar.getImageById
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-avatar-id-get
  * @param options Request options.
  */
    async getAvatarImageById(options) {
        return this.Avatar.getImageById(options);
    }
    /**
  * Returns the avatar image for a project, issue type or priority.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  For system avatars, none.
   *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  For priority avatars, none.
  * Alternative usage: Avatar.getImageByOwner
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-owner-entityid-get
  * @param options Request options.
  */
    async getAvatarImageByOwner(options) {
        return this.Avatar.getImageByOwner(options);
    }
    /**
  * Returns the system and custom avatars for a project, issue type or priority.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  for custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  for custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  for system avatars, none.
   *  for priority avatars, none.
  * Alternative usage: Avatar.getAvatars
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-get
  * @param options Request options.
  */
    async getAvatars(options) {
        return this.Avatar.getAvatars(options);
    }
    /**
  * Loads a custom avatar for a project or issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/universal_avatar/type/{type}/owner/{entityId}'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use:
  
   *  [Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
   *  [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Recommended usage: Avatar.loadAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-post
  * @param options Request options.
  */
    async loadAvatar(options) {
        return this.Avatar.loadAvatar(options);
    }
    /**
  * Deletes an avatar from a project, issue type or priority.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Avatar.deleteAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-owningobjectid-avatar-id-delete
  * @param options Request options.
  */
    async deleteAvatar(options) {
        return this.Avatar.deleteAvatar(options);
    }
    /**
  * Deletes a project asynchronously.
  
  This operation is:
  
   *  transactional, that is, if part of the delete fails the project is not deleted.
   *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.deleteProjectAsync
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-delete-post
  * @param options Request options.
  */
    async deleteProjectAsync(options) {
        return this.Project.deleteProjectAsync(options);
    }
    /**
  * Restores a project that has been archived or placed in the Jira recycle bin.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)for Company managed projects.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project for Team managed projects.
  * Alternative usage: Project.restoreDeletedProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-restore-post
  * @param options Request options.
  */
    async restoreDeletedProject(options) {
        return this.Project.restoreDeletedProject(options);
    }
    /**
  * Creates a project based on a project type template, as shown in the following table:
  
  | Project Type Key | Project Template Key |
  |--|--|
  | `business` | `com.atlassian.jira-core-project-templates:jira-core-simplified-content-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval`, `com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking`, `com.atlassian.jira-core-project-templates:jira-core-simplified-process-control`, `com.atlassian.jira-core-project-templates:jira-core-simplified-procurement`, `com.atlassian.jira-core-project-templates:jira-core-simplified-project-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment`, `com.atlassian.jira-core-project-templates:jira-core-simplified-task-tracking` |
  | `service_desk` | `com.atlassian.servicedesk:simplified-it-service-management`, `com.atlassian.servicedesk:simplified-general-service-desk-it`, `com.atlassian.servicedesk:simplified-general-service-desk-business`, `com.atlassian.servicedesk:simplified-external-service-desk`, `com.atlassian.servicedesk:simplified-hr-service-desk`, `com.atlassian.servicedesk:simplified-facilities-service-desk`, `com.atlassian.servicedesk:simplified-legal-service-desk`, `com.atlassian.servicedesk:simplified-analytics-service-desk`, `com.atlassian.servicedesk:simplified-marketing-service-desk`, `com.atlassian.servicedesk:simplified-design-service-desk`, `com.atlassian.servicedesk:simplified-sales-service-desk`, `com.atlassian.servicedesk:simplified-blank-project-business`, `com.atlassian.servicedesk:simplified-blank-project-it`, `com.atlassian.servicedesk:simplified-finance-service-desk`, `com.atlassian.servicedesk:next-gen-it-service-desk`, `com.atlassian.servicedesk:next-gen-hr-service-desk`, `com.atlassian.servicedesk:next-gen-legal-service-desk`, `com.atlassian.servicedesk:next-gen-marketing-service-desk`, `com.atlassian.servicedesk:next-gen-facilities-service-desk`, `com.atlassian.servicedesk:next-gen-general-it-service-desk`, `com.atlassian.servicedesk:next-gen-general-business-service-desk`, `com.atlassian.servicedesk:next-gen-analytics-service-desk`, `com.atlassian.servicedesk:next-gen-finance-service-desk`, `com.atlassian.servicedesk:next-gen-design-service-desk`, `com.atlassian.servicedesk:next-gen-sales-service-desk` |
  | `software` | `com.pyxis.greenhopper.jira:gh-simplified-agility-kanban`, `com.pyxis.greenhopper.jira:gh-simplified-agility-scrum`, `com.pyxis.greenhopper.jira:gh-simplified-basic`, `com.pyxis.greenhopper.jira:gh-simplified-kanban-classic`, `com.pyxis.greenhopper.jira:gh-simplified-scrum-classic` |
  The project types are available according to the installed Jira features as follows:
  
   *  Jira Core, the default, enables `business` projects.
   *  Jira Service Management enables `service_desk` projects.
   *  Jira Software enables `software` projects.
  
  To determine which features are installed, go to **Jira settings** > **Apps** > **Manage apps** and review the System Apps list. To add Jira Software or Jira Service Management into a JIRA instance, use **Jira settings** > **Apps** > **Finding new apps**. For more information, see [ Managing add-ons](https://confluence.atlassian.com/x/S31NLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.createProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-post
  * @param options Request options.
  */
    async createProject(options) {
        return this.Project.createProject(options);
    }
    /**
  * Returns a [paginated](#pagination) list of projects visible to the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.getProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-search-get
  * @param options Request options.
  */
    async getProjects(options) {
        return this.Project.getProjects(options);
    }
    /**
  * Returns the [project details](https://confluence.atlassian.com/x/ahLpNw) for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.getProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-get
  * @param options Request options.
  */
    async getProject(options) {
        return this.Project.getProject(options);
    }
    /**
  * Updates the [project details](https://confluence.atlassian.com/x/ahLpNw) of a project.
  
  All parameters are optional in the body of the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.updateProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-put
  * @param options Request options.
  */
    async updateProject(options) {
        return this.Project.updateProject(options);
    }
    /**
  * Deletes a project.
  
  You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.deleteProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-delete
  * @param options Request options.
  */
    async deleteProject(options) {
        return this.Project.deleteProject(options);
    }
    /**
  * Returns the valid statuses for a project. The statuses are grouped by issue type, as each project has a set of valid issue types and each issue type has a set of valid statuses.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.getStatuses
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-statuses-get
  * @param options Request options.
  */
    async getStatusesForProject(options) {
        return this.Project.getStatuses(options);
    }
    /**
  * Sets the avatar displayed for a project.
  
  Use [Load project avatar](#api-rest-api-3-project-projectIdOrKey-avatar2-post) to store avatars against the project, before using this operation to set the displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: Project.Avatar.setAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar-put
  * @param options Request options.
  */
    async setProjectAvatar(options) {
        return this.Project.Avatar.setAvatar(options);
    }
    /**
  * Deletes a custom avatar from a project. Note that system avatars cannot be deleted.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: Project.Avatar.deleteAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar-id-delete
  * @param options Request options.
  */
    async deleteProjectAvatar(options) {
        return this.Project.Avatar.deleteAvatar(options);
    }
    /**
  * Loads an avatar for a project.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/project/{projectIdOrKey}/avatar2'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Recommended usage: Project.Avatar.loadAvatar
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar2-post
  * @param options Request options.
  */
    async loadProjectAvatar(options) {
        return this.Project.Avatar.loadAvatar(options);
    }
    /**
  * Returns all project avatars, grouped by system and custom avatars.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Avatar.getAvatars
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatars-get
  * @param options Request options.
  */
    async getProjectAvatars(options) {
        return this.Project.Avatar.getAvatars(options);
    }
    /**
  * Creates a component. Use components to provide containers for issues within a project. Use components to provide containers for issues within a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Component.createComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-post
  * @param options Request options.
  */
    async createProjectComponent(options) {
        return this.Project.Component.createComponent(options);
    }
    /**
  * Returns a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
  * Alternative usage: Project.Component.getComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-get
  * @param options Request options.
  */
    async getProjectComponent(options) {
        return this.Project.Component.getComponent(options);
    }
    /**
  * Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Component.updateComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-put
  * @param options Request options.
  */
    async updateProjectComponent(options) {
        return this.Project.Component.updateComponent(options);
    }
    /**
  * Deletes a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Component.deleteComponent
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-delete
  * @param options Request options.
  */
    async deleteProjectComponent(options) {
        return this.Project.Component.deleteComponent(options);
    }
    /**
  * Returns the counts of issues assigned to the component.
  
  This operation can be accessed anonymously.
  
  **Deprecation notice:** The required OAuth 2.0 scopes will be updated on June 15, 2024.
  
   *  **Classic**: `read:jira-work`
   *  **Granular**: `read:field:jira`, `read:project.component:jira`
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Component.getIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-relatedissuecounts-get
  * @param options Request options.
  */
    async getProjectComponentIssueCount(options) {
        return this.Project.Component.getIssueCount(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.
  
  If your project uses Compass components, this API will return a list of Compass components that are linked to issues in that project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Component.getComponentsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-project-projectidorkey-component-get
  * @param options Request options.
  */
    async getProjectComponentsPaginated(options) {
        return this.Project.Component.getComponentsPaginated(options);
    }
    /**
  * Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.
  
  If your project uses Compass components, this API will return a paginated list of Compass components that are linked to issues in that project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Component.getComponents
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-project-projectidorkey-components-get
  * @param options Request options.
  */
    async getProjectComponents(options) {
        return this.Project.Component.getComponents(options);
    }
    /**
  * Returns a list of [project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) for the project returning the name and self URL for each role.
  
  Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.getRolesForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-role-get
  * @param options Request options.
  */
    async getProjectRolesForProject(options) {
        return this.Project.Role.getRolesForProject(options);
    }
    /**
  * Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.
  
  To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.getRoleForProject
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-role-id-get
  * @param options Request options.
  */
    async getProjectRoleForProject(options) {
        return this.Project.Role.getRoleForProject(options);
    }
    /**
  * Returns all [project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) and the details for each role. Note that the list of project roles is common to all projects.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Role.getDetails
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-roledetails-get
  * @param options Request options.
  */
    async getProjectRoleDetails(options) {
        return this.Project.Role.getDetails(options);
    }
    /**
  * Gets a list of all project roles, complete with project role details and default actors.
  
  ### About project roles ###
  
  [Project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).
  
  Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.
  
  #### Members and actors ####
  
  In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.
  
  Actors may be set as [default members](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/#Specifying-'default-members'-for-a-project-role) of the project role or set at the project level:
  
   *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
   *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.getRoles
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-get
  * @param options Request options.
  */
    async getProjectRoles(options) {
        return this.Project.Role.getRoles(options);
    }
    /**
  * Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.
  
  *Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.createRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-post
  * @param options Request options.
  */
    async createProjectRole(options) {
        return this.Project.Role.createRole(options);
    }
    /**
  * Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.getRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-get
  * @param options Request options.
  */
    async getProjectRole(options) {
        return this.Project.Role.getRole(options);
    }
    /**
  * Updates the project role's name and description. You must include both a name and a description in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.fullyUpdateRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-put
  * @param options Request options.
  */
    async fullyUpdateProjectRole(options) {
        return this.Project.Role.fullyUpdateRole(options);
    }
    /**
  * Updates either the project role's name or its description.
  
  You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.partiallyUpdateRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-post
  * @param options Request options.
  */
    async partiallyUpdateProjectRole(options) {
        return this.Project.Role.partiallyUpdateRole(options);
    }
    /**
  * Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.deleteRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-delete
  * @param options Request options.
  */
    async deleteProjectRole(options) {
        return this.Project.Role.deleteRole(options);
    }
    /**
  * Sets the actors for a project role for a project, replacing all existing actors.
  
  To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.setActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-put
  * @param options Request options.
  */
    async setActorsForProjectRole(options) {
        return this.Project.Role.Actor.setActors(options);
    }
    /**
  * Adds actors to a project role for the project.
  
  To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.addActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-post
  * @param options Request options.
  */
    async addActorsToProjectRole(options) {
        return this.Project.Role.Actor.addActors(options);
    }
    /**
  * Deletes actors from a project role for the project.
  
  To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.deleteActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-delete
  * @param options Request options.
  */
    async deleteActorsFromProjectRole(options) {
        return this.Project.Role.Actor.deleteActors(options);
    }
    /**
  * Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.Default.getActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-get
  * @param options Request options.
  */
    async getDefaultActorsForProjectRole(options) {
        return this.Project.Role.Actor.Default.getActors(options);
    }
    /**
  * Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.Default.addActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-post
  * @param options Request options.
  */
    async addDefaultActorsToProjectRole(options) {
        return this.Project.Role.Actor.Default.addActors(options);
    }
    /**
  * Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Role.Actor.Default.deleteActors
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-delete
  * @param options Request options.
  */
    async deleteDefaultActorsFromProjectRole(options) {
        return this.Project.Role.Actor.Default.deleteActors(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Version.getVersionsPaginated
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-project-projectidorkey-version-get
  * @param options Request options.
  */
    async getProjectVersionsPaginated(options) {
        return this.Project.Version.getVersionsPaginated(options);
    }
    /**
  * Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Version.getVersions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-project-projectidorkey-versions-get
  * @param options Request options.
  */
    async getProjectVersions(options) {
        return this.Project.Version.getVersions(options);
    }
    /**
  * Creates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
  * Alternative usage: Project.Version.createVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-post
  * @param options Request options.
  */
    async createProjectVersion(options) {
        return this.Project.Version.createVersion(options);
    }
    /**
  * Returns a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
  * Alternative usage: Project.Version.getVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-get
  * @param options Request options.
  */
    async getProjectVersion(options) {
        return this.Project.Version.getVersion(options);
    }
    /**
  * Updates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Alternative usage: Project.Version.updateVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-put
  * @param options Request options.
  */
    async updateProjectVersion(options) {
        return this.Project.Version.updateVersion(options);
    }
    /**
  * Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.
  
  Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Alternative usage: Project.Version.mergeVersions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-mergeto-moveissuesto-put
  * @param options Request options.
  */
    async mergeProjectVersions(options) {
        return this.Project.Version.mergeVersions(options);
    }
    /**
  * Modifies the version's sequence within the project, which affects the display order of the versions in Jira.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Alternative usage: Project.Version.moveVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-move-post
  * @param options Request options.
  */
    async moveProjectVersion(options) {
        return this.Project.Version.moveVersion(options);
    }
    /**
  * Deletes a project version.
  
  Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Alternative usage: Project.Version.deleteAndReplaceVersion
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-removeandswap-post
  * @param options Request options.
  */
    async deleteAndReplaceProjectVersion(options) {
        return this.Project.Version.deleteAndReplaceVersion(options);
    }
    /**
  * Returns the following counts for a version:
  
   *  Number of issues where the `fixVersion` is set to the version.
   *  Number of issues where the `affectedVersion` is set to the version.
   *  Number of issues where a version custom field is set to the version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Alternative usage: Project.Version.Count.getRelatedIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-relatedissuecounts-get
  * @param options Request options.
  */
    async getProjectVersionRelatedIssueCount(options) {
        return this.Project.Version.Count.getRelatedIssueCount(options);
    }
    /**
  * Returns counts of the issues and unresolved issues for the project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Alternative usage: Project.Version.Count.getUnresolvedIssueCount
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-unresolvedissuecount-get
  * @param options Request options.
  */
    async getProjectVersionUnresolvedIssueCount(options) {
        return this.Project.Version.Count.getUnresolvedIssueCount(options);
    }
    /**
  * Get the issue type hierarchy for a next-gen project.
  
  The issue type hierarchy for a project consists of:
  
   *  *Epic* at level 1 (optional).
   *  One or more issue types at level 0 such as *Story*, *Task*, or *Bug*. Where the issue type *Epic* is defined, these issue types are used to break down the content of an epic.
   *  *Subtask* at level -1 (optional). This issue type enables level 0 issue types to be broken down into components. Issues based on a level -1 issue type must have a parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.IssueType.getHierarchy
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectid-hierarchy-get
  * @param options Request options.
  * @deprecated
  */
    async getProjectIssueTypeHierarchy(options) {
        return this.Project.IssueType.getHierarchy(options);
    }
    /**
  * Validates a project key by confirming the key is a valid string and not in use.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Validation.validateProjectKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-key-get
  * @param options Request options.
  */
    async validateProjectKey(options) {
        return this.Project.Validation.validateProjectKey(options);
    }
    /**
  * Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Validation.getValidProjectKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-validprojectkey-get
  * @param options Request options.
  */
    async getValidProjectKey(options) {
        return this.Project.Validation.getValidProjectKey(options);
    }
    /**
  * Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Validation.getValidProjectName
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-validprojectname-get
  * @param options Request options.
  */
    async getValidProjectName(options) {
        return this.Project.Validation.getValidProjectName(options);
    }
    /**
  * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Type.getTypes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
  * @param options Request options.
  */
    async getProjectTypes(options) {
        return this.Project.Type.getTypes(options);
    }
    /**
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
     * Alternative usage: Project.Type.getLicensedTypes
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
     * @param options Request options.
     */
    async getLicensedProjectTypes(options) {
        return this.Project.Type.getLicensedTypes(options);
    }
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Project.Type.getTypeByKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
  * @param options Request options.
  */
    async getProjectTypeByKey(options) {
        return this.Project.Type.getTypeByKey(options);
    }
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Project.Type.getAccessibleTypeByKey
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
  * @param options Request options.
  */
    async getAccessibleProjectTypeByKey(options) {
        return this.Project.Type.getAccessibleTypeByKey(options);
    }
    /**
  * Returns all project categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Project.Category.getCategories
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-get
  * @param options Request options.
  */
    async getProjectCategories(options) {
        return this.Project.Category.getCategories(options);
    }
    /**
  * Creates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Category.createCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-post
  * @param options Request options.
  */
    async createProjectCategory(options) {
        return this.Project.Category.createCategory(options);
    }
    /**
  * Returns a project category.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Project.Category.getCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-get
  * @param options Request options.
  */
    async getProjectCategory(options) {
        return this.Project.Category.getCategory(options);
    }
    /**
  * Updates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Category.updateCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-put
  * @param options Request options.
  */
    async updateProjectCategory(options) {
        return this.Project.Category.updateCategory(options);
    }
    /**
  * Deletes a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Project.Category.deleteCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-delete
  * @param options Request options.
  */
    async deleteProjectCategory(options) {
        return this.Project.Category.deleteCategory(options);
    }
    /**
  * Gets a [notification scheme](https://confluence.atlassian.com/x/8YdKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: Project.Notification.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectkeyorid-notificationscheme-get
  * @param options Request options.
  * @deprecated
  */
    async getProjectNotificationScheme(options) {
        return this.Project.Notification.Scheme.getScheme(options);
    }
    /**
  * Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
  * Alternative usage: Project.Permission.Scheme.assignScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
  * @param options Request options.
  */
    async assignProjectPermissionScheme(options) {
        return this.Project.Permission.Scheme.assignScheme(options);
    }
    /**
  * Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: Project.Permission.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
  * @param options Request options.
  */
    async getProjectPermissionScheme(options) {
        return this.Project.Permission.Scheme.getScheme(options);
    }
    /**
  * Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
  * Alternative usage: Project.Permission.Scheme.getIssueSecurityLevels
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
  * @param options Request options.
  */
    async getProjectIssueSecurityLevels(options) {
        return this.Project.Permission.Scheme.getIssueSecurityLevels(options);
    }
    /**
  * Returns the [issue security scheme](https://confluence.atlassian.com/x/J4lKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or the *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: Project.Security.Scheme.getIssueScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-issuesecuritylevelscheme-get
  * @param options Request options.
  */
    async getProjectIssueSecurityScheme(options) {
        return this.Project.Security.Scheme.getIssueScheme(options);
    }
    /**
  * Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Alternative usage: Project.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
  * @param options Request options.
  */
    async getProjectPropertyKeys(options) {
        return this.Project.Property.getPropertyKeys(options);
    }
    /**
  * Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Alternative usage: Project.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
  * @param options Request options.
  */
    async getProjectProperty(options) {
        return this.Project.Property.getProperty(options);
    }
    /**
  * Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
  * Alternative usage: Project.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
  * @param options Request options.
  */
    async setProjectProperty(options) {
        return this.Project.Property.setProperty(options);
    }
    /**
  * Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Alternative usage: Project.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProjectProperty(options) {
        return this.Project.Property.deleteProperty(options);
    }
    /**
  * Returns a list of all users, including active users, inactive users and previously deleted users that have an Atlassian account.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: User.getUsersDefault
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-users-get
  * @param options Request options.
  */
    async getUsersDefault(options) {
        return this.User.getUsersDefault(options);
    }
    /**
  * Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
   *  Permission to access Jira, to get the calling user's column details.
  * Alternative usage: User.getDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
  * @param options Request options.
  */
    async getUserDefaultColumns(options) {
        return this.User.getDefaultColumns(options);
    }
    /**
  * Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Alternative usage: User.setDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
  * @param options Request options.
  */
    async setUserDefaultColumns(options) {
        return this.User.setDefaultColumns(options);
    }
    /**
  * Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Alternative usage: User.resetDefaultColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
  * @param options Request options.
  */
    async resetUserDefaultColumns(options) {
        return this.User.resetDefaultColumns(options);
    }
    /**
  * Returns a user.
  
  Privacy controls are applied to the response based on the user's preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: User.getUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-get
  * @param options Request options.
  */
    async getUser(options) {
        return this.User.getUser(options);
    }
    /**
  * Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.
  
  If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: User.createUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-post
  * @param options Request options.
  */
    async createUser(options) {
        return this.User.createUser(options);
    }
    /**
  * Deletes a user. If the operation completes successfully then the user is removed from Jira's user base. This operation does not delete the user's Atlassian account.
  
  **[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Alternative usage: User.deleteUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-delete
  * @param options Request options.
  */
    async deleteUser(options) {
        return this.User.deleteUser(options);
    }
    /**
  * Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: User.getAccountIdsForUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-bulk-migration-get
  * @param options Request options.
  */
    async getAccountIdsForUsers(options) {
        return this.User.getAccountIdsForUsers(options);
    }
    /**
     * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603). For Forge apps, this API only supports access via asApp() requests.
     * Alternative usage: User.getEmail
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-email-get
     * @param options Request options.
     */
    async getUserEmail(options) {
        return this.User.getEmail(options);
    }
    /**
  * Returns the groups to which a user belongs.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: User.getGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-groups-get
  * @param options Request options.
  */
    async getUserGroups(options) {
        return this.User.getGroups(options);
    }
    /**
  * Returns a list of all users, including active users, inactive users and previously deleted users that have an Atlassian account.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: User.getUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-users-search-get
  * @param options Request options.
  */
    async getUsers(options) {
        return this.User.getUsers(options);
    }
    /**
  * Returns a list of users who can be assigned issues in one or more projects. The list may be restricted to users whose attributes match a string.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned issues in the projects. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned issues in the projects, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: User.Search.findUsersAssignableToProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-assignable-multiprojectsearch-get
  * @param options Request options.
  */
    async findUsersAssignableToProjects(options) {
        return this.User.Search.findUsersAssignableToProjects(options);
    }
    /**
  * Returns a list of users that can be assigned to an issue. Use this operation to find the list of users who can be assigned to:
  
   *  a new issue, by providing the `projectKeyOrId`.
   *  an updated issue, by providing the `issueKey`.
   *  to an issue during a transition (workflow action), by providing the `issueKey` and the transition id in `actionDescriptorId`. You can obtain the IDs of an issue's valid transitions using the `transitions` option in the `expand` parameter of [ Get issue](#api-rest-api-3-issue-issueIdOrKey-get).
  
  In all these cases, you can pass an account ID to determine if a user can be assigned to an issue. The user is returned in the response if they can be assigned to the issue or issue transition.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned the issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned the issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: User.Search.findUsersAssignableToIssues
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-assignable-search-get
  * @param options Request options.
  */
    async findUsersAssignableToIssues(options) {
        return this.User.Search.findUsersAssignableToIssues(options);
    }
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have a set of permissions for a project or issue.
  
  If no search string is provided, a list of all users with the permissions is returned.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission for the project or issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission for the project or issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get users for any project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project, to get users for that project.
  * Alternative usage: User.Search.findUsersWithPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-permission-search-get
  * @param options Request options.
  */
    async findUsersWithPermissions(options) {
        return this.User.Search.findUsersWithPermissions(options);
    }
    /**
  * Returns a list of users whose attributes match the query term. The returned object includes the `html` field where the matched query term is highlighted with the HTML strong tag. A list of account IDs can be provided to exclude users from the results.
  
  This operation takes the users in the range defined by `maxResults`, up to the thousandth user, and then returns only the users from that range that match the query term. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the query term, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return search results for an exact name match only.
  * Alternative usage: User.Search.findUsersForPicker
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-picker-get
  * @param options Request options.
  */
    async findUsersForPicker(options) {
        return this.User.Search.findUsersForPicker(options);
    }
    /**
  * Returns a list of users that match the search string and property.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and property. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and property, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls or calls by users without the required permission return empty search results.
  * Alternative usage: User.Search.findUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-get
  * @param options Request options.
  */
    async findUsers(options) {
        return this.User.Search.findUsers(options);
    }
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user details.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value. For example, if user property `location` is set to value `{"office": {"country": "AU", "city": "Sydney"}}`, then it's possible to use `[location].office.city is "Sydney"` to match the user.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Alternative usage: User.Search.findUsersByQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-query-get
  * @param options Request options.
  */
    async findUsersByQuery(options) {
        return this.User.Search.findUsersByQuery(options);
    }
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user keys.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value. For example, if user property `location` is set to value `{"office": {"country": "AU", "city": "Sydney"}}`, then it's possible to use `[location].office.city is "Sydney"` to match the user.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Alternative usage: User.Search.findUserKeysByQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-query-key-get
  * @param options Request options.
  */
    async findUserKeysByQuery(options) {
        return this.User.Search.findUserKeysByQuery(options);
    }
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have permission to browse issues.
  
  Use this resource to find users who can browse:
  
   *  an issue, by providing the `issueKey`.
   *  any issue in a project, by providing the `projectKey`.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission to browse issues. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission to browse issues, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return empty search results.
  * Alternative usage: User.Search.findUsersWithBrowsePermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-viewissue-search-get
  * @param options Request options.
  */
    async findUsersWithBrowsePermission(options) {
        return this.User.Search.findUsersWithBrowsePermission(options);
    }
    /**
  * Returns the keys of all properties for a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
   *  Access to Jira, to access the calling user's property keys.
  * Alternative usage: User.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-get
  * @param options Request options.
  */
    async getUserPropertyKeys(options) {
        return this.User.Property.getPropertyKeys(options);
    }
    /**
  * Returns the value of a user's property.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
   *  Access to Jira, to get a property from the calling user's record.
  * Alternative usage: User.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-get
  * @param options Request options.
  */
    async getUserProperty(options) {
        return this.User.Property.getProperty(options);
    }
    /**
  * Sets the value of a user's property. Use this resource to store custom data against a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
   *  Access to Jira, to set a property on the calling user's record.
  * Alternative usage: User.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-put
  * @param options Request options.
  */
    async setUserProperty(options) {
        return this.User.Property.setProperty(options);
    }
    /**
  * Deletes a property from a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
   *  Access to Jira, to delete a property from the calling user's record.
  * Alternative usage: User.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteUserProperty(options) {
        return this.User.Property.deleteProperty(options);
    }
    /**
  * Creates a workflow. You can define transition rules using the shapes detailed in the following sections. If no transitional rules are specified the default system transition rules are used. Note: This only applies to company-managed scoped workflows. Use [bulk create workflows](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflows-create-post) to create both team and company-managed scoped workflows.
  
  #### Conditions ####
  
  Conditions enable workflow rules that govern whether a transition can execute.
  
  ##### Always false condition #####
  
  A condition that always fails.
  
      {
         "type": "AlwaysFalseCondition"
       }
  
  ##### Block transition until approval #####
  
  A condition that blocks issue transition if there is a pending approval.
  
      {
         "type": "BlockInProgressApprovalCondition"
       }
  
  ##### Compare number custom field condition #####
  
  A condition that allows transition if a comparison between a number custom field and a value is true.
  
      {
         "type": "CompareNumberCFCondition",
         "configuration": {
           "comparator": "=",
           "fieldId": "customfield_10029",
           "fieldValue": 2
         }
       }
  
   *  `comparator` One of the supported comparator: `=`, `>`, and `<`.
   *  `fieldId` The custom numeric field ID. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
       *  `com.pyxis.greenhopper.jira:jsw-story-points`
   *  `fieldValue` The value for comparison.
  
  ##### Hide from user condition #####
  
  A condition that hides a transition from users. The transition can only be triggered from a workflow function or REST API operation.
  
      {
         "type": "RemoteOnlyCondition"
       }
  
  ##### Only assignee condition #####
  
  A condition that allows only the assignee to execute a transition.
  
      {
         "type": "AllowOnlyAssignee"
       }
  
  ##### Only Bamboo notifications workflow condition (deprecated) #####
  
  A condition that makes the transition available only to Bamboo build notifications.
  
      {
         "type": "OnlyBambooNotificationsCondition"
       }
  
  ##### Only reporter condition #####
  
  A condition that allows only the reporter to execute a transition.
  
      {
         "type": "AllowOnlyReporter"
       }
  
  ##### Permission condition #####
  
  A condition that allows only users with a permission to execute a transition.
  
      {
         "type": "PermissionCondition",
         "configuration": {
             "permissionKey": "BROWSE_PROJECTS"
         }
       }
  
   *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
  
  ##### Previous status condition #####
  
  A condition that allows a transition based on whether an issue has or has not transitioned through a status.
  
      {
         "type": "PreviousStatusCondition",
         "configuration": {
           "ignoreLoopTransitions": true,
           "includeCurrentStatus": true,
           "mostRecentStatusOnly": true,
           "reverseCondition": true,
           "previousStatus": {
             "id": "5"
           }
         }
       }
  
  By default this condition allows the transition if the status, as defined by its ID in the `previousStatus` object, matches any previous issue status, unless:
  
   *  `ignoreLoopTransitions` is `true`, then loop transitions (from and to the same status) are ignored.
   *  `includeCurrentStatus` is `true`, then the current issue status is also checked.
   *  `mostRecentStatusOnly` is `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
   *  `reverseCondition` is `true`, then the status must not be present.
  
  ##### Separation of duties condition #####
  
  A condition that prevents a user to perform the transition, if the user has already performed a transition on the issue.
  
      {
         "type": "SeparationOfDutiesCondition",
         "configuration": {
           "fromStatus": {
             "id": "5"
           },
           "toStatus": {
             "id": "6"
           }
         }
       }
  
   *  `fromStatus` OPTIONAL. An object containing the ID of the source status of the transition that is blocked. If omitted any transition to `toStatus` is blocked.
   *  `toStatus` An object containing the ID of the target status of the transition that is blocked.
  
  ##### Subtask blocking condition #####
  
  A condition that blocks transition on a parent issue if any of its subtasks are in any of one or more statuses.
  
      {
         "type": "SubTaskBlockingCondition",
         "configuration": {
           "statuses": [
             {
               "id": "1"
             },
             {
               "id": "3"
             }
           ]
         }
       }
  
   *  `statuses` A list of objects containing status IDs.
  
  ##### User is in any group condition #####
  
  A condition that allows users belonging to any group from a list of groups to execute a transition.
  
      {
         "type": "UserInAnyGroupCondition",
         "configuration": {
           "groups": [
             "administrators",
             "atlassian-addons-admin"
           ]
         }
       }
  
   *  `groups` A list of group names.
  
  ##### User is in any project role condition #####
  
  A condition that allows only users with at least one project roles from a list of project roles to execute a transition.
  
      {
         "type": "InAnyProjectRoleCondition",
         "configuration": {
           "projectRoles": [
             {
               "id": "10002"
             },
             {
               "id": "10003"
             },
             {
               "id": "10012"
             },
             {
               "id": "10013"
             }
           ]
         }
       }
  
   *  `projectRoles` A list of objects containing project role IDs.
  
  ##### User is in custom field condition #####
  
  A condition that allows only users listed in a given custom field to execute the transition.
  
      {
         "type": "UserIsInCustomFieldCondition",
         "configuration": {
           "allowUserInField": false,
           "fieldId": "customfield_10010"
         }
       }
  
   *  `allowUserInField` If `true` only a user who is listed in `fieldId` can perform the transition, otherwise, only a user who is not listed in `fieldId` can perform the transition.
   *  `fieldId` The ID of the field containing the list of users.
  
  ##### User is in group condition #####
  
  A condition that allows users belonging to a group to execute a transition.
  
      {
         "type": "UserInGroupCondition",
         "configuration": {
           "group": "administrators"
         }
       }
  
   *  `group` The name of the group.
  
  ##### User is in group custom field condition #####
  
  A condition that allows users belonging to a group specified in a custom field to execute a transition.
  
      {
         "type": "InGroupCFCondition",
         "configuration": {
           "fieldId": "customfield_10012"
         }
       }
  
   *  `fieldId` The ID of the field. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:grouppicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
       *  `com.pyxis.greenhopper.jira:gh-epic-status`
  
  ##### User is in project role condition #####
  
  A condition that allows users with a project role to execute a transition.
  
      {
         "type": "InProjectRoleCondition",
         "configuration": {
           "projectRole": {
             "id": "10002"
           }
         }
       }
  
   *  `projectRole` An object containing the ID of a project role.
  
  ##### Value field condition #####
  
  A conditions that allows a transition to execute if the value of a field is equal to a constant value or simply set.
  
      {
         "type": "ValueFieldCondition",
         "configuration": {
           "fieldId": "assignee",
           "fieldValue": "qm:6e1ecee6-8e64-4db6-8c85-916bb3275f51:54b56885-2bd2-4381-8239-78263442520f",
           "comparisonType": "NUMBER",
           "comparator": "="
         }
       }
  
   *  `fieldId` The ID of a field used in the comparison.
   *  `fieldValue` The expected value of the field.
   *  `comparisonType` The type of the comparison. Allowed values: `STRING`, `NUMBER`, `DATE`, `DATE_WITHOUT_TIME`, or `OPTIONID`.
   *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, `!=`.
  
  **Notes:**
  
   *  If you choose the comparison type `STRING`, only `=` and `!=` are valid options.
   *  You may leave `fieldValue` empty when comparison type is `!=` to indicate that a value is required in the field.
   *  For date fields without time format values as `yyyy-MM-dd`, and for those with time as `yyyy-MM-dd HH:mm`. For example, for July 16 2021 use `2021-07-16`, for 8:05 AM use `2021-07-16 08:05`, and for 4 PM: `2021-07-16 16:00`.
  
  #### Validators ####
  
  Validators check that any input made to the transition is valid before the transition is performed.
  
  ##### Date field validator #####
  
  A validator that compares two dates.
  
      {
         "type": "DateFieldValidator",
         "configuration": {
             "comparator": ">",
             "date1": "updated",
             "date2": "created",
             "expression": "1d",
             "includeTime": true
           }
       }
  
   *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, or `!=`.
   *  `date1` The date field to validate. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `date2` The second date field. Required, if `expression` is not passed. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `expression` An expression specifying an offset. Required, if `date2` is not passed. Offsets are built with a number, with `-` as prefix for the past, and one of these time units: `d` for day, `w` for week, `m` for month, or `y` for year. For example, -2d means two days into the past and 1w means one week into the future. The `now` keyword enables a comparison with the current date.
   *  `includeTime` If `true`, then the time part of the data is included for the comparison. If the field doesn't have a time part, 00:00:00 is used.
  
  ##### Windows date validator #####
  
  A validator that checks that a date falls on or after a reference date and before or on the reference date plus a number of days.
  
      {
         "type": "WindowsDateValidator",
         "configuration": {
             "date1": "customfield_10009",
             "date2": "created",
             "windowsDays": 5
           }
       }
  
   *  `date1` The date field to validate. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `date2` The reference date. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `windowsDays` A positive integer indicating a number of days.
  
  ##### Field required validator #####
  
  A validator that checks fields are not empty. By default, if a field is not included in the current context it's ignored and not validated.
  
      {
           "type": "FieldRequiredValidator",
           "configuration": {
               "ignoreContext": true,
               "errorMessage": "Hey",
               "fieldIds": [
                   "versions",
                   "customfield_10037",
                   "customfield_10003"
               ]
           }
       }
  
   *  `ignoreContext` If `true`, then the context is ignored and all the fields are validated.
   *  `errorMessage` OPTIONAL. The error message displayed when one or more fields are empty. A default error message is shown if an error message is not provided.
   *  `fieldIds` The list of fields to validate.
  
  ##### Field changed validator #####
  
  A validator that checks that a field value is changed. However, this validation can be ignored for users from a list of groups.
  
      {
           "type": "FieldChangedValidator",
           "configuration": {
               "fieldId": "comment",
               "errorMessage": "Hey",
               "exemptedGroups": [
                   "administrators",
                   "atlassian-addons-admin"
               ]
           }
       }
  
   *  `fieldId` The ID of a field.
   *  `errorMessage` OPTIONAL. The error message displayed if the field is not changed. A default error message is shown if the error message is not provided.
   *  `exemptedGroups` OPTIONAL. The list of groups.
  
  ##### Field has single value validator #####
  
  A validator that checks that a multi-select field has only one value. Optionally, the validation can ignore values copied from subtasks.
  
      {
           "type": "FieldHasSingleValueValidator",
           "configuration": {
               "fieldId": "attachment,
               "excludeSubtasks": true
           }
       }
  
   *  `fieldId` The ID of a field.
   *  `excludeSubtasks` If `true`, then values copied from subtasks are ignored.
  
  ##### Parent status validator #####
  
  A validator that checks the status of the parent issue of a subtask. Ìf the issue is not a subtask, no validation is performed.
  
      {
           "type": "ParentStatusValidator",
           "configuration": {
               "parentStatuses": [
                   {
                     "id":"1"
                   },
                   {
                     "id":"2"
                   }
               ]
           }
       }
  
   *  `parentStatus` The list of required parent issue statuses.
  
  ##### Permission validator #####
  
  A validator that checks the user has a permission.
  
      {
         "type": "PermissionValidator",
         "configuration": {
             "permissionKey": "ADMINISTER_PROJECTS"
         }
       }
  
   *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
  
  ##### Previous status validator #####
  
  A validator that checks if the issue has held a status.
  
      {
         "type": "PreviousStatusValidator",
         "configuration": {
             "mostRecentStatusOnly": false,
             "previousStatus": {
                 "id": "15"
             }
         }
       }
  
   *  `mostRecentStatusOnly` If `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
   *  `previousStatus` An object containing the ID of an issue status.
  
  ##### Regular expression validator #####
  
  A validator that checks the content of a field against a regular expression.
  
      {
         "type": "RegexpFieldValidator",
         "configuration": {
             "regExp": "[0-9]",
             "fieldId": "customfield_10029"
         }
       }
  
   *  `regExp`A regular expression.
   *  `fieldId` The ID of a field. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:textarea`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:textfield`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:url`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
       *  `com.pyxis.greenhopper.jira:jsw-story-points`
       *  `com.pyxis.greenhopper.jira:gh-epic-status`
       *  `description`
       *  `summary`
  
  ##### User permission validator #####
  
  A validator that checks if a user has a permission. Obsolete. You may encounter this validator when getting transition rules and can pass it when updating or creating rules, for example, when you want to duplicate the rules from a workflow on a new workflow.
  
      {
           "type": "UserPermissionValidator",
           "configuration": {
               "permissionKey": "BROWSE_PROJECTS",
               "nullAllowed": false,
               "username": "TestUser"
           }
       }
  
   *  `permissionKey` The permission to be validated. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
   *  `nullAllowed` If `true`, allows the transition when `username` is empty.
   *  `username` The username to validate against the `permissionKey`.
  
  #### Post functions ####
  
  Post functions carry out any additional processing required after a Jira workflow transition is executed.
  
  ##### Fire issue event function #####
  
  A post function that fires an event that is processed by the listeners.
  
      {
         "type": "FireIssueEventFunction",
         "configuration": {
           "event": {
             "id":"1"
           }
         }
       }
  
  **Note:** If provided, this post function overrides the default `FireIssueEventFunction`. Can be included once in a transition.
  
   *  `event` An object containing the ID of the issue event.
  
  ##### Update issue status #####
  
  A post function that sets issue status to the linked status of the destination workflow status.
  
      {
         "type": "UpdateIssueStatusFunction"
       }
  
  **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
  
  ##### Create comment #####
  
  A post function that adds a comment entered during the transition to an issue.
  
      {
         "type": "CreateCommentFunction"
       }
  
  **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
  
  ##### Store issue #####
  
  A post function that stores updates to an issue.
  
      {
         "type": "IssueStoreFunction"
       }
  
  **Note:** This post function can only be added to the initial transition and can only be added once.
  
  ##### Assign to current user function #####
  
  A post function that assigns the issue to the current user if the current user has the `ASSIGNABLE_USER` permission.
  
      {
           "type": "AssignToCurrentUserFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Assign to lead function #####
  
  A post function that assigns the issue to the project or component lead developer.
  
      {
           "type": "AssignToLeadFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Assign to reporter function #####
  
  A post function that assigns the issue to the reporter.
  
      {
           "type": "AssignToReporterFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Clear field value function #####
  
  A post function that clears the value from a field.
  
      {
         "type": "ClearFieldValuePostFunction",
         "configuration": {
           "fieldId": "assignee"
         }
       }
  
   *  `fieldId` The ID of the field.
  
  ##### Copy value from other field function #####
  
  A post function that copies the value of one field to another, either within an issue or from parent to subtask.
  
      {
         "type": "CopyValueFromOtherFieldPostFunction",
         "configuration": {
           "sourceFieldId": "assignee",
           "destinationFieldId": "creator",
           "copyType": "same"
         }
       }
  
   *  `sourceFieldId` The ID of the source field.
   *  `destinationFieldId` The ID of the destination field.
   *  `copyType` Use `same` to copy the value from a field inside the issue, or `parent` to copy the value from the parent issue.
  
  ##### Create Crucible review workflow function (deprecated) #####
  
  A post function that creates a Crucible review for all unreviewed code for the issue.
  
      {
           "type": "CreateCrucibleReviewWorkflowFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Set issue security level based on user's project role function #####
  
  A post function that sets the issue's security level if the current user has a project role.
  
      {
         "type": "SetIssueSecurityFromRoleFunction",
         "configuration": {
           "projectRole": {
               "id":"10002"
           },
           "issueSecurityLevel": {
               "id":"10000"
           }
         }
       }
  
   *  `projectRole` An object containing the ID of the project role.
   *  `issueSecurityLevel` OPTIONAL. The object containing the ID of the security level. If not passed, then the security level is set to `none`.
  
  ##### Trigger a webhook function #####
  
  A post function that triggers a webhook.
  
      {
         "type": "TriggerWebhookFunction",
         "configuration": {
           "webhook": {
             "id": "1"
           }
         }
       }
  
   *  `webhook` An object containing the ID of the webhook listener to trigger.
  
  ##### Update issue custom field function #####
  
  A post function that updates the content of an issue custom field.
  
      {
         "type": "UpdateIssueCustomFieldPostFunction",
         "configuration": {
           "mode": "append",
           "fieldId": "customfield_10003",
           "fieldValue": "yikes"
         }
       }
  
   *  `mode` Use `replace` to override the field content with `fieldValue` or `append` to add `fieldValue` to the end of the field content.
   *  `fieldId` The ID of the field.
   *  `fieldValue` The update content.
  
  ##### Update issue field function #####
  
  A post function that updates a simple issue field.
  
      {
         "type": "UpdateIssueFieldFunction",
         "configuration": {
           "fieldId": "assignee",
           "fieldValue": "5f0c277e70b8a90025a00776"
         }
       }
  
   *  `fieldId` The ID of the field. Allowed field types:
      
       *  `assignee`
       *  `description`
       *  `environment`
       *  `priority`
       *  `resolution`
       *  `summary`
       *  `timeoriginalestimate`
       *  `timeestimate`
       *  `timespent`
   *  `fieldValue` The update value.
   *  If the `fieldId` is `assignee`, the `fieldValue` should be one of these values:
      
       *  an account ID.
       *  `automatic`.
       *  a blank string, which sets the value to `unassigned`.
  
  #### Connect rules ####
  
  Connect rules are conditions, validators, and post functions of a transition that are registered by Connect apps. To create a rule registered by the app, the app must be enabled and the rule's module must exist.
  
      {
         "type": "appKey__moduleKey",
         "configuration": {
           "value":"{\"isValid\":\"true\"}"
         }
       }
  
   *  `type` A Connect rule key in a form of `appKey__moduleKey`.
   *  `value` The stringified JSON configuration of a Connect rule.
  
  #### Forge rules ####
  
  Forge transition rules are not yet supported.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.createWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-post
  * @param options Request options.
  */
    async createWorkflow(options) {
        return this.Workflow.createWorkflow(options);
    }
    /**
  * Deletes a workflow.
  
  The workflow cannot be deleted if it is:
  
   *  an active workflow.
   *  a system workflow.
   *  associated with any workflow scheme.
   *  associated with any draft workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.deleteWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-entityid-delete
  * @param options Request options.
  */
    async deleteWorkflow(options) {
        return this.Workflow.deleteWorkflow(options);
    }
    /**
  * Returns a [paginated](#pagination) list of published classic workflows. When workflow names are specified, details of those workflows are returned. Otherwise, all published classic workflows are returned.
  
  This operation does not return next-gen workflows.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.getWorkflows
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-search-get
  * @param options Request options.
  */
    async getWorkflows(options) {
        return this.Workflow.getWorkflows(options);
    }
    /**
  * Returns the properties on a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Transition.Property.getProperties
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-get
  * @param options Request options.
  */
    async getWorkflowTransitionProperties(options) {
        return this.Workflow.Transition.Property.getProperties(options);
    }
    /**
  * Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Transition.Property.updateProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
  * @param options Request options.
  */
    async updateWorkflowTransitionProperty(options) {
        return this.Workflow.Transition.Property.updateProperty(options);
    }
    /**
  * Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Transition.Property.createProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
  * @param options Request options.
  */
    async createWorkflowTransitionProperty(options) {
        return this.Workflow.Transition.Property.createProperty(options);
    }
    /**
  * Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Transition.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
  * @param options Request options.
  */
    async deleteWorkflowTransitionProperty(options) {
        return this.Workflow.Transition.Property.deleteProperty(options);
    }
    /**
  * Returns a list of all statuses associated with active workflows.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Workflow.Status.getStatuses
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-statuses/#api-rest-api-3-status-get
  * @param options Request options.
  */
    async getWorkflowStatuses(options) {
        return this.Workflow.Status.getStatuses(options);
    }
    /**
  * Returns a status. The status must be associated with an active workflow to be returned.
  
  If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.
  
  This operation can be accessed anonymously.
  
  [Permissions](#permissions) required: None.
  * Alternative usage: Workflow.Status.getStatus
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-statuses/#api-rest-api-3-status-idorname-get
  * @param options Request options.
  */
    async getWorkflowStatus(options) {
        return this.Workflow.Status.getStatus(options);
    }
    /**
  * Returns a list of all status categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Workflow.Status.Category.getCategories
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-get
  * @param options Request options.
  */
    async getWorkflowStatusCategories(options) {
        return this.Workflow.Status.Category.getCategories(options);
    }
    /**
  * Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Workflow.Status.Category.getCategory
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-idorkey-get
  * @param options Request options.
  */
    async getWorkflowStatusCategory(options) {
        return this.Workflow.Status.Category.getCategory(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-get
  * @param options Request options.
  */
    async getWorkflowSchemes(options) {
        return this.Workflow.Scheme.getSchemes(options);
    }
    /**
  * Creates a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
  * @param options Request options.
  */
    async createWorkflowScheme(options) {
        return this.Workflow.Scheme.createScheme(options);
    }
    /**
  * Returns a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
  * @param options Request options.
  */
    async getWorkflowScheme(options) {
        return this.Workflow.Scheme.getScheme(options);
    }
    /**
  * Updates a company-manged project workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
  * @param options Request options.
  */
    async updateWorkflowScheme(options) {
        return this.Workflow.Scheme.updateScheme(options);
    }
    /**
  * Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
  * @param options Request options.
  */
    async deleteWorkflowScheme(options) {
        return this.Workflow.Scheme.deleteScheme(options);
    }
    /**
  * Returns the issue type-workflow mapping for an issue type in a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.getWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
  * @param options Request options.
  */
    async getWorkflowForIssueTypeInWorkflowScheme(options) {
        return this.Workflow.Scheme.getWorkflowForIssueType(options);
    }
    /**
  * Sets the workflow for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.setWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
  * @param options Request options.
  */
    async setWorkflowForIssueTypeInWorkflowScheme(options) {
        return this.Workflow.Scheme.setWorkflowForIssueType(options);
    }
    /**
  * Deletes the issue type-workflow mapping for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.deleteWorkflowForIssueType
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
  * @param options Request options.
  */
    async deleteWorkflowForIssueTypeInWorkflowScheme(options) {
        return this.Workflow.Scheme.deleteWorkflowForIssueType(options);
    }
    /**
  * Returns the workflow-issue type mappings for a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.getIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
  * @param options Request options.
  */
    async getIssueTypesForWorkflowInWorkflowScheme(options) {
        return this.Workflow.Scheme.getIssueTypesForWorkflow(options);
    }
    /**
  * Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.setIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
  * @param options Request options.
  */
    async setIssueTypesForWorkflowInWorkflowScheme(options) {
        return this.Workflow.Scheme.setIssueTypesForWorkflow(options);
    }
    /**
  * Deletes the workflow-issue type mapping for a workflow in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.deleteIssueTypesForWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
  * @param options Request options.
  */
    async deleteIssueTypesForWorkflowInWorkflowScheme(options) {
        return this.Workflow.Scheme.deleteIssueTypesForWorkflow(options);
    }
    /**
  * Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.getDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
  * @param options Request options.
  */
    async getDefaultWorkflowForWorkflowScheme(options) {
        return this.Workflow.Scheme.getDefaultWorkflow(options);
    }
    /**
  * Sets the default workflow for a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.updateDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
  * @param options Request options.
  */
    async updateDefaultWorkflowForWorkflowScheme(options) {
        return this.Workflow.Scheme.updateDefaultWorkflow(options);
    }
    /**
  * Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.deleteDefaultWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
  * @param options Request options.
  */
    async deleteDefaultWorkflowForWorkflowScheme(options) {
        return this.Workflow.Scheme.deleteDefaultWorkflow(options);
    }
    /**
  * Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.
  
  If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.Project.getProjectAssociations
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-get
  * @param options Request options.
  */
    async getWorkflowSchemeProjectAssociations(options) {
        return this.Workflow.Scheme.Project.getProjectAssociations(options);
    }
    /**
  * Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.
  
  Workflow schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Workflow.Scheme.Project.assignWorkflow
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-put
  * @param options Request options.
  */
    async assignWorkflowSchemeToProject(options) {
        return this.Workflow.Scheme.Project.assignWorkflow(options);
    }
    /**
  * Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Dashboard.getDashboards
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
  * @param options Request options.
  */
    async getDashboards(options) {
        return this.Dashboard.getDashboards(options);
    }
    /**
  * Creates a dashboard.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Dashboard.createDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
  * @param options Request options.
  */
    async createDashboard(options) {
        return this.Dashboard.createDashboard(options);
    }
    /**
  * Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:
  
   *  Dashboards owned by the user. Not returned for anonymous users.
   *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
   *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
   *  Dashboards shared with a public project.
   *  Dashboards shared with the public.
  * Alternative usage: Dashboard.searchDashboards
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
  * @param options Request options.
  */
    async searchDashboards(options) {
        return this.Dashboard.searchDashboards(options);
    }
    /**
  * Returns a dashboard.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  
  However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
  * Alternative usage: Dashboard.getDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
  * @param options Request options.
  */
    async getDashboard(options) {
        return this.Dashboard.getDashboard(options);
    }
    /**
  * Updates a dashboard, replacing all the dashboard details with those provided.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be updated must be owned by the user.
  * Alternative usage: Dashboard.updateDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
  * @param options Request options.
  */
    async updateDashboard(options) {
        return this.Dashboard.updateDashboard(options);
    }
    /**
  * Deletes a dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be deleted must be owned by the user.
  * Alternative usage: Dashboard.deleteDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
  * @param options Request options.
  */
    async deleteDashboard(options) {
        return this.Dashboard.deleteDashboard(options);
    }
    /**
  * Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be copied must be owned by or shared with the user.
  * Alternative usage: Dashboard.copyDashboard
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
  * @param options Request options.
  */
    async copyDashboard(options) {
        return this.Dashboard.copyDashboard(options);
    }
    /**
  * Returns the keys of all properties for a dashboard item.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira\\u2019s anonymous access is permitted.
  * Alternative usage: Dashboard.Property.getPropertyKeys
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-get
  * @param options Request options.
  */
    async getDashboardItemPropertyKeys(options) {
        return this.Dashboard.Property.getPropertyKeys(options);
    }
    /**
  * Returns the key and value of a dashboard item property.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira\\u2019s anonymous access is permitted.
  * Alternative usage: Dashboard.Property.getProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-get
  * @param options Request options.
  */
    async getDashboardItemProperty(options) {
        return this.Dashboard.Property.getProperty(options);
    }
    /**
  * Sets the value of a dashboard item property. Use this resource in apps to store custom data against a dashboard item.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Alternative usage: Dashboard.Property.setProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-put
  * @param options Request options.
  */
    async setDashboardItemProperty(options) {
        return this.Dashboard.Property.setProperty(options);
    }
    /**
  * Deletes a dashboard item property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Alternative usage: Dashboard.Property.deleteProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteDashboardItemProperty(options) {
        return this.Dashboard.Property.deleteProperty(options);
    }
    /**
  * Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Application.Role.getRoles
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-get
  * @param options Request options.
  */
    async getApplicationRoles(options) {
        return this.Application.Role.getRoles(options);
    }
    /**
  * Returns an application role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Application.Role.getRole
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-key-get
  * @param options Request options.
  */
    async getApplicationRole(options) {
        return this.Application.Role.getRole(options);
    }
    /**
  * Changes the value of an application property. For example, you can change the value of the `jira.clone.prefix` from its default value of *CLONE -* to *Clone -* if you prefer sentence case capitalization. Editable properties are described below along with their default values.
  
  #### Advanced settings ####
  
  The advanced settings below are also accessible in [Jira](https://confluence.atlassian.com/x/vYXKM).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.clone.prefix` | The string of text prefixed to the title of a cloned issue. | `CLONE -` |
  | `jira.date.picker.java.format` | The date format for the Java (server-side) generated dates. This must be the same as the `jira.date.picker.javascript.format` format setting. | `d/MMM/yy` |
  | `jira.date.picker.javascript.format` | The date format for the JavaScript (client-side) generated dates. This must be the same as the `jira.date.picker.java.format` format setting. | `%e/%b/%y` |
  | `jira.date.time.picker.java.format` | The date format for the Java (server-side) generated date times. This must be the same as the `jira.date.time.picker.javascript.format` format setting. | `dd/MMM/yy h:mm a` |
  | `jira.date.time.picker.javascript.format` | The date format for the JavaScript (client-side) generated date times. This must be the same as the `jira.date.time.picker.java.format` format setting. | `%e/%b/%y %I:%M %p` |
  | `jira.issue.actions.order` | The default order of actions (such as *Comments* or *Change history*) displayed on the issue view. | `asc` |
  | `jira.view.issue.links.sort.order` | The sort order of the list of issue links on the issue view. | `type, status, priority` |
  | `jira.comment.collapsing.minimum.hidden` | The minimum number of comments required for comment collapsing to occur. A value of `0` disables comment collapsing. | `4` |
  | `jira.newsletter.tip.delay.days` | The number of days before a prompt to sign up to the Jira Insiders newsletter is shown. A value of `-1` disables this feature. | `7` |
  
  
  #### Look and feel ####
  
  The settings listed below adjust the [look and feel](https://confluence.atlassian.com/x/VwCLLg).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.lf.date.time` | The [ time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `h:mm a` |
  | `jira.lf.date.day` | The [ day format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `EEEE h:mm a` |
  | `jira.lf.date.complete` | The [ date and time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy h:mm a` |
  | `jira.lf.date.dmy` | The [ date format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy` |
  | `jira.date.time.picker.use.iso8061` | When enabled, sets Monday as the first day of the week in the date picker, as specified by the ISO8601 standard. | `false` |
  | `jira.lf.logo.url` | The URL of the logo image file. | `/images/icon-jira-logo.png` |
  | `jira.lf.logo.show.application.title` | Controls the visibility of the application title on the sidebar. | `false` |
  | `jira.lf.favicon.url` | The URL of the favicon. | `/favicon.ico` |
  | `jira.lf.favicon.hires.url` | The URL of the high-resolution favicon. | `/images/64jira.png` |
  | `jira.lf.navigation.bgcolour` | The background color of the sidebar. | `#0747A6` |
  | `jira.lf.navigation.highlightcolour` | The color of the text and logo of the sidebar. | `#DEEBFF` |
  | `jira.lf.hero.button.base.bg.colour` | The background color of the hero button. | `#3b7fc4` |
  | `jira.title` | The text for the application title. The application title can also be set in *General settings*. | `Jira` |
  | `jira.option.globalsharing` | Whether filters and dashboards can be shared with anyone signed into Jira. | `true` |
  | `xflow.product.suggestions.enabled` | Whether to expose product suggestions for other Atlassian products within Jira. | `true` |
  
  
  #### Other settings ####
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.issuenav.criteria.autoupdate` | Whether instant updates to search criteria is active. | `true` |
  
  
  *Note: Be careful when changing [application properties and advanced settings](https://confluence.atlassian.com/x/vYXKM).*
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Instance.setApplicationProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-id-put
  * @param options Request options.
  */
    async setApplicationProperty(options) {
        return this.Instance.setApplicationProperty(options);
    }
    /**
  * Returns all application properties or an application property.
  
  If you specify a value for the `key` parameter, then an application property is returned as an object (not in an array). Otherwise, an array of all editable application properties is returned. See [Set application property](#api-rest-api-3-application-properties-id-put) for descriptions of editable properties.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Instance.getApplicationProperty
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-get
  * @param options Request options.
  */
    async getApplicationProperty(options) {
        return this.Instance.getApplicationProperty(options);
    }
    /**
  * Returns the application properties that are accessible on the *Advanced Settings* page. To navigate to the *Advanced Settings* page in Jira, choose the Jira icon > **Jira settings** > **System**, **General Configuration** and then click **Advanced Settings** (in the upper right).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Instance.getAdvancedSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-advanced-settings-get
  * @param options Request options.
  */
    async getAdvancedSettings(options) {
        return this.Instance.getAdvancedSettings(options);
    }
    /**
  * Returns the attachment settings, that is, whether attachments are enabled and the maximum attachment size allowed.
  
  Note that there are also [project permissions](https://confluence.atlassian.com/x/yodKLg) that restrict whether users can create and delete attachments.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Instance.getAttachmentSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-meta-get
  * @param options Request options.
  */
    async getJiraAttachmentSettings(options) {
        return this.Instance.getAttachmentSettings(options);
    }
    /**
  * Returns the [global settings](https://confluence.atlassian.com/x/qYXKM) in Jira. These settings determine whether optional features (for example, subtasks, time tracking, and others) are enabled. If time tracking is enabled, this operation also returns the time tracking configuration.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Instance.getGlobalSettings
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-configuration-get
  * @param options Request options.
  */
    async getGlobalSettings(options) {
        return this.Instance.getGlobalSettings(options);
    }
    /**
  * Returns information about the Jira instance.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Instance.getInfo
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-server-info/#api-rest-api-3-serverinfo-get
  * @param options Request options.
  */
    async getJiraInstanceInfo(options) {
        return this.Instance.getInfo(options);
    }
    /**
  * Returns licensing information about the Jira instance.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Instance.getLicense
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-instance-information/#api-rest-api-3-instance-license-get
  * @param options Request options.
  */
    async getLicense(options) {
        return this.Instance.getLicense(options);
    }
    /**
  * Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Filter.createFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-post
  * @param options Request options.
  */
    async createFilter(options) {
        return this.Filter.createFilter(options);
    }
    /**
  * Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Alternative usage: Filter.getMyFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-my-get
  * @param options Request options.
  */
    async getMyFilters(options) {
        return this.Filter.getMyFilters(options);
    }
    /**
  * Returns a [paginated](#pagination) list of filters. Use this operation to get:
  
   *  specific filters, by defining `id` only.
   *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.searchFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-search-get
  * @param options Request options.
  */
    async searchFilters(options) {
        return this.Filter.searchFilters(options);
    }
    /**
  * Returns a filter.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, the filter is only returned where it is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  * Alternative usage: Filter.getFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-get
  * @param options Request options.
  */
    async getFilter(options) {
        return this.Filter.getFilter(options);
    }
    /**
  * Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
  * Alternative usage: Filter.updateFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-put
  * @param options Request options.
  */
    async updateFilter(options) {
        return this.Filter.updateFilter(options);
    }
    /**
  * Delete a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Filter.deleteFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-delete
  * @param options Request options.
  */
    async deleteFilter(options) {
        return this.Filter.deleteFilter(options);
    }
    /**
  * Returns the visible favorite filters of the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Alternative usage: Filter.Favourite.getFilters
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-favourite-get
  * @param options Request options.
  */
    async getFavouriteFilters(options) {
        return this.Filter.Favourite.getFilters(options);
    }
    /**
  * Add a filter as a favorite for the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Favourite.addFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-favourite-put
  * @param options Request options.
  */
    async addFilterAsFavourite(options) {
        return this.Filter.Favourite.addFilter(options);
    }
    /**
  * Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Filter.Favourite.removeFilter
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-favourite-delete
  * @param options Request options.
  */
    async removeFilterAsFavourite(options) {
        return this.Filter.Favourite.removeFilter(options);
    }
    /**
  * Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, column details are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Column.getColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-get
  * @param options Request options.
  */
    async getFilterColumns(options) {
        return this.Filter.Column.getColumns(options);
    }
    /**
  * Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Column.setColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-put
  * @param options Request options.
  */
    async setFilterColumns(options) {
        return this.Filter.Column.setColumns(options);
    }
    /**
  * Reset the user's column configuration for the filter to the default.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Column.resetColumns
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-delete
  * @param options Request options.
  */
    async resetFilterColumns(options) {
        return this.Filter.Column.resetColumns(options);
    }
    /**
  * Returns the default sharing settings for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Filter.Share.getDefaultScope
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-get
  * @param options Request options.
  */
    async getFiltersDefaultShareScope(options) {
        return this.Filter.Share.getDefaultScope(options);
    }
    /**
  * Sets the default sharing for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Filter.Share.setDefaultScope
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-put
  * @param options Request options.
  */
    async setFiltersDefaultShareScope(options) {
        return this.Filter.Share.setDefaultScope(options);
    }
    /**
  * Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, share permissions are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Share.Permission.getPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
  * @param options Request options.
  */
    async getFiltersSharePermissions(options) {
        return this.Filter.Share.Permission.getPermissions(options);
    }
    /**
  * Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.
  
  Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).
  
  **[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
  * Alternative usage: Filter.Share.Permission.addPermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
  * @param options Request options.
  */
    async addFiltersSharePermission(options) {
        return this.Filter.Share.Permission.addPermission(options);
    }
    /**
  * Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, a share permission is only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Alternative usage: Filter.Share.Permission.getPermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
  * @param options Request options.
  */
    async getFiltersSharePermission(options) {
        return this.Filter.Share.Permission.getPermission(options);
    }
    /**
  * Deletes a share permission from a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
  * Alternative usage: Filter.Share.Permission.deletePermission
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
  * @param options Request options.
  */
    async deleteFiltersSharePermission(options) {
        return this.Filter.Share.Permission.deletePermission(options);
    }
    /**
  * Creates a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Alternative usage: Group.createGroup
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-post
  * @param options Request options.
  */
    async createGroup(options) {
        return this.Group.createGroup(options);
    }
    /**
  * Deletes a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
  * Alternative usage: Group.removeGroup
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-delete
  * @param options Request options.
  */
    async removeGroup(options) {
        return this.Group.removeGroup(options);
    }
    /**
  * Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.
  
  The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.
  
  The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
  
  *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Without this permission, calls where query is not an exact match to an existing group will return an empty list.
  * Alternative usage: Group.findGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-groups-picker-get
  * @param options Request options.
  */
    async findGroups(options) {
        return this.Group.findGroups(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all users in a group.
  
  Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Group.User.getUsers
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-member-get
  * @param options Request options.
  */
    async getUsersFromGroup(options) {
        return this.Group.User.getUsers(options);
    }
    /**
  * Adds a user to a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Alternative usage: Group.User.addUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-user-post
  * @param options Request options.
  */
    async addUserToGroup(options) {
        return this.Group.User.addUser(options);
    }
    /**
  * Removes a user from a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Alternative usage: Group.User.removeUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-user-delete
  * @param options Request options.
  */
    async removeUserFromGroup(options) {
        return this.Group.User.removeUser(options);
    }
    /**
  * Returns a list of users and groups matching a string. The string is used:
  
   *  for users, to find a case-insensitive match with display name and e-mail address. Note that if a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
   *  for groups, to find a case-sensitive match with group name.
  
  For example, if the string *tin* is used, records with the display name *Tina*, email address *sarah@tinplatetraining.com*, and the group *accounting* would be returned.
  
  Optionally, the search can be refined to:
  
   *  the projects and issue types associated with a custom field, such as a user picker. The search can then be further refined to return only users and groups that have permission to view specific:
      
       *  projects.
       *  issue types.
      
      If multiple projects or issue types are specified, they must be a subset of those enabled for the custom field or no results are returned. For example, if a field is enabled for projects A, B, and C then the search could be limited to projects B and C. However, if the search is limited to projects B and D, nothing is returned.
   *  not return Connect app users and groups.
   *  return groups that have a case-insensitive match with the query.
  
  The primary use case for this resource is to populate a picker field suggestion list with users or groups. To this end, the returned object includes an `html` field for each list. This field highlights the matched query term in the item name with the HTML strong tag. Also, each list is wrapped in a response object that contains a header for use in a picker, specifically *Showing X of Y matching groups*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/yodKLg).
  * Alternative usage: GroupAndUserPicker.findUsersAndGroups
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-group-and-user-picker/#api-rest-api-3-groupuserpicker-get
  * @param options Request options.
  */
    async findUsersAndGroupsForPicker(options) {
        return this.GroupAndUserPicker.findUsersAndGroups(options);
    }
    /**
  * Parses and validates JQL queries.
  
  Validation is performed in context of the current user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Jql.parseQuery
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-parse-post
  * @param options Request options.
  */
    async parseJqlQuery(options) {
        return this.Jql.parseQuery(options);
    }
    /**
  * Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.
  
  You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Jql.convertUserIdentifiersToAccountIdsInQueries
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-pdcleaner-post
  * @param options Request options.
  */
    async convertUserIdentifiersToAccountIdsInJqlQueries(options) {
        return this.Jql.convertUserIdentifiersToAccountIdsInQueries(options);
    }
    /**
  * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
  
  To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Jql.getReferenceData
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-autocompletedata-get
  * @param options Request options.
  */
    async getReferenceDataForJql(options) {
        return this.Jql.getReferenceData(options);
    }
    /**
     * Returns a [paginated](#pagination) list of labels.
     * Alternative usage: Label.getLabels
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-labels/#api-rest-api-3-label-get
     * @param options Request options.
     */
    async getLabels(options) {
        return this.Label.getLabels(options);
    }
    /**
  * Returns a list of permissions indicating which permissions the user has. Details of the user's permissions can be obtained in a global, project, issue or comment context.
  
  The user is reported as having a project permission:
  
   *  in the global context, if the user has the project permission in any project.
   *  for a project, where the project permission is determined using issue data, if the user meets the permission's criteria for any issue in the project. Otherwise, if the user has the project permission in the project.
   *  for an issue, where a project permission is determined using issue data, if the user has the permission in the issue. Otherwise, if the user has the project permission in the project containing the issue.
   *  for a comment, where the user has both the permission to browse the comment and the project permission for the comment's parent issue. Only the BROWSE\_PROJECTS permission is supported. If a `commentId` is provided whose `permissions` does not equal BROWSE\_PROJECTS, a 400 error will be returned.
  
  This means that users may be shown as having an issue permission (such as EDIT\_ISSUES) in the global context or a project context but may not have the permission for any or all issues. For example, if Reporters have the EDIT\_ISSUES permission a user would be shown as having this permission in the global context or the context of a project, because any user can be a reporter. However, if they are not the user who reported the issue queried they would not have EDIT\_ISSUES permission for that issue.
  
  For [Jira Service Management project permissions](https://support.atlassian.com/jira-cloud-administration/docs/customize-jira-service-management-permissions/), this will be evaluated similarly to a user in the customer portal. For example, if the BROWSE\_PROJECTS permission is granted to Service Project Customer - Portal Access, any users with access to the customer portal will have the BROWSE\_PROJECTS permission.
  
  Global permissions are unaffected by context.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Permission.getMyPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-mypermissions-get
  * @param options Request options.
  */
    async getMyPermissions(options) {
        return this.Permission.getMyPermissions(options);
    }
    /**
  * Returns all permissions, including:
  
   *  global permissions.
   *  project permissions.
   *  global permissions added by plugins.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Permission.getPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-get
  * @param options Request options.
  */
    async getPermissions(options) {
        return this.Permission.getPermissions(options);
    }
    /**
  * Returns:
  
   *  for a list of global permissions, the global permissions granted to a user.
   *  for a list of project permissions and lists of projects and issues, for each project permission a list of the projects and issues a user can access or manipulate.
  
  If no account ID is provided, the operation returns details for the logged in user.
  
  Note that:
  
   *  Invalid project and issue IDs are ignored.
   *  A maximum of 1000 projects and 1000 issues can be checked.
   *  Null values in `globalPermissions`, `projectPermissions`, `projectPermissions.projects`, and `projectPermissions.issues` are ignored.
   *  Empty strings in `projectPermissions.permissions` are ignored.
  
  **Deprecation notice:** The required OAuth 2.0 scopes will be updated on June 15, 2024.
  
   *  **Classic**: `read:jira-work`
   *  **Granular**: `read:permission:jira`
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to check the permissions for other users, otherwise none. However, Connect apps can make a call from the app server to the product to obtain permission details for any user, without admin permission. This Connect app ability doesn't apply to calls made using AP.request() in a browser.
  * Alternative usage: Permission.getBulkPermissions
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-check-post
  * @param options Request options.
  */
    async getBulkPermissions(options) {
        return this.Permission.getBulkPermissions(options);
    }
    /**
  * Returns all the projects where the user is granted a list of project permissions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Permission.getPermittedProjects
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-project-post
  * @param options Request options.
  */
    async getPermittedProjects(options) {
        return this.Permission.getPermittedProjects(options);
    }
    /**
  * Returns all permission schemes.
  
  ### About permission schemes and grants ###
  
  A permission scheme is a collection of permission grants. A permission grant consists of a `holder` and a `permission`.
  
  #### Holder object ####
  
  The `holder` object contains information about the user or group being granted the permission. For example, the *Administer projects* permission is granted to a group named *Teams in space administrators*. In this case, the type is `"type": "group"`, and the parameter is the group name, `"parameter": "Teams in space administrators"` and the value is group ID, `"value": "ca85fac0-d974-40ca-a615-7af99c48d24f"`.
  
  The `holder` object is defined by the following properties:
  
   *  `type` Identifies the user or group (see the list of types below).
   *  `parameter` As a group's name can change, use of `value` is recommended. The value of this property depends on the `type`. For example, if the `type` is a group, then you need to specify the group name.
   *  `value` The value of this property depends on the `type`. If the `type` is a group, then you need to specify the group ID. For other `type` it has the same value as `parameter`
  
  The following `types` are available. The expected values for `parameter` and `value` are given in parentheses (some types may not have a `parameter` or `value`):
  
   *  `anyone` Grant for anonymous users.
   *  `applicationRole` Grant for users with access to the specified application (application name, application name). See [Update product access settings](https://confluence.atlassian.com/x/3YxjL) for more information.
   *  `assignee` Grant for the user currently assigned to an issue.
   *  `group` Grant for the specified group (`parameter` : group name, `value` : group ID).
   *  `groupCustomField` Grant for a user in the group selected in the specified custom field (`parameter` : custom field ID, `value` : custom field ID).
   *  `projectLead` Grant for a project lead.
   *  `projectRole` Grant for the specified project role (`parameter` :project role ID, `value` : project role ID).
   *  `reporter` Grant for the user who reported the issue.
   *  `sd.customer.portal.only` Jira Service Desk only. Grants customers permission to access the customer portal but not Jira. See [Customizing Jira Service Desk permissions](https://confluence.atlassian.com/x/24dKLg) for more information.
   *  `user` Grant for the specified user (`parameter` : user ID - historically this was the userkey but that is deprecated and the account ID should be used, `value` : user ID).
   *  `userCustomField` Grant for a user selected in the specified custom field (`parameter` : custom field ID, `value` : custom field ID).
  
  #### Built-in permissions ####
  
  The [built-in Jira permissions](https://confluence.atlassian.com/x/yodKLg) are listed below. Apps can also define custom permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information.
  
  **Project permissions**
  
   *  `ADMINISTER_PROJECTS`
   *  `BROWSE_PROJECTS`
   *  `MANAGE_SPRINTS_PERMISSION` (Jira Software only)
   *  `SERVICEDESK_AGENT` (Jira Service Desk only)
   *  `VIEW_DEV_TOOLS` (Jira Software only)
   *  `VIEW_READONLY_WORKFLOW`
  
  **Issue permissions**
  
   *  `ASSIGNABLE_USER`
   *  `ASSIGN_ISSUES`
   *  `CLOSE_ISSUES`
   *  `CREATE_ISSUES`
   *  `DELETE_ISSUES`
   *  `EDIT_ISSUES`
   *  `LINK_ISSUES`
   *  `MODIFY_REPORTER`
   *  `MOVE_ISSUES`
   *  `RESOLVE_ISSUES`
   *  `SCHEDULE_ISSUES`
   *  `SET_ISSUE_SECURITY`
   *  `TRANSITION_ISSUES`
  
  **Voters and watchers permissions**
  
   *  `MANAGE_WATCHERS`
   *  `VIEW_VOTERS_AND_WATCHERS`
  
  **Comments permissions**
  
   *  `ADD_COMMENTS`
   *  `DELETE_ALL_COMMENTS`
   *  `DELETE_OWN_COMMENTS`
   *  `EDIT_ALL_COMMENTS`
   *  `EDIT_OWN_COMMENTS`
  
  **Attachments permissions**
  
   *  `CREATE_ATTACHMENTS`
   *  `DELETE_ALL_ATTACHMENTS`
   *  `DELETE_OWN_ATTACHMENTS`
  
  **Time tracking permissions**
  
   *  `DELETE_ALL_WORKLOGS`
   *  `DELETE_OWN_WORKLOGS`
   *  `EDIT_ALL_WORKLOGS`
   *  `EDIT_OWN_WORKLOGS`
   *  `WORK_ON_ISSUES`
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Permission.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-get
  * @param options Request options.
  */
    async getPermissionSchemes(options) {
        return this.Permission.Scheme.getSchemes(options);
    }
    /**
  * Creates a new permission scheme. You can create a permission scheme with or without defining a set of permission grants.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Permission.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-post
  * @param options Request options.
  */
    async createPermissionScheme(options) {
        return this.Permission.Scheme.createScheme(options);
    }
    /**
  * Returns a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Permission.Scheme.getScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-get
  * @param options Request options.
  */
    async getPermissionScheme(options) {
        return this.Permission.Scheme.getScheme(options);
    }
    /**
  * Updates a permission scheme. Below are some important things to note when using this resource:
  
   *  If a permissions list is present in the request, then it is set in the permission scheme, overwriting *all existing* grants.
   *  If you want to update only the name and description, then do not send a permissions list in the request.
   *  Sending an empty list will remove all permission grants from the permission scheme.
  
  If you want to add or delete a permission grant instead of updating the whole list, see [Create permission grant](#api-rest-api-3-permissionscheme-schemeId-permission-post) or [Delete permission scheme entity](#api-rest-api-3-permissionscheme-schemeId-permission-permissionId-delete).
  
  See [About permission schemes and grants](#about-permission-schemes) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Permission.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-put
  * @param options Request options.
  */
    async updatePermissionScheme(options) {
        return this.Permission.Scheme.updateScheme(options);
    }
    /**
  * Deletes a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Permission.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-delete
  * @param options Request options.
  */
    async deletePermissionScheme(options) {
        return this.Permission.Scheme.deleteScheme(options);
    }
    /**
  * Returns all permission grants for a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Permission.Scheme.Grant.getGrants
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
  * @param options Request options.
  */
    async getPermissionSchemeGrants(options) {
        return this.Permission.Scheme.Grant.getGrants(options);
    }
    /**
  * Creates a permission grant in a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Permission.Scheme.Grant.createGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
  * @param options Request options.
  */
    async createPermissionSchemeGrant(options) {
        return this.Permission.Scheme.Grant.createGrant(options);
    }
    /**
  * Returns a permission grant.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Permission.Scheme.Grant.getGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
  * @param options Request options.
  */
    async getPermissionSchemeGrant(options) {
        return this.Permission.Scheme.Grant.getGrant(options);
    }
    /**
  * Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Permission.Scheme.Grant.deleteGrant
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
  * @param options Request options.
  */
    async deletePermissionSchemeGrant(options) {
        return this.Permission.Scheme.Grant.deleteGrant(options);
    }
    /**
  * Returns the value of a preference of the current user.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
   *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.
  
  These system preferences keys will be deprecated by 15/07/2024. You can still retrieve these keys, but it will not have any impact on Notification behaviour.
  
   *  *user.notifications.watcher* Whether the user gets notified when they are watcher.
   *  *user.notifications.assignee* Whether the user gets notified when they are assignee.
   *  *user.notifications.reporter* Whether the user gets notified when they are reporter.
   *  *user.notifications.mentions* Whether the user gets notified when they are mentions.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Myself.getPreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-get
  * @param options Request options.
  */
    async getMyPreference(options) {
        return this.Myself.getPreference(options);
    }
    /**
  * Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:
  
   *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
   *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
   *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
   *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.
   *  *user.notifiy.own.changes* Whether the user gets notified of their own changes.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  These system preferences keys will be deprecated by 15/07/2024. You can still use these keys to create arbitrary preferences, but it will not have any impact on Notification behaviour.
  
   *  *user.notifications.watcher* Whether the user gets notified when they are watcher.
   *  *user.notifications.assignee* Whether the user gets notified when they are assignee.
   *  *user.notifications.reporter* Whether the user gets notified when they are reporter.
   *  *user.notifications.mentions* Whether the user gets notified when they are mentions.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Myself.setPreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-put
  * @param options Request options.
  */
    async setMyPreference(options) {
        return this.Myself.setPreference(options);
    }
    /**
  * Deletes a preference of the user, which restores the default value of system defined settings.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Myself.deletePreference
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-delete
  * @param options Request options.
  */
    async deleteMyPreference(options) {
        return this.Myself.deletePreference(options);
    }
    /**
  * Returns the locale for the user.
  
  If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Alternative usage: Myself.getLocale
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-locale-get
  * @param options Request options.
  */
    async getMyLocale(options) {
        return this.Myself.getLocale(options);
    }
    /**
  * Returns details for the current user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Alternative usage: Myself.getCurrentUser
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-myself-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        return this.Myself.getCurrentUser(options);
    }
    /**
  * Returns a [paginated](#pagination) list of the screens a field is used in.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.getScreensForField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
  * @param options Request options.
  */
    async getScreensForField(options) {
        return this.Screen.getScreensForField(options);
    }
    /**
  * Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.getScreens
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
  * @param options Request options.
  */
    async getScreens(options) {
        return this.Screen.getScreens(options);
    }
    /**
  * Creates a screen with a default field tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.createScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
  * @param options Request options.
  */
    async createScreen(options) {
        return this.Screen.createScreen(options);
    }
    /**
  * Adds a field to the default tab of the default screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.addFieldToDefaultScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
  * @param options Request options.
  */
    async addFieldToDefaultScreen(options) {
        return this.Screen.addFieldToDefaultScreen(options);
    }
    /**
  * Returns the fields that can be added to a tab on a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.getAvailableScreenFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
  * @param options Request options.
  */
    async getAvailableScreenFields(options) {
        return this.Screen.getAvailableScreenFields(options);
    }
    /**
  * Updates a screen. Only screens used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.updateScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
  * @param options Request options.
  */
    async updateScreen(options) {
        return this.Screen.updateScreen(options);
    }
    /**
  * Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.
  
  Only screens used in classic projects can be deleted.
  * Alternative usage: Screen.deleteScreen
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
  * @param options Request options.
  */
    async deleteScreen(options) {
        return this.Screen.deleteScreen(options);
    }
    /**
  * Returns a [paginated](#pagination) list of screen schemes.
  
  Only screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Scheme.getSchemes
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-get
  * @param options Request options.
  */
    async getScreenSchemes(options) {
        return this.Screen.Scheme.getSchemes(options);
    }
    /**
  * Creates a screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Scheme.createScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
  * @param options Request options.
  */
    async createScreenScheme(options) {
        return this.Screen.Scheme.createScheme(options);
    }
    /**
  * Updates a screen scheme. Only screen schemes used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Scheme.updateScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
  * @param options Request options.
  */
    async updateScreenScheme(options) {
        return this.Screen.Scheme.updateScheme(options);
    }
    /**
  * Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.
  
  Only screens schemes used in classic projects can be deleted.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Scheme.deleteScheme
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
  * @param options Request options.
  */
    async deleteScreenScheme(options) {
        return this.Screen.Scheme.deleteScheme(options);
    }
    /**
  * Returns the list of tabs for a screen.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Alternative usage: Screen.Tab.getTabs
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
  * @param options Request options.
  */
    async getScreenTabs(options) {
        return this.Screen.Tab.getTabs(options);
    }
    /**
  * Creates a tab for a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.createTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
  * @param options Request options.
  */
    async createScreenTab(options) {
        return this.Screen.Tab.createTab(options);
    }
    /**
  * Updates the name of a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.updateTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
  * @param options Request options.
  */
    async updateScreenTab(options) {
        return this.Screen.Tab.updateTab(options);
    }
    /**
  * Deletes a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.deleteTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
  * @param options Request options.
  */
    async deleteScreenTab(options) {
        return this.Screen.Tab.deleteTab(options);
    }
    /**
  * Moves a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.moveTab
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
  * @param options Request options.
  */
    async moveScreenTab(options) {
        return this.Screen.Tab.moveTab(options);
    }
    /**
  * Returns all fields for a screen tab.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Alternative usage: Screen.Tab.Field.getFields
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
  * @param options Request options.
  */
    async getScreenTabFields(options) {
        return this.Screen.Tab.Field.getFields(options);
    }
    /**
  * Adds a field to a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.Field.addField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
  * @param options Request options.
  */
    async addScreenTabField(options) {
        return this.Screen.Tab.Field.addField(options);
    }
    /**
  * Removes a field from a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.Field.removeField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
  * @param options Request options.
  */
    async removeScreenTabField(options) {
        return this.Screen.Tab.Field.removeField(options);
    }
    /**
  * Moves a screen tab field.
  
  If `after` and `position` are provided in the request, `position` is ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Alternative usage: Screen.Tab.Field.moveField
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
  * @param options Request options.
  */
    async moveScreenTabField(options) {
        return this.Screen.Tab.Field.moveField(options);
    }
}
class IssueGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Priority = new IssuePriorityGroup(implementation, this.getGlobalErrorStrategy);
        this.Field = new IssueFieldGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new IssueTypeGroup(implementation, this.getGlobalErrorStrategy);
        this.Worklog = new IssueWorklogGroup(implementation, this.getGlobalErrorStrategy);
        this.Attachment = new IssueAttachmentGroup(implementation, this.getGlobalErrorStrategy);
        this.Comment = new IssueCommentGroup(implementation, this.getGlobalErrorStrategy);
        this.Metadata = new IssueMetadataGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new IssuePropertyGroup(implementation, this.getGlobalErrorStrategy);
        this.Link = new IssueLinkGroup(implementation, this.getGlobalErrorStrategy);
        this.Transition = new IssueTransitionGroup(implementation, this.getGlobalErrorStrategy);
        this.Vote = new IssueVoteGroup(implementation, this.getGlobalErrorStrategy);
        this.Watcher = new IssueWatcherGroup(implementation, this.getGlobalErrorStrategy);
        this.Search = new IssueSearchGroup(implementation, this.getGlobalErrorStrategy);
        this.Resolution = new IssueResolutionGroup(implementation, this.getGlobalErrorStrategy);
        this.Security = new IssueSecurityGroup(implementation, this.getGlobalErrorStrategy);
        this.Notification = new IssueNotificationGroup(implementation, this.getGlobalErrorStrategy);
        this.Navigator = new IssueNavigatorGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates an issue or, where the option to create subtasks is enabled in Jira, a subtask. A transition may be applied, to move the issue or subtask to a workflow step other than the default start step, and issue properties set.
  
  The content of the issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issue's create screen. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` must contain the ID or key of the parent issue.
  
  In a next-gen project any issue may be made a child providing that the parent and child are members of the same project.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which the issue or subtask is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-post
  * @param options Request options.
  */
    async createIssue(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/issue`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates upto **50** issues and, where the option to create subtasks is enabled in Jira, subtasks. Transitions may be applied, to move the issues or subtasks to a workflow step other than the default start step, and issue properties set.
  
  The content of each issue or subtask is defined using `update` and `fields`. The fields that can be set in the issue or subtask are determined using the [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get). These are the same fields that appear on the issues' create screens. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Creating a subtask differs from creating an issue as follows:
  
   *  `issueType` must be set to a subtask issue type (use [ Get create issue metadata](#api-rest-api-3-issue-createmeta-get) to find subtask issue types).
   *  `parent` the must contain the ID or key of the parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* and *Create issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project in which each issue or subtask is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-bulk-post
  * @param options Request options.
  */
    async createIssues(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issue/bulk`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the details for an issue.
  
  The issue is identified by its ID or key, however, if the identifier doesn't match an issue, a case-insensitive search and check for moved issues is performed. If a matching issue is found its details are returned, a 302 or other redirect is **not** returned. The issue key returned in the response is the key of the issue found.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-get
  * @param options Request options.
  */
    async getIssue(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Edits an issue. Issue properties may be updated as part of the edit. Please note that issue transition is not supported and is ignored here. To transition an issue, please use [Transition issue](#api-rest-api-3-issue-issueIdOrKey-transitions-post).
  
  The edits to the issue's fields are defined using `update` and `fields`. The fields that can be edited are determined using [ Get edit issue metadata](#api-rest-api-3-issue-issueIdOrKey-editmeta-get).
  
  The parent field may be set by key or ID. For standard issue types, the parent may be removed by setting `update.parent.set.none` to *true*. Note that the `description`, `environment`, and any `textarea` type custom fields (multi-line text fields) take Atlassian Document Format content. Single line custom fields (`textfield`) accept a string and don't handle Atlassian Document Format content.
  
  Connect apps having an app user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), can override the screen security configuration using `overrideScreenSecurity` and `overrideEditableFlag`.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-put
  * @param options Request options.
  */
    async editIssue(options) {
        const { body, headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes an issue.
  
  An issue cannot be deleted if it has one or more subtasks. To delete an issue with subtasks, set `deleteSubtasks`. This causes the issue's subtasks to be deleted with the issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Delete issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-delete
  * @param options Request options.
  */
    async deleteIssue(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Assigns an issue to a user. Use this operation when the calling user does not have the *Edit Issues* permission but has the *Assign issue* permission for the project that the issue is in.
  
  If `name` or `accountId` is set to:
  
   *  `"-1"`, the issue is assigned to the default assignee for the project.
   *  `null`, the issue is set to unassigned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Assign Issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-assignee-put
  * @param options Request options.
  */
    async assignIssue(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("PUT", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/assignee`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a [paginated](#pagination) list of all changelogs for an issue sorted by date, starting from the oldest.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-get
  * @param options Request options.
  */
    async getChangeLogs(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/changelog`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns changelogs for an issue specified by a list of changelog IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-changelog-list-post
  * @param options Request options.
  */
    async getChangeLogsById(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/changelog/list`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates an email notification for an issue and adds it to the mail queue.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-notify-post
  * @param options Request options.
  */
    async sendNotification(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/notify`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssuePriorityGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of priorities. The list can contain all priorities or a subset determined by any combination of these criteria:
  
   *  a list of priority IDs. Any invalid priority IDs are ignored.
   *  a list of project IDs. Only priorities that are available in these projects will be returned. Any invalid project IDs are ignored.
   *  whether the field configuration is a default. This returns priorities from company-managed (classic) projects only, as there is no concept of default priorities in team-managed projects.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-search-get
  * @param options Request options.
  */
    async searchPriorities(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/priority/search`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the list of all issue priorities.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-get
  * @param options Request options.
  * @deprecated
  */
    async getPriorities(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/priority`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an issue priority.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-priorities/#api-rest-api-3-priority-id-get
  * @param options Request options.
  */
    async getPriority(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/priority/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueFieldGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Custom = new IssueFieldCustomGroup(implementation, this.getGlobalErrorStrategy);
        this.Configuration = new IssueFieldConfigurationGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns system and custom issue fields according to the following rules:
  
   *  Fields that cannot be added to the issue navigator are always returned.
   *  Fields that cannot be placed on an issue screen are always returned.
   *  Fields that depend on global Jira settings are only returned if the setting is enabled. That is, timetracking fields, subtasks, votes, and watches.
   *  For all other fields, this operation only returns the fields that the user has permission to view (that is, the field is used in at least one project that the user has *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.)
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-get
  * @param options Request options.
  */
    async getFields(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/field`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of fields for Classic Jira projects. The list can include:
  
   *  all fields
   *  specific fields, by defining `id`
   *  fields that contain a string in the field name or description, by defining `query`
   *  specific fields that contain a string in the field name or description, by defining `id` and `query`
  
  Use `type` must be set to `custom` to show custom fields only.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-search-get
  * @param options Request options.
  */
    async getFieldsPaginated(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/field/search`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of the contexts a field is used in. Deprecated, use [ Get custom field contexts](#api-rest-api-3-field-fieldId-context-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-contexts-get
  * @param options Request options.
  * @deprecated
  */
    async getContexts(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/contexts`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueFieldCustomGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Context = new IssueFieldCustomContextGroup(implementation, this.getGlobalErrorStrategy);
        this.Option = new IssueFieldCustomOptionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-post
  * @param options Request options.
  */
    async createField(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/field`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a custom field. The custom field is deleted whether it is in the trash or not. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  This operation is [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-delete
  * @param options Request options.
  */
    async deleteField(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/field/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Restores a custom field from trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-restore-post
  * @param options Request options.
  */
    async restoreField(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(id)}/restore`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Moves a custom field to trash. See [Edit or delete a custom field](https://confluence.atlassian.com/x/Z44fOw) for more information on trashing and deleting custom fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-id-trash-post
  * @param options Request options.
  */
    async moveToTrash(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(id)}/trash`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Updates a custom field.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-fields/#api-rest-api-3-field-fieldid-put
  * @param options Request options.
  */
    async updateField(options) {
        const { body, headers, errorStrategy, fieldId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueFieldCustomContextGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Option = new IssueFieldCustomContextOptionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a [paginated](#pagination) list of project and issue type mappings and, for each mapping, the ID of a [custom field context](https://confluence.atlassian.com/x/k44fOw) that applies to the project and issue type.
  
  If there is no custom field context assigned to the project then, if present, the custom field context that applies to all projects is returned if it also applies to the issue type or all issue types. If a custom field context is not found, the returned custom field context ID is `null`.
  
  Duplicate project and issue type mappings cannot be provided in the request.
  
  The order of the returned values is the same as provided in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-mapping-post
  * @param options Request options.
  */
    async getForProjectsAndIssueType(options) {
        const { body, headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context/mapping`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-delete
  * @param options Request options.
  */
    async deleteContext(options) {
        const { headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("DELETE", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Updates a [ custom field context](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-put
  * @param options Request options.
  */
    async updateContext(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a [paginated](#pagination) list of [ contexts](https://confluence.atlassian.com/adminjiracloud/what-are-custom-field-contexts-991923859.html) for a custom field. Contexts can be returned as follows:
  
   *  With no other parameters set, all contexts.
   *  By defining `id` only, all contexts from the list of IDs.
   *  By defining `isAnyIssueType`, limit the list of contexts returned to either those that apply to all issue types (true) or those that apply to only a subset of issue types (false)
   *  By defining `isGlobalContext`, limit the list of contexts return to either those that apply to all projects (global contexts) (true) or those that apply to only a subset of projects (false).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-get
  * @param options Request options.
  */
    async getContexts(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a custom field context.
  
  If `projectIds` is empty, a global context is created. A global context is one that applies to all project. If `issueTypeIds` is empty, the context applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-post
  * @param options Request options.
  */
    async createContext(options) {
        const { body, headers, errorStrategy, fieldId } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of defaults for a custom field. The results can be filtered by `contextId`, otherwise all values are returned. If no defaults are set for a context, nothing is returned.
  The returned object depends on type of the custom field:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group pickers.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group pickers.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URLs.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project pickers.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for floats (floating-point numbers).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text fields.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area fields.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) fields.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version pickers.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version pickers.
  
  Forge custom fields [types](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field-type/#data-types) are also supported, returning:
  
   *  `CustomFieldContextDefaultValueForgeStringFieldBean` (type `forge.string`) for Forge string fields.
   *  `CustomFieldContextDefaultValueForgeMultiStringFieldBean` (type `forge.string.list`) for Forge string collection fields.
   *  `CustomFieldContextDefaultValueForgeObjectFieldBean` (type `forge.object`) for Forge object fields.
   *  `CustomFieldContextDefaultValueForgeDateTimeFieldBean` (type `forge.datetime`) for Forge date-time fields.
   *  `CustomFieldContextDefaultValueForgeGroupFieldBean` (type `forge.group`) for Forge group fields.
   *  `CustomFieldContextDefaultValueForgeMultiGroupFieldBean` (type `forge.group.list`) for Forge group collection fields.
   *  `CustomFieldContextDefaultValueForgeNumberFieldBean` (type `forge.number`) for Forge number fields.
   *  `CustomFieldContextDefaultValueForgeUserFieldBean` (type `forge.user`) for Forge user fields.
   *  `CustomFieldContextDefaultValueForgeMultiUserFieldBean` (type `forge.user.list`) for Forge user collection fields.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-get
  * @param options Request options.
  */
    async getDefaultContexts(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context/defaultValue`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets default for contexts of a custom field. Default are defined using these objects:
  
   *  `CustomFieldContextDefaultValueDate` (type `datepicker`) for date fields.
   *  `CustomFieldContextDefaultValueDateTime` (type `datetimepicker`) for date-time fields.
   *  `CustomFieldContextDefaultValueSingleOption` (type `option.single`) for single choice select lists and radio buttons.
   *  `CustomFieldContextDefaultValueMultipleOption` (type `option.multiple`) for multiple choice select lists and checkboxes.
   *  `CustomFieldContextDefaultValueCascadingOption` (type `option.cascading`) for cascading select lists.
   *  `CustomFieldContextSingleUserPickerDefaults` (type `single.user.select`) for single users.
   *  `CustomFieldContextDefaultValueMultiUserPicker` (type `multi.user.select`) for user lists.
   *  `CustomFieldContextDefaultValueSingleGroupPicker` (type `grouppicker.single`) for single choice group pickers.
   *  `CustomFieldContextDefaultValueMultipleGroupPicker` (type `grouppicker.multiple`) for multiple choice group pickers.
   *  `CustomFieldContextDefaultValueURL` (type `url`) for URLs.
   *  `CustomFieldContextDefaultValueProject` (type `project`) for project pickers.
   *  `CustomFieldContextDefaultValueFloat` (type `float`) for floats (floating-point numbers).
   *  `CustomFieldContextDefaultValueLabels` (type `labels`) for labels.
   *  `CustomFieldContextDefaultValueTextField` (type `textfield`) for text fields.
   *  `CustomFieldContextDefaultValueTextArea` (type `textarea`) for text area fields.
   *  `CustomFieldContextDefaultValueReadOnly` (type `readonly`) for read only (text) fields.
   *  `CustomFieldContextDefaultValueMultipleVersion` (type `version.multiple`) for single choice version pickers.
   *  `CustomFieldContextDefaultValueSingleVersion` (type `version.single`) for multiple choice version pickers.
  
  Forge custom fields [types](https://developer.atlassian.com/platform/forge/manifest-reference/modules/jira-custom-field-type/#data-types) are also supported, returning:
  
   *  `CustomFieldContextDefaultValueForgeStringFieldBean` (type `forge.string`) for Forge string fields.
   *  `CustomFieldContextDefaultValueForgeMultiStringFieldBean` (type `forge.string.list`) for Forge string collection fields.
   *  `CustomFieldContextDefaultValueForgeObjectFieldBean` (type `forge.object`) for Forge object fields.
   *  `CustomFieldContextDefaultValueForgeDateTimeFieldBean` (type `forge.datetime`) for Forge date-time fields.
   *  `CustomFieldContextDefaultValueForgeGroupFieldBean` (type `forge.group`) for Forge group fields.
   *  `CustomFieldContextDefaultValueForgeMultiGroupFieldBean` (type `forge.group.list`) for Forge group collection fields.
   *  `CustomFieldContextDefaultValueForgeNumberFieldBean` (type `forge.number`) for Forge number fields.
   *  `CustomFieldContextDefaultValueForgeUserFieldBean` (type `forge.user`) for Forge user fields.
   *  `CustomFieldContextDefaultValueForgeMultiUserFieldBean` (type `forge.user.list`) for Forge user collection fields.
  
  Only one type of default object can be included in a request. To remove a default for a context, set the default parameter to `null`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-defaultvalue-put
  * @param options Request options.
  */
    async setDefaultContexts(options) {
        const { body, headers, errorStrategy, fieldId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/defaultValue`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a [paginated](#pagination) list of context to issue type mappings for a custom field. Mappings are returned for all contexts or a list of contexts. Mappings are ordered first by context ID and then by issue type ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-issuetypemapping-get
  * @param options Request options.
  */
    async getIssueTypes(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context/issuetypemapping`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of context to project mappings for a custom field. The result can be filtered by `contextId`. Otherwise, all mappings are returned. Invalid IDs are ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-projectmapping-get
  * @param options Request options.
  */
    async getProjectMappings(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context/projectmapping`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds issue types to a custom field context, appending the issue types to the issue types list.
  
  A custom field context without any issue types applies to all issue types. Adding issue types to such a custom field context would result in it applying to only the listed issue types.
  
  If any of the issue types exists in the custom field context, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-put
  * @param options Request options.
  */
    async addIssueTypes(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/issuetype`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes issue types from a custom field context.
  
  A custom field context without any issue types applies to all issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-issuetype-remove-post
  * @param options Request options.
  */
    async removeIssueTypes(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/issuetype/remove`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Assigns a custom field context to projects.
  
  If any project in the request is assigned to any context of the custom field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-put
  * @param options Request options.
  */
    async assignToProjects(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes a custom field context from projects.
  
  A custom field context without any projects applies to all projects. Removing all projects from a custom field context would result in it applying to all projects.
  
  If any project in the request is not assigned to the context, or the operation would result in two global contexts for the field, the operation fails.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-contexts/#api-rest-api-3-field-fieldid-context-contextid-project-remove-post
  * @param options Request options.
  */
    async removeFromProjects(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/project/remove`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueFieldCustomContextOptionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of all custom field option for a context. Options are returned first then cascading options, in the order they display in Jira.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-get
  * @param options Request options.
  */
    async getOptions(options) {
        const { headers, errorStrategy, fieldId, contextId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/option`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates options and, where the custom select field is of the type Select List (cascading), cascading options for a custom select field. The options are added to a context of the field.
  
  The maximum number of options that can be created per request is 1000 and each field can have a maximum of 10000 options.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-post
  * @param options Request options.
  */
    async createOptions(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("POST", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/option`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the options of a custom field.
  
  If any of the options are not found, no options are updated. Options where the values in the request match the current values aren't updated and aren't reported in the response.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-put
  * @param options Request options.
  */
    async updateOptions(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/option`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Changes the order of custom field options or cascading options in a context.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-move-put
  * @param options Request options.
  */
    async reorderOptions(options) {
        const { body, headers, errorStrategy, fieldId, contextId } = options;
        const request = new Request("PUT", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/option/move`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a custom field option.
  
  Options with cascading options cannot be deleted without deleting the cascading options first.
  
  This operation works for custom field options created in Jira or the operations from this resource. **To work with issue field select list options created for Connect apps use the [Issue custom field options (apps)](#api-group-issue-custom-field-options--apps-) operations.**
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-field-fieldid-context-contextid-option-optionid-delete
  * @param options Request options.
  */
    async deleteOption(options) {
        const { headers, errorStrategy, fieldId, contextId, optionId } = options;
        const request = new Request("DELETE", `/rest/api/3/field/${encodeURIComponent(fieldId)}/context/${encodeURIComponent(contextId)}/option/${encodeURIComponent(optionId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueFieldCustomOptionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a custom field option. For example, an option in a select list.
  
  Note that this operation **only works for issue field select list options created in Jira or using operations from the [Issue custom field options](#api-group-Issue-custom-field-options) resource**, it cannot be used with issue field select list options created by Connect apps.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The custom field option is returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the custom field is used in, and the field is visible in at least one layout the user has permission to view.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-custom-field-options/#api-rest-api-3-customfieldoption-id-get
  * @param options Request options.
  */
    async getOption(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/customFieldOption/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueFieldConfigurationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new IssueFieldConfigurationSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a field configuration. The field configuration is created with the same field properties as the default configuration, with all the fields being optional.
  
  This operation can only create configurations for use in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-post
  * @param options Request options.
  */
    async createConfiguration(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/fieldconfiguration`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of field configurations. The list can be for all field configurations or a subset determined by any combination of these criteria:
  
   *  a list of field configuration item IDs.
   *  whether the field configuration is a default.
   *  whether the field configuration name or description contains a query string.
  
  Only field configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-get
  * @param options Request options.
  */
    async getConfigurations(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/fieldconfiguration`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a field configuration. The name and the description provided in the request override the existing values.
  
  This operation can only update configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-put
  * @param options Request options.
  */
    async updateConfiguration(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/fieldconfiguration/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a field configuration.
  
  This operation can only delete configurations used in company-managed (classic) projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-delete
  * @param options Request options.
  */
    async deleteConfiguration(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/fieldconfiguration/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a [paginated](#pagination) list of all fields for a configuration.
  
  Only the fields from configurations used in company-managed (classic) projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfiguration-id-fields-get
  * @param options Request options.
  */
    async getConfigurationItems(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/fieldconfiguration/${encodeURIComponent(id)}/fields`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration issue type items.
  
  Only items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-mapping-get
  * @param options Request options.
  */
    async getConfigurationIssueTypeItems(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/fieldconfigurationscheme/mapping`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/fieldconfigurationscheme`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueFieldConfigurationSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of field configuration schemes and, for each scheme, a list of the projects that use it.
  
  The list is sorted by field configuration scheme ID. The first item contains the list of project IDs assigned to the default field configuration scheme.
  
  Only field configuration schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-get
  * @param options Request options.
  */
    async getSchemesForProjects(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/fieldconfigurationscheme/project`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Assigns a field configuration scheme to a project. If the field configuration scheme ID is `null`, the operation assigns the default field configuration scheme.
  
  Field configuration schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-field-configurations/#api-rest-api-3-fieldconfigurationscheme-project-put
  * @param options Request options.
  */
    async assignSchemeToProject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/fieldconfigurationscheme/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Screen = new IssueTypeScreenGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new IssueTypePropertyGroup(implementation, this.getGlobalErrorStrategy);
        this.Scheme = new IssueTypeSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all issue types.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issue types are only returned as follows:
  
   *  if the user has the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), all issue types are returned.
   *  if the user has the *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for one or more projects, the issue types associated with the projects the user has permission to browse are returned.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-get
  * @param options Request options.
  */
    async getTypesForUser(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/issuetype`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates an issue type and adds it to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-post
  * @param options Request options.
  */
    async createType(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issuetype`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns issue types for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in the relevant project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-project-get
  * @param options Request options.
  */
    async getTypesForProject(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetype/project`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) in a project the issue type is associated with or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-get
  * @param options Request options.
  */
    async getType(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/issuetype/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the issue type.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-put
  * @param options Request options.
  */
    async updateType(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/issuetype/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the issue type. If the issue type is in use, all uses are updated with the alternative issue type (`alternativeIssueTypeId`). A list of alternative issue types are obtained from the [Get alternative issue types](#api-rest-api-3-issuetype-id-alternatives-get) resource.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-delete
  * @param options Request options.
  */
    async deleteType(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/issuetype/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a list of issue types that can be used to replace the issue type. The alternative issue types are those assigned to the same workflow scheme, field configuration scheme, and screen scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-types/#api-rest-api-3-issuetype-id-alternatives-get
  * @param options Request options.
  */
    async getAlternativeTypes(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/issuetype/${encodeURIComponent(id)}/alternatives`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Loads an avatar for the issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST \ --user email@example.com:<api_token> \ --header 'X-Atlassian-Token: no-check' \ --header 'Content-Type: image/< image_type>' \ --data-binary "<@/path/to/file/with/your/avatar>" \ --url 'https://your-domain.atlassian.net/rest/api/3/issuetype/{issueTypeId}'This`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar, use [ Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issuetype-id-avatar2-post
  * @param options Request options.
  */
    async loadTypeAvatar(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/issuetype/${encodeURIComponent(id)}/avatar2`, queryParams), constructHeaders(body.content, { ...headers, "Content-Type": `image/${body.filetype}` }), body.content);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueTypeScreenGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new IssueTypeScreenSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class IssueTypeScreenSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of projects associated with an issue type screen scheme.
  
  Only company-managed projects associated with an issue type screen scheme are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-project-get
  * @param options Request options.
  */
    async getProjects(options) {
        const { headers, errorStrategy, issueTypeScreenSchemeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}/project`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescreenscheme`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-post
  * @param options Request options.
  */
    async createScheme(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issuetypescreenscheme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen scheme items.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-mapping-get
  * @param options Request options.
  */
    async getSchemeItems(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescreenscheme/mapping`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type screen schemes and, for each issue type screen scheme, a list of the projects that use it.
  
  Only issue type screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-get
  * @param options Request options.
  */
    async getSchemesForProjects(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescreenscheme/project`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Assigns an issue type screen scheme to a project.
  
  Issue type screen schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-project-put
  * @param options Request options.
  */
    async assignSchemeToProject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescreenscheme/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-put
  * @param options Request options.
  */
    async updateScheme(options) {
        const { body, headers, errorStrategy, issueTypeScreenSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-delete
  * @param options Request options.
  */
    async deleteScheme(options) {
        const { headers, errorStrategy, issueTypeScreenSchemeId } = options;
        const request = new Request("DELETE", `/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Appends issue type to screen scheme mappings to an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-put
  * @param options Request options.
  */
    async appendMappings(options) {
        const { body, headers, errorStrategy, issueTypeScreenSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}/mapping`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the default screen scheme of an issue type screen scheme. The default screen scheme is used for all unmapped issue types.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-default-put
  * @param options Request options.
  */
    async updateDefaultScheme(options) {
        const { body, headers, errorStrategy, issueTypeScreenSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}/mapping/default`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes issue type to screen scheme mappings from an issue type screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-screen-schemes/#api-rest-api-3-issuetypescreenscheme-issuetypescreenschemeid-mapping-remove-post
  * @param options Request options.
  */
    async removeMappings(options) {
        const { body, headers, errorStrategy, issueTypeScreenSchemeId } = options;
        const request = new Request("POST", `/rest/api/3/issuetypescreenscheme/${encodeURIComponent(issueTypeScreenSchemeId)}/mapping/remove`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueTypePropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys of the issue type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the property keys of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the property keys of any issue types associated with the projects the user has permission to browse.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-get
  * @param options Request options.
  */
    async getPropertyKeys(options) {
        const { headers, errorStrategy, issueTypeId } = options;
        const request = new Request("GET", `/rest/api/3/issuetype/${encodeURIComponent(issueTypeId)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the key and value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to get the details of any issue type.
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) to get the details of any issue types associated with the projects the user has permission to browse.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, issueTypeId, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/issuetype/${encodeURIComponent(issueTypeId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates or updates the value of the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). Use this resource to store and update data against an issue type.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, issueTypeId, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/issuetype/${encodeURIComponent(issueTypeId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes the [issue type property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-properties/#api-rest-api-3-issuetype-issuetypeid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, issueTypeId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/issuetype/${encodeURIComponent(issueTypeId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueTypeSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of issue type schemes.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescheme`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-post
  * @param options Request options.
  */
    async createScheme(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issuetypescheme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type scheme items.
  
  Only issue type scheme items used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-mapping-get
  * @param options Request options.
  */
    async getSchemeItems(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescheme/mapping`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of issue type schemes and, for each issue type scheme, a list of the projects that use it.
  
  Only issue type schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-get
  * @param options Request options.
  */
    async getSchemesForProjects(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issuetypescheme/project`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Assigns an issue type scheme to a project.
  
  If any issues in the project are assigned issue types not present in the new scheme, the operation will fail. To complete the assignment those issues must be updated to use issue types in the new scheme.
  
  Issue type schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-project-put
  * @param options Request options.
  */
    async assignToProject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescheme/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Adds issue types to an issue type scheme.
  
  The added issue types are appended to the issue types list.
  
  If any of the issue types exist in the issue type scheme, the operation fails and no issue types are added.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-put
  * @param options Request options.
  */
    async addIssueTypesToScheme(options) {
        const { body, headers, errorStrategy, issueTypeSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescheme/${encodeURIComponent(issueTypeSchemeId)}/issuetype`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Updates an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-put
  * @param options Request options.
  */
    async updateScheme(options) {
        const { body, headers, errorStrategy, issueTypeSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescheme/${encodeURIComponent(issueTypeSchemeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes an issue type scheme.
  
  Only issue type schemes used in classic projects can be deleted.
  
  Any projects assigned to the scheme are reassigned to the default issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-delete
  * @param options Request options.
  */
    async deleteScheme(options) {
        const { headers, errorStrategy, issueTypeSchemeId } = options;
        const request = new Request("DELETE", `/rest/api/3/issuetypescheme/${encodeURIComponent(issueTypeSchemeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Changes the order of issue types in an issue type scheme.
  
  The request body parameters must meet the following requirements:
  
   *  all of the issue types must belong to the issue type scheme.
   *  either `after` or `position` must be provided.
   *  the issue type in `after` must not be in the issue type list.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-move-put
  * @param options Request options.
  */
    async changeIssueTypesOrder(options) {
        const { body, headers, errorStrategy, issueTypeSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/issuetypescheme/${encodeURIComponent(issueTypeSchemeId)}/issuetype/move`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Removes an issue type from an issue type scheme.
  
  This operation cannot remove:
  
   *  any issue type used by issues.
   *  any issue types from the default issue type scheme.
   *  the last standard issue type from an issue type scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-type-schemes/#api-rest-api-3-issuetypescheme-issuetypeschemeid-issuetype-issuetypeid-delete
  * @param options Request options.
  */
    async removeIssueTypesFromScheme(options) {
        const { headers, errorStrategy, issueTypeSchemeId, issueTypeId } = options;
        const request = new Request("DELETE", `/rest/api/3/issuetypescheme/${encodeURIComponent(issueTypeSchemeId)}/issuetype/${encodeURIComponent(issueTypeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueWorklogGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new IssueWorklogPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns worklogs for an issue (ordered by created time), starting from the oldest worklog or from the worklog started on or after a date and time.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Workloads are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-get
  * @param options Request options.
  */
    async getWorklogs(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a worklog to an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Work on issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-post
  * @param options Request options.
  */
    async addWorklog(options) {
        const { body, headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-get
  * @param options Request options.
  */
    async getWorklog(options) {
        const { headers, errorStrategy, issueIdOrKey, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a worklog.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-put
  * @param options Request options.
  */
    async updateWorklog(options) {
        const { body, headers, errorStrategy, issueIdOrKey, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(id)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a worklog from an issue.
  
  Time tracking must be enabled in Jira, otherwise this operation returns an error. For more information, see [Configuring time tracking](https://confluence.atlassian.com/x/qoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any worklog or *Delete own worklogs* to delete worklogs created by the user,
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-issue-issueidorkey-worklog-id-delete
  * @param options Request options.
  */
    async deleteWorklog(options) {
        const { headers, errorStrategy, issueIdOrKey, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a list of IDs and delete timestamps for worklogs deleted after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs deleted during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-deleted-get
  * @param options Request options.
  */
    async getDeletedIds(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/worklog/deleted`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns worklog details for a list of worklog IDs.
  
  The returned list of worklogs is limited to 1000 items.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-list-post
  * @param options Request options.
  */
    async getFromIds(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/worklog/list`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of IDs and update timestamps for worklogs updated after a date and time.
  
  This resource is paginated, with a limit of 1000 worklogs per page. Each page lists worklogs from oldest to youngest. If the number of items in the date range exceeds 1000, `until` indicates the timestamp of the youngest item on the page. Also, `nextPage` provides the URL for the next page of worklogs. The `lastPage` parameter is set to true on the last page of worklogs.
  
  This resource does not return worklogs updated during the minute preceding the request.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, worklogs are only returned where either of the following is true:
  
   *  the worklog is set as *Viewable by All Users*.
   *  the user is a member of a project role or group with permission to view the worklog.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklogs/#api-rest-api-3-worklog-updated-get
  * @param options Request options.
  */
    async getUpdatedIds(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/worklog/updated`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueWorklogPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all properties for a worklog.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-get
  * @param options Request options.
  */
    async getKeys(options) {
        const { headers, errorStrategy, issueIdOrKey, worklogId } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(worklogId)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, issueIdOrKey, worklogId, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(worklogId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of a worklog property. Use this operation to store custom data against the worklog.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all worklogs*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any worklog or *Edit own worklogs* to update worklogs created by the user.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, issueIdOrKey, worklogId, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(worklogId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a worklog property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the worklog has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-worklog-properties/#api-rest-api-3-issue-issueidorkey-worklog-worklogid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, issueIdOrKey, worklogId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/worklog/${encodeURIComponent(worklogId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueAttachmentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Metadata = new IssueAttachmentMetadataGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deletes an attachment from an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the project holding the issue containing the attachment:
  
   *  *Delete own attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by the calling user.
   *  *Delete all attachments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete an attachment created by any user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-delete
  * @param options Request options.
  */
    async deleteAttachment(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/attachment/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Adds one or more attachments to an issue. Attachments are posted as multipart/form-data ([RFC 1867](https://www.ietf.org/rfc/rfc1867.txt)).
  
  Note that:
  
   *  The request must have a `X-Atlassian-Token: no-check` header, if not it is blocked. See [Special headers](#special-request-headers) for more information.
   *  The name of the multipart/form-data parameter that contains the attachments must be `file`.
  
  The following examples upload a file called *myfile.txt* to the issue *TEST-123*:
  
  #### curl ####
  
      curl --location --request POST 'https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments'
       -u 'email@example.com:<api_token>'
       -H 'X-Atlassian-Token: no-check'
       --form 'file=@"myfile.txt"'
  
  #### Node.js ####
  
      // This code sample uses the 'node-fetch' and 'form-data' libraries:
       // https://www.npmjs.com/package/node-fetch
       // https://www.npmjs.com/package/form-data
       const fetch = require('node-fetch');
       const FormData = require('form-data');
       const fs = require('fs');
      
       const filePath = 'myfile.txt';
       const form = new FormData();
       const stats = fs.statSync(filePath);
       const fileSizeInBytes = stats.size;
       const fileStream = fs.createReadStream(filePath);
      
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       fetch('https://your-domain.atlassian.net/rest/api/3/issue/TEST-123/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Authorization': `Basic ${Buffer.from(
                   'email@example.com:'
               ).toString('base64')}`,
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       })
           .then(response => {
               console.log(
                   `Response: ${response.status} ${response.statusText}`
               );
               return response.text();
           })
           .then(text => console.log(text))
           .catch(err => console.error(err));
  
  #### Java ####
  
      // This code sample uses the  'Unirest' library:
       // http://unirest.io/java.html
       HttpResponse response = Unirest.post("https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments")
               .basicAuth("email@example.com", "")
               .header("Accept", "application/json")
               .header("X-Atlassian-Token", "no-check")
               .field("file", new File("myfile.txt"))
               .asJson();
      
               System.out.println(response.getBody());
  
  #### Python ####
  
      # This code sample uses the 'requests' library:
       # http://docs.python-requests.org
       import requests
       from requests.auth import HTTPBasicAuth
       import json
      
       url = "https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments"
      
       auth = HTTPBasicAuth("email@example.com", "")
      
       headers = {
          "Accept": "application/json",
          "X-Atlassian-Token": "no-check"
       }
      
       response = requests.request(
          "POST",
          url,
          headers = headers,
          auth = auth,
          files = {
               "file": ("myfile.txt", open("myfile.txt","rb"), "application-type")
          }
       )
      
       print(json.dumps(json.loads(response.text), sort_keys=True, indent=4, separators=(",", ": ")))
  
  #### PHP ####
  
      // This code sample uses the 'Unirest' library:
       // http://unirest.io/php.html
       Unirest\Request::auth('email@example.com', '');
      
       $headers = array(
         'Accept' => 'application/json',
         'X-Atlassian-Token' => 'no-check'
       );
      
       $parameters = array(
         'file' => File::add('myfile.txt')
       );
      
       $response = Unirest\Request::post(
         'https://your-domain.atlassian.net/rest/api/2/issue/{issueIdOrKey}/attachments',
         $headers,
         $parameters
       );
      
       var_dump($response)
  
  #### Forge ####
  
      // This sample uses Atlassian Forge and the `form-data` library.
       // https://developer.atlassian.com/platform/forge/
       // https://www.npmjs.com/package/form-data
       import api from "@forge/api";
       import FormData from "form-data";
      
       const form = new FormData();
       form.append('file', fileStream, {knownLength: fileSizeInBytes});
      
       const response = await api.asApp().requestJira('/rest/api/2/issue/{issueIdOrKey}/attachments', {
           method: 'POST',
           body: form,
           headers: {
               'Accept': 'application/json',
               'X-Atlassian-Token': 'no-check'
           }
       });
      
       console.log(`Response: ${response.status} ${response.statusText}`);
       console.log(await response.json());
  
  Tip: Use a client library. Many client libraries have classes for handling multipart POST operations. For example, in Java, the Apache HTTP Components library provides a [MultiPartEntity](http://hc.apache.org/httpcomponents-client-ga/httpmime/apidocs/org/apache/http/entity/mime/MultipartEntity.html) class for multipart POST operations.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse Projects* and *Create attachments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/#api-rest-api-3-issue-issueIdOrKey-attachments-post
  * @param options Request options.
  */
    async addAttachments(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const formBody = new FormData();
        formBody.setBufferImplementation(this.implementation);
        body.forEach((x) => {
            formBody.append("file", new Blob(this.implementation, [x.content], {}), x.fileName);
        });
        const bodyBlob = formBody.getBlob();
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/attachments`, constructHeaders(bodyBlob, headers), bodyBlob);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the contents of an attachment. A `Range` header can be set to define a range of bytes within the attachment to download. See the [HTTP Range header standard](https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Range) for details.
  
  To return a thumbnail of the attachment, use [Get attachment thumbnail](#api-rest-api-3-attachment-thumbnail-id-get).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-content-id-get
  * @param options Request options.
  */
    async getAttachmentContent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/attachment/content/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        const parseResponse = async (res) => {
            if (res.headers.get("content-type") === "text/plain") {
                return await res.text();
            }
            return await res.arrayBuffer();
        };
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, parseResponse);
    }
}
class IssueAttachmentMetadataGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the metadata for an attachment. Note that the attachment itself is not returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-get
  * @param options Request options.
  */
    async getMetadata(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/attachment/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive, and metadata for the attachment itself. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned and metadata for the ZIP archive. Currently, only the ZIP archive format is supported.
  
  Use this operation to retrieve data that is presented to the user, as this operation returns the metadata for the attachment itself, such as the attachment's ID and name. Otherwise, use [ Get contents metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-raw-get), which only returns the metadata for the attachment's contents.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-expand-human-get
  * @param options Request options.
  */
    async getMetadataForExpandedAttachment(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/attachment/${encodeURIComponent(id)}/expand/human`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the metadata for the contents of an attachment, if it is an archive. For example, if the attachment is a ZIP archive, then information about the files in the archive is returned. Currently, only the ZIP archive format is supported.
  
  Use this operation if you are processing the data without presenting it to the user, as this operation only returns the metadata for the contents of the attachment. Otherwise, to retrieve data to present to the user, use [ Get all metadata for an expanded attachment](#api-rest-api-3-attachment-id-expand-human-get) which also returns the metadata for the attachment itself, such as the attachment's ID and name.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** For the issue containing the attachment:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If attachments are added in private comments, the comment-level restriction will be applied.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-id-expand-raw-get
  * @param options Request options.
  */
    async getContentsMetadataForExpandedAttachment(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/attachment/${encodeURIComponent(id)}/expand/raw`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueCommentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new IssueCommentPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a [paginated](#pagination) list of comments specified by a list of comment IDs.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are returned where the user:
  
   *  has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-comment-list-post
  * @param options Request options.
  */
    async getCommentsByIds(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/comment/list`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all comments for an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Comments are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-get
  * @param options Request options.
  */
    async getComments(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/comment`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a comment to an issue.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Add comments* [ project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-post
  * @param options Request options.
  */
    async addComment(options) {
        const { body, headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/comment`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the comment.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-get
  * @param options Request options.
  */
    async getComment(options) {
        const { headers, errorStrategy, issueIdOrKey, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Edit all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to update any comment or *Edit own comments* to update comment created by the user.
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-put
  * @param options Request options.
  */
    async updateComment(options) {
        const { body, headers, errorStrategy, issueIdOrKey, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(id)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a comment.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue containing the comment is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  *Delete all comments*[ project permission](https://confluence.atlassian.com/x/yodKLg) to delete any comment or *Delete own comments* to delete comment created by the user,
   *  If the comment has visibility restrictions, the user belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comments/#api-rest-api-3-issue-issueidorkey-comment-id-delete
  * @param options Request options.
  */
    async deleteComment(options) {
        const { headers, errorStrategy, issueIdOrKey, id } = options;
        const request = new Request("DELETE", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/comment/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueCommentPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all the properties of a comment.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-get
  * @param options Request options.
  */
    async getKeys(options) {
        const { headers, errorStrategy, commentId } = options;
        const request = new Request("GET", `/rest/api/3/comment/${encodeURIComponent(commentId)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of a comment property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, commentId, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/comment/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates or updates the value of a property for a comment. Use this resource to store custom data against a comment.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to create or update the value of a property on a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, commentId, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/comment/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a comment property.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Edit All Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from any comment.
   *  *Edit Own Comments* [project permission](https://confluence.atlassian.com/x/yodKLg) to delete a property from a comment created by the user.
  
  Also, when the visibility of a comment is restricted to a role or group the user must be a member of that role or group.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-comment-properties/#api-rest-api-3-comment-commentid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, commentId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/comment/${encodeURIComponent(commentId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueMetadataGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns details of projects, issue types within projects, and, when requested, the create screen fields for each issue type for the user. Use the information to populate the requests in [ Create issue](#api-rest-api-3-issue-post) and [Create issues](#api-rest-api-3-issue-bulk-post).
  
  Deprecated, see [Create Issue Meta Endpoint Deprecation Notice](https://developer.atlassian.com/cloud/jira/platform/changelog/#CHANGE-1304).
  
  The request can be restricted to specific projects or issue types using the query parameters. The response will contain information for the valid projects, issue types, or project and issue type combinations requested. Note that invalid project, issue type, or project and issue type combinations do not generate errors.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Create issues* [project permission](https://confluence.atlassian.com/x/yodKLg) in the requested projects.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-createmeta-get
  * @param options Request options.
  */
    async getCreateMetadata(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/createmeta`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the edit screen fields for an issue that are visible to and editable by the user. Use the information to populate the requests in [Edit issue](#api-rest-api-3-issue-issueIdOrKey-put).
  
  This endpoint will check for these conditions:
  
  1.  Field is available on a field screen - through screen, screen scheme, issue type screen scheme, and issue type scheme configuration. `overrideScreenSecurity=true` skips this condition.
  2.  Field is visible in the [field configuration](https://support.atlassian.com/jira-cloud-administration/docs/change-a-field-configuration/). `overrideScreenSecurity=true` skips this condition.
  3.  Field is shown on the issue: each field has different conditions here. For example: Attachment field only shows if attachments are enabled. Assignee only shows if user has permissions to assign the issue.
  4.  If a field is custom then it must have valid custom field context, applicable for its project and issue type. All system fields are assumed to have context in all projects and all issue types.
  5.  Issue has a project, issue type, and status defined.
  6.  Issue is assigned to a valid workflow, and the current status has assigned a workflow step. `overrideEditableFlag=true` skips this condition.
  7.  The current workflow step is editable. This is true by default, but [can be disabled by setting](https://support.atlassian.com/jira-cloud-administration/docs/use-workflow-properties/) the `jira.issue.editable` property to `false`. `overrideEditableFlag=true` skips this condition.
  8.  User has [Edit issues permission](https://support.atlassian.com/jira-cloud-administration/docs/permissions-for-company-managed-projects/).
  9.  Workflow permissions allow editing a field. This is true by default but [can be modified](https://support.atlassian.com/jira-cloud-administration/docs/use-workflow-properties/) using `jira.permission.*` workflow properties.
  
  Fields hidden using [Issue layout settings page](https://support.atlassian.com/jira-software-cloud/docs/configure-field-layout-in-the-issue-view/) remain editable.
  
  Connect apps having an app user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), and Forge apps acting on behalf of users with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), can return additional details using:
  
   *  `overrideScreenSecurity` When this flag is `true`, then this endpoint skips checking if fields are available through screens, and field configuration (conditions 1. and 2. from the list above).
   *  `overrideEditableFlag` When this flag is `true`, then this endpoint skips checking if workflow is present and if the current step is editable (conditions 6. and 7. from the list above).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note: For any fields to be editable the user must have the *Edit issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-editmeta-get
  * @param options Request options.
  */
    async getEditMetadata(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/editmeta`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssuePropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the URLs and keys of an issue's properties.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Property details are only returned where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-get
  * @param options Request options.
  */
    async getKeys(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the key and value of an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, issueIdOrKey, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of an issue's property. Use this resource to store custom data against an issue.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, issueIdOrKey, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes an issue's property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Edit issues* [project permissions](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-properties/#api-rest-api-3-issue-issueidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, issueIdOrKey, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueLinkGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Remote = new IssueLinkRemoteGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new IssueLinkTypeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a link between two issues. Use this operation to indicate a relationship between two issues and optionally add a comment to the from (outward) issue. To use this resource the site must have [Issue Linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This resource returns nothing on the creation of an issue link. To obtain the ID of the issue link, use `https://your-domain.atlassian.net/rest/api/3/issue/[linked issue key]?fields=issuelinks`.
  
  If the link request duplicates a link, the response indicates that the issue link was created. If the request included a comment, the comment is added.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues to be linked,
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) on the project containing the from (outward) issue,
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  If the comment has visibility restrictions, belongs to the group or has the role visibility is restricted to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-post
  * @param options Request options.
  */
    async createLink(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issueLink`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse project* [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the linked issues.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-linkid-get
  * @param options Request options.
  */
    async getLink(options) {
        const { headers, errorStrategy, linkId } = options;
        const request = new Request("GET", `/rest/api/3/issueLink/${encodeURIComponent(linkId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes an issue link.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  Browse project [project permission](https://confluence.atlassian.com/x/yodKLg) for all the projects containing the issues in the link.
   *  *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one of the projects containing issues in the link.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, permission to view both of the issues.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-links/#api-rest-api-3-issuelink-linkid-delete
  * @param options Request options.
  */
    async deleteLink(options) {
        const { headers, errorStrategy, linkId } = options;
        const request = new Request("DELETE", `/rest/api/3/issueLink/${encodeURIComponent(linkId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueLinkRemoteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the remote issue links for an issue. When a remote issue link global ID is provided the record with that global ID is returned, otherwise all remote issue links are returned. Where a global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-get
  * @param options Request options.
  */
    async getLinks(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates or updates a remote issue link for an issue.
  
  If a `globalId` is provided and a remote issue link with that global ID is found it is updated. Any fields without values in the request are set to null. Otherwise, the remote issue link is created.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-post
  * @param options Request options.
  */
    async createOrUpdateLink(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the remote issue link from the issue using the link's global ID. Where the global ID includes reserved URL characters these must be escaped in the request. For example, pass `system=http://www.mycompany.com/support&id=1` as `system%3Dhttp%3A%2F%2Fwww.mycompany.com%2Fsupport%26id%3D1`.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is implemented, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-delete
  * @param options Request options.
  */
    async deleteLinkByGlobalId(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a remote issue link for an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-get
  * @param options Request options.
  */
    async getLink(options) {
        const { headers, errorStrategy, issueIdOrKey, linkId } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink/${encodeURIComponent(linkId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a remote issue link for an issue.
  
  Note: Fields without values in the request are set to null.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-put
  * @param options Request options.
  */
    async updateLink(options) {
        const { body, headers, errorStrategy, issueIdOrKey, linkId } = options;
        const request = new Request("PUT", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink/${encodeURIComponent(linkId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a remote issue link from an issue.
  
  This operation requires [issue linking to be active](https://confluence.atlassian.com/x/yoXKM).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects*, *Edit issues*, and *Link issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-remote-links/#api-rest-api-3-issue-issueidorkey-remotelink-linkid-delete
  * @param options Request options.
  */
    async deleteLink(options) {
        const { headers, errorStrategy, issueIdOrKey, linkId } = options;
        const request = new Request("DELETE", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/remotelink/${encodeURIComponent(linkId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueLinkTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of all issue link types.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-get
  * @param options Request options.
  */
    async getTypes(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/issueLinkType`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates an issue link type. Use this operation to create descriptions of the reasons why issues are linked. The issue link type consists of a name and descriptions for a link's inward and outward relationships.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-post
  * @param options Request options.
  */
    async createType(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/issueLinkType`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project in the site.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-get
  * @param options Request options.
  */
    async getType(options) {
        const { headers, errorStrategy, issueLinkTypeId } = options;
        const request = new Request("GET", `/rest/api/3/issueLinkType/${encodeURIComponent(issueLinkTypeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-put
  * @param options Request options.
  */
    async updateType(options) {
        const { body, headers, errorStrategy, issueLinkTypeId } = options;
        const request = new Request("PUT", `/rest/api/3/issueLinkType/${encodeURIComponent(issueLinkTypeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes an issue link type.
  
  To use this operation, the site must have [issue linking](https://confluence.atlassian.com/x/yoXKM) enabled.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-link-types/#api-rest-api-3-issuelinktype-issuelinktypeid-delete
  * @param options Request options.
  */
    async deleteType(options) {
        const { headers, errorStrategy, issueLinkTypeId } = options;
        const request = new Request("DELETE", `/rest/api/3/issueLinkType/${encodeURIComponent(issueLinkTypeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueTransitionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns either all transitions or a transition that can be performed by the user on an issue, based on the issue's status.
  
  Note, if a request is made for a transition that does not exist or cannot be performed on the issue, given its status, the response will return any empty transitions list.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required: A list or transition is returned only when the user has:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  However, if the user does not have the *Transition issues* [ project permission](https://confluence.atlassian.com/x/yodKLg) the response will not list any transitions.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-transitions-get
  * @param options Request options.
  */
    async getTransitions(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/transitions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Performs an issue transition and, if the transition has a screen, updates the fields from the transition screen.
  
  sortByCategory To update the fields on the transition screen, specify the fields in the `fields` or `update` parameters in the request body. Get details about the fields using [ Get transitions](#api-rest-api-3-issue-issueIdOrKey-transitions-get) with the `transitions.fields` expand.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* and *Transition issues* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issues/#api-rest-api-3-issue-issueidorkey-transitions-post
  * @param options Request options.
  */
    async performTransition(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/transitions`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueVoteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns details about the votes on an issue.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  
  Note that users with the necessary permissions for this operation but without the *View voters and watchers* project permissions are not returned details in the `voters` field.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-get
  * @param options Request options.
  */
    async getVotes(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/votes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds the user's vote to an issue. This is the equivalent of the user clicking *Vote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-post
  * @param options Request options.
  */
    async addVote(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/votes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a user's vote from an issue. This is the equivalent of the user clicking *Unvote* on an issue in Jira.
  
  This operation requires the **Allow users to vote on issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-votes/#api-rest-api-3-issue-issueidorkey-votes-delete
  * @param options Request options.
  */
    async deleteVote(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("DELETE", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/votes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueWatcherGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the watchers for an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is ini
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To see details of users on the watchlist other than themselves, *View voters and watchers* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-get
  * @param options Request options.
  */
    async getWatchers(options) {
        const { headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/watchers`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user as a watcher of an issue by passing the account ID of the user. For example, `"5b10ac8d82e05b22cc7d4ef5"`. If no user is specified the calling user is added.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To add users other than themselves to the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-post
  * @param options Request options.
  */
    async addWatcher(options) {
        const { body, headers, errorStrategy, issueIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/watchers`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a user as a watcher of an issue.
  
  This operation requires the **Allow users to watch issues** option to be *ON*. This option is set in General configuration for Jira. See [Configuring Jira application options](https://confluence.atlassian.com/x/uYXKM) for details.
  
  **[Permissions](#permissions) required:**
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
   *  To remove users other than themselves from the watchlist, *Manage watcher list* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-watchers/#api-rest-api-3-issue-issueidorkey-watchers-delete
  * @param options Request options.
  */
    async deleteWatcher(options) {
        const { headers, errorStrategy, issueIdOrKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/issue/${encodeURIComponent(issueIdOrKey)}/watchers`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class IssueSearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Checks whether one or more issues would be returned by one or more JQL queries.
  
  **[Permissions](#permissions) required:** None, however, issues are only matched against JQL queries where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that the issue is in.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-jql-match-post
  * @param options Request options.
  */
    async checkAgainstJql(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/jql/match`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ).
  
  There is a [GET](#api-rest-api-3-search-get) version of this resource that can be used for smaller JQL query expressions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-search-get
  * @param options Request options.
  * @deprecated
  */
    async searchByJql(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/search`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Searches for issues using [JQL](https://confluence.atlassian.com/x/egORLQ). Recent updates might not be immediately visible in the returned search results. If you need [read-after-write](https://developer.atlassian.com/cloud/jira/platform/search-and-reconcile/) consistency, you can utilize the `reconcileIssues` parameter to ensure stronger consistency assurances. This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Issues are included in the response where the user has:
  
   *  *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the issue.
   *  If [issue-level security](https://confluence.atlassian.com/x/J4lKLg) is configured, issue-level security permission to view the issue.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-search/#api-rest-api-3-search-jql-post
  * @param options Request options.
  */
    async searchByJqlEnhancedSearch(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/search/jql`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueResolutionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of all issue resolution values.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-resolutions/#api-rest-api-3-resolution-get
  * @param options Request options.
  * @deprecated
  */
    async getResolutions(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/resolution`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an issue resolution value.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-resolutions/#api-rest-api-3-resolution-id-get
  * @param options Request options.
  */
    async getResolution(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/resolution/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueSecurityGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new IssueSecuritySchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns issue security level members.
  
  Only issue security level members in context of classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-issuesecurityschemes-issuesecurityschemeid-members-get
  * @param options Request options.
  */
    async getMembers(options) {
        const { headers, errorStrategy, issueSecuritySchemeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/issuesecurityschemes/${encodeURIComponent(issueSecuritySchemeId)}/members`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns details of an issue security level.
  
  Use [Get issue security scheme](#api-rest-api-3-issuesecurityschemes-id-get) to obtain the IDs of issue security levels associated with the issue security scheme.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-level/#api-rest-api-3-securitylevel-id-get
  * @param options Request options.
  */
    async getLevel(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/securitylevel/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueSecuritySchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all [issue security schemes](https://confluence.atlassian.com/x/J4lKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/issuesecurityschemes`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an issue security scheme along with its security levels.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project that uses the requested issue security scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-security-schemes/#api-rest-api-3-issuesecurityschemes-id-get
  * @param options Request options.
  */
    async getScheme(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/issuesecurityschemes/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueNotificationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new IssueNotificationSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class IssueNotificationSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of [notification schemes](https://confluence.atlassian.com/x/8YdKLg) ordered by the display name.
  
  *Note that you should allow for events without recipients to appear in responses.*
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user must have permission to administer at least one project associated with a notification scheme for it to be returned.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/notificationscheme`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [notification scheme](https://confluence.atlassian.com/x/8YdKLg), including the list of events and the recipients who will receive notifications for those events.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user must have permission to administer at least one project associated with the notification scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-notification-schemes/#api-rest-api-3-notificationscheme-id-get
  * @param options Request options.
  */
    async getScheme(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/notificationscheme/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class IssueNavigatorGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the default issue navigator columns.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-get
  * @param options Request options.
  */
    async getDefaultColumns(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/settings/columns`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the default issue navigator columns.
  
  The `columns` parameter accepts a navigable field value and is expressed as HTML form data. To specify multiple columns, pass multiple `columns` parameters. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/settings/columns`
  
  If no column details are sent, then all default columns are removed.
  
  A navigable field is one that can be used as a column on the issue navigator. Find details of navigable issue columns using [Get fields](#api-rest-api-3-field-get).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-navigator-settings/#api-rest-api-3-settings-columns-put
  * @param options Request options.
  */
    async setDefaultColumns(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/settings/columns`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class AvatarGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the default project, issue type or priority avatar image.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-get
  * @param options Request options.
  */
    async getImageByType(options) {
        const { headers, errorStrategy, type, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/universal_avatar/view/type/${encodeURIComponent(type)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a project, issue type or priority avatar image by ID.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  For system avatars, none.
   *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  For priority avatars, none.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-avatar-id-get
  * @param options Request options.
  */
    async getImageById(options) {
        const { headers, errorStrategy, type, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/universal_avatar/view/type/${encodeURIComponent(type)}/avatar/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the avatar image for a project, issue type or priority.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  For system avatars, none.
   *  For custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  For custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  For priority avatars, none.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-view-type-type-owner-entityid-get
  * @param options Request options.
  */
    async getImageByOwner(options) {
        const { headers, errorStrategy, type, entityId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/universal_avatar/view/type/${encodeURIComponent(type)}/owner/${encodeURIComponent(entityId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the system and custom avatars for a project, issue type or priority.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  for custom project avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the avatar belongs to.
   *  for custom issue type avatars, *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for at least one project the issue type is used in.
   *  for system avatars, none.
   *  for priority avatars, none.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-get
  * @param options Request options.
  */
    async getAvatars(options) {
        const { headers, errorStrategy, type, entityId } = options;
        const request = new Request("GET", `/rest/api/3/universal_avatar/type/${encodeURIComponent(type)}/owner/${encodeURIComponent(entityId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Loads a custom avatar for a project or issue type.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/universal_avatar/type/{type}/owner/{entityId}'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use:
  
   *  [Update issue type](#api-rest-api-3-issuetype-id-put) to set it as the issue type's displayed avatar.
   *  [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-entityid-post
  * @param options Request options.
  */
    async loadAvatar(options) {
        const { body, headers, errorStrategy, type, entityId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/universal_avatar/type/${encodeURIComponent(type)}/owner/${encodeURIComponent(entityId)}`, queryParams), constructHeaders(body.content, { ...headers, "Content-Type": `image/${body.filetype}` }), body.content);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes an avatar from a project, issue type or priority.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-avatars/#api-rest-api-3-universal-avatar-type-type-owner-owningobjectid-avatar-id-delete
  * @param options Request options.
  */
    async deleteAvatar(options) {
        const { headers, errorStrategy, type, owningObjectId, id } = options;
        const request = new Request("DELETE", `/rest/api/3/universal_avatar/type/${encodeURIComponent(type)}/owner/${encodeURIComponent(owningObjectId)}/avatar/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ProjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Avatar = new ProjectAvatarGroup(implementation, this.getGlobalErrorStrategy);
        this.Component = new ProjectComponentGroup(implementation, this.getGlobalErrorStrategy);
        this.Role = new ProjectRoleGroup(implementation, this.getGlobalErrorStrategy);
        this.Version = new ProjectVersionGroup(implementation, this.getGlobalErrorStrategy);
        this.IssueType = new ProjectIssueTypeGroup(implementation, this.getGlobalErrorStrategy);
        this.Validation = new ProjectValidationGroup(implementation, this.getGlobalErrorStrategy);
        this.Type = new ProjectTypeGroup(implementation, this.getGlobalErrorStrategy);
        this.Category = new ProjectCategoryGroup(implementation, this.getGlobalErrorStrategy);
        this.Notification = new ProjectNotificationGroup(implementation, this.getGlobalErrorStrategy);
        this.Permission = new ProjectPermissionGroup(implementation, this.getGlobalErrorStrategy);
        this.Security = new ProjectSecurityGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new ProjectPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Deletes a project asynchronously.
  
  This operation is:
  
   *  transactional, that is, if part of the delete fails the project is not deleted.
   *  [asynchronous](#async). Follow the `location` link in the response to determine the status of the task and use [Get task](#api-rest-api-3-task-taskId-get) to obtain subsequent updates.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-delete-post
  * @param options Request options.
  */
    async deleteProjectAsync(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/delete`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Restores a project that has been archived or placed in the Jira recycle bin.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)for Company managed projects.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project for Team managed projects.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-restore-post
  * @param options Request options.
  */
    async restoreDeletedProject(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("POST", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/restore`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a project based on a project type template, as shown in the following table:
  
  | Project Type Key | Project Template Key |
  |--|--|
  | `business` | `com.atlassian.jira-core-project-templates:jira-core-simplified-content-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-document-approval`, `com.atlassian.jira-core-project-templates:jira-core-simplified-lead-tracking`, `com.atlassian.jira-core-project-templates:jira-core-simplified-process-control`, `com.atlassian.jira-core-project-templates:jira-core-simplified-procurement`, `com.atlassian.jira-core-project-templates:jira-core-simplified-project-management`, `com.atlassian.jira-core-project-templates:jira-core-simplified-recruitment`, `com.atlassian.jira-core-project-templates:jira-core-simplified-task-tracking` |
  | `service_desk` | `com.atlassian.servicedesk:simplified-it-service-management`, `com.atlassian.servicedesk:simplified-general-service-desk-it`, `com.atlassian.servicedesk:simplified-general-service-desk-business`, `com.atlassian.servicedesk:simplified-external-service-desk`, `com.atlassian.servicedesk:simplified-hr-service-desk`, `com.atlassian.servicedesk:simplified-facilities-service-desk`, `com.atlassian.servicedesk:simplified-legal-service-desk`, `com.atlassian.servicedesk:simplified-analytics-service-desk`, `com.atlassian.servicedesk:simplified-marketing-service-desk`, `com.atlassian.servicedesk:simplified-design-service-desk`, `com.atlassian.servicedesk:simplified-sales-service-desk`, `com.atlassian.servicedesk:simplified-blank-project-business`, `com.atlassian.servicedesk:simplified-blank-project-it`, `com.atlassian.servicedesk:simplified-finance-service-desk`, `com.atlassian.servicedesk:next-gen-it-service-desk`, `com.atlassian.servicedesk:next-gen-hr-service-desk`, `com.atlassian.servicedesk:next-gen-legal-service-desk`, `com.atlassian.servicedesk:next-gen-marketing-service-desk`, `com.atlassian.servicedesk:next-gen-facilities-service-desk`, `com.atlassian.servicedesk:next-gen-general-it-service-desk`, `com.atlassian.servicedesk:next-gen-general-business-service-desk`, `com.atlassian.servicedesk:next-gen-analytics-service-desk`, `com.atlassian.servicedesk:next-gen-finance-service-desk`, `com.atlassian.servicedesk:next-gen-design-service-desk`, `com.atlassian.servicedesk:next-gen-sales-service-desk` |
  | `software` | `com.pyxis.greenhopper.jira:gh-simplified-agility-kanban`, `com.pyxis.greenhopper.jira:gh-simplified-agility-scrum`, `com.pyxis.greenhopper.jira:gh-simplified-basic`, `com.pyxis.greenhopper.jira:gh-simplified-kanban-classic`, `com.pyxis.greenhopper.jira:gh-simplified-scrum-classic` |
  The project types are available according to the installed Jira features as follows:
  
   *  Jira Core, the default, enables `business` projects.
   *  Jira Service Management enables `service_desk` projects.
   *  Jira Software enables `software` projects.
  
  To determine which features are installed, go to **Jira settings** > **Apps** > **Manage apps** and review the System Apps list. To add Jira Software or Jira Service Management into a JIRA instance, use **Jira settings** > **Apps** > **Finding new apps**. For more information, see [ Managing add-ons](https://confluence.atlassian.com/x/S31NLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-post
  * @param options Request options.
  */
    async createProject(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of projects visible to the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** Projects are returned only where the user has one of:
  
   *  *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-search-get
  * @param options Request options.
  */
    async getProjects(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/project/search`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the [project details](https://confluence.atlassian.com/x/ahLpNw) for a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-get
  * @param options Request options.
  */
    async getProject(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the [project details](https://confluence.atlassian.com/x/ahLpNw) of a project.
  
  All parameters are optional in the body of the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-put
  * @param options Request options.
  */
    async updateProject(options) {
        const { body, headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a project.
  
  You can't delete a project if it's archived. To delete an archived project, restore the project and then delete it. To restore a project, use the Jira UI.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-delete
  * @param options Request options.
  */
    async deleteProject(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the valid statuses for a project. The statuses are grouped by issue type, as each project has a set of valid issue types and each issue type has a set of valid statuses.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectidorkey-statuses-get
  * @param options Request options.
  */
    async getStatuses(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/statuses`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectAvatarGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Sets the avatar displayed for a project.
  
  Use [Load project avatar](#api-rest-api-3-project-projectIdOrKey-avatar2-post) to store avatars against the project, before using this operation to set the displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar-put
  * @param options Request options.
  */
    async setAvatar(options) {
        const { body, headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("PUT", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/avatar`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a custom avatar from a project. Note that system avatars cannot be deleted.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar-id-delete
  * @param options Request options.
  */
    async deleteAvatar(options) {
        const { headers, errorStrategy, projectIdOrKey, id } = options;
        const request = new Request("DELETE", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/avatar/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Loads an avatar for a project.
  
  Specify the avatar's local file location in the body of the request. Also, include the following headers:
  
   *  `X-Atlassian-Token: no-check` To prevent XSRF protection blocking the request, for more information see [Special Headers](#special-request-headers).
   *  `Content-Type: image/image type` Valid image types are JPEG, GIF, or PNG.
  
  For example:
  `curl --request POST `
  
  `--user email@example.com:<api_token> `
  
  `--header 'X-Atlassian-Token: no-check' `
  
  `--header 'Content-Type: image/< image_type>' `
  
  `--data-binary "<@/path/to/file/with/your/avatar>" `
  
  `--url 'https://your-domain.atlassian.net/rest/api/3/project/{projectIdOrKey}/avatar2'`
  
  The avatar is cropped to a square. If no crop parameters are specified, the square originates at the top left of the image. The length of the square's sides is set to the smaller of the height or width of the image.
  
  The cropped image is then used to create avatars of 16x16, 24x24, 32x32, and 48x48 in size.
  
  After creating the avatar use [Set project avatar](#api-rest-api-3-project-projectIdOrKey-avatar-put) to set it as the project's displayed avatar.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatar2-post
  * @param options Request options.
  */
    async loadAvatar(options) {
        const { body, headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/avatar2`, queryParams), constructHeaders(body.content, { ...headers, "Content-Type": `image/${body.filetype}` }), body.content);
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all project avatars, grouped by system and custom avatars.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-avatars/#api-rest-api-3-project-projectidorkey-avatars-get
  * @param options Request options.
  */
    async getAvatars(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/avatars`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectComponentGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Creates a component. Use components to provide containers for issues within a project. Use components to provide containers for issues within a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the component is created or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-post
  * @param options Request options.
  */
    async createComponent(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/component`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for project containing the component.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-get
  * @param options Request options.
  */
    async getComponent(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/component/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a component. Any fields included in the request are overwritten. If `leadAccountId` is an empty string ("") the component lead is removed.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-put
  * @param options Request options.
  */
    async updateComponent(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/component/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a component.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the component or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-delete
  * @param options Request options.
  */
    async deleteComponent(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/component/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the counts of issues assigned to the component.
  
  This operation can be accessed anonymously.
  
  **Deprecation notice:** The required OAuth 2.0 scopes will be updated on June 15, 2024.
  
   *  **Classic**: `read:jira-work`
   *  **Granular**: `read:field:jira`, `read:project.component:jira`
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-component-id-relatedissuecounts-get
  * @param options Request options.
  */
    async getIssueCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/component/${encodeURIComponent(id)}/relatedIssueCounts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of all components in a project. See the [Get project components](#api-rest-api-3-project-projectIdOrKey-components-get) resource if you want to get a full list of versions without pagination.
  
  If your project uses Compass components, this API will return a list of Compass components that are linked to issues in that project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-project-projectidorkey-component-get
  * @param options Request options.
  */
    async getComponentsPaginated(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/component`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all components in a project. See the [Get project components paginated](#api-rest-api-3-project-projectIdOrKey-component-get) resource if you want to get a full list of components with pagination.
  
  If your project uses Compass components, this API will return a paginated list of Compass components that are linked to issues in that project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-components/#api-rest-api-3-project-projectidorkey-components-get
  * @param options Request options.
  */
    async getComponents(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/components`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectRoleGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Actor = new ProjectRoleActorGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of [project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) for the project returning the name and self URL for each role.
  
  Note that all project roles are shared with all projects in Jira Cloud. See [Get all project roles](#api-rest-api-3-role-get) for more information.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for any project on the site or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-role-get
  * @param options Request options.
  */
    async getRolesForProject(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/role`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a project role's details and actors associated with the project. The list of actors is sorted by display name.
  
  To check whether a user belongs to a role based on their group memberships, use [Get user](#api-rest-api-3-user-get) with the `groups` expand parameter selected. Then check whether the user keys and groups match with the actors returned for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-role-id-get
  * @param options Request options.
  */
    async getRoleForProject(options) {
        const { headers, errorStrategy, projectIdOrKey, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/role/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all [project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) and the details for each role. Note that the list of project roles is common to all projects.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-project-projectidorkey-roledetails-get
  * @param options Request options.
  */
    async getDetails(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/roledetails`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets a list of all project roles, complete with project role details and default actors.
  
  ### About project roles ###
  
  [Project roles](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/) are a flexible way to to associate users and groups with projects. In Jira Cloud, the list of project roles is shared globally with all projects, but each project can have a different set of actors associated with it (unlike groups, which have the same membership throughout all Jira applications).
  
  Project roles are used in [permission schemes](#api-rest-api-3-permissionscheme-get), [email notification schemes](#api-rest-api-3-notificationscheme-get), [issue security levels](#api-rest-api-3-issuesecurityschemes-get), [comment visibility](#api-rest-api-3-comment-list-post), and workflow conditions.
  
  #### Members and actors ####
  
  In the Jira REST API, a member of a project role is called an *actor*. An *actor* is a group or user associated with a project role.
  
  Actors may be set as [default members](https://support.atlassian.com/jira-cloud-administration/docs/manage-project-roles/#Specifying-'default-members'-for-a-project-role) of the project role or set at the project level:
  
   *  Default actors: Users and groups that are assigned to the project role for all newly created projects. The default actors can be removed at the project level later if desired.
   *  Actors: Users and groups that are associated with a project role for a project, which may differ from the default actors. This enables you to assign a user to different roles in different projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-get
  * @param options Request options.
  */
    async getRoles(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/role`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new project role with no [default actors](#api-rest-api-3-resolution-get). You can use the [Add default actors to project role](#api-rest-api-3-role-id-actors-post) operation to add default actors to the project role after creating it.
  
  *Note that although a new project role is available to all projects upon creation, any default actors that are associated with the project role are not added to projects that existed prior to the role being created.*<
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-post
  * @param options Request options.
  */
    async createRole(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/role`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets the project role details and the default actors associated with the role. The list of default actors is sorted by display name.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-get
  * @param options Request options.
  */
    async getRole(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/role/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the project role's name and description. You must include both a name and a description in the request.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-put
  * @param options Request options.
  */
    async fullyUpdateRole(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/role/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates either the project role's name or its description.
  
  You cannot update both the name and description at the same time using this operation. If you send a request with a name and a description only the name is updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-post
  * @param options Request options.
  */
    async partiallyUpdateRole(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/role/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a project role. You must specify a replacement project role if you wish to delete a project role that is in use.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-roles/#api-rest-api-3-role-id-delete
  * @param options Request options.
  */
    async deleteRole(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/role/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ProjectRoleActorGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Default = new ProjectRoleActorDefaultGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Sets the actors for a project role for a project, replacing all existing actors.
  
  To add actors to the project without overwriting the existing list, use [Add actors to project role](#api-rest-api-3-project-projectIdOrKey-role-id-post).
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-put
  * @param options Request options.
  */
    async setActors(options) {
        const { body, headers, errorStrategy, projectIdOrKey, id } = options;
        const request = new Request("PUT", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/role/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds actors to a project role for the project.
  
  To replace all actors for the project, use [Set actors for project role](#api-rest-api-3-project-projectIdOrKey-role-id-put).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-post
  * @param options Request options.
  */
    async addActors(options) {
        const { body, headers, errorStrategy, projectIdOrKey, id } = options;
        const request = new Request("POST", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/role/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes actors from a project role for the project.
  
  To remove default actors from the project role, use [Delete default actors from project role](#api-rest-api-3-role-id-actors-delete).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project or *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-project-projectidorkey-role-id-delete
  * @param options Request options.
  */
    async deleteActors(options) {
        const { headers, errorStrategy, projectIdOrKey, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/role/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ProjectRoleActorDefaultGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the [default actors](#api-rest-api-3-resolution-get) for the project role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-get
  * @param options Request options.
  */
    async getActors(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/role/${encodeURIComponent(id)}/actors`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds [default actors](#api-rest-api-3-resolution-get) to a role. You may add groups or users, but you cannot add groups and users in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-post
  * @param options Request options.
  */
    async addActors(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/role/${encodeURIComponent(id)}/actors`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the [default actors](#api-rest-api-3-resolution-get) from a project role. You may delete a group or user, but you cannot delete a group and a user in the same request.
  
  Changing a project role's default actors does not affect project role members for projects already created.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-role-actors/#api-rest-api-3-role-id-actors-delete
  * @param options Request options.
  */
    async deleteActors(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/role/${encodeURIComponent(id)}/actors`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectVersionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Count = new ProjectVersionCountGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a [paginated](#pagination) list of all versions in a project. See the [Get project versions](#api-rest-api-3-project-projectIdOrKey-versions-get) resource if you want to get a full list of versions without pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-project-projectidorkey-version-get
  * @param options Request options.
  */
    async getVersionsPaginated(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/version`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all versions in a project. The response is not paginated. Use [Get project versions paginated](#api-rest-api-3-project-projectIdOrKey-version-get) if you want to get the versions in a project with pagination.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-project-projectidorkey-versions-get
  * @param options Request options.
  */
    async getVersions(options) {
        const { headers, errorStrategy, projectIdOrKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/versions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project the version is added to.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-post
  * @param options Request options.
  */
    async createVersion(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/version`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-get
  * @param options Request options.
  */
    async getVersion(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/version/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-put
  * @param options Request options.
  */
    async updateVersion(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/version/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Merges two project versions. The merge is completed by deleting the version specified in `id` and replacing any occurrences of its ID in `fixVersion` with the version ID specified in `moveIssuesTo`.
  
  Consider using [ Delete and replace version](#api-rest-api-3-version-id-removeAndSwap-post) instead. This resource supports swapping version values in `fixVersion`, `affectedVersion`, and custom fields.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-mergeto-moveissuesto-put
  * @param options Request options.
  */
    async mergeVersions(options) {
        const { headers, errorStrategy, id, moveIssuesTo } = options;
        const request = new Request("PUT", `/rest/api/3/version/${encodeURIComponent(id)}/mergeto/${encodeURIComponent(moveIssuesTo)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Modifies the version's sequence within the project, which affects the display order of the versions in Jira.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-move-post
  * @param options Request options.
  */
    async moveVersion(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/version/${encodeURIComponent(id)}/move`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a project version.
  
  Alternative versions can be provided to update issues that use the deleted version in `fixVersion`, `affectedVersion`, or any version picker custom fields. If alternatives are not provided, occurrences of `fixVersion`, `affectedVersion`, and any version picker custom field, that contain the deleted version, are cleared. Any replacement version must be in the same project as the version being deleted and cannot be the version being deleted.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-removeandswap-post
  * @param options Request options.
  */
    async deleteAndReplaceVersion(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/version/${encodeURIComponent(id)}/removeAndSwap`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectVersionCountGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the following counts for a version:
  
   *  Number of issues where the `fixVersion` is set to the version.
   *  Number of issues where the `affectedVersion` is set to the version.
   *  Number of issues where a version custom field is set to the version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-relatedissuecounts-get
  * @param options Request options.
  */
    async getRelatedIssueCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/version/${encodeURIComponent(id)}/relatedIssueCounts`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns counts of the issues and unresolved issues for the project version.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* project permission for the project that contains the version.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-versions/#api-rest-api-3-version-id-unresolvedissuecount-get
  * @param options Request options.
  */
    async getUnresolvedIssueCount(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/version/${encodeURIComponent(id)}/unresolvedIssueCount`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectIssueTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Get the issue type hierarchy for a next-gen project.
  
  The issue type hierarchy for a project consists of:
  
   *  *Epic* at level 1 (optional).
   *  One or more issue types at level 0 such as *Story*, *Task*, or *Bug*. Where the issue type *Epic* is defined, these issue types are used to break down the content of an epic.
   *  *Subtask* at level -1 (optional). This issue type enables level 0 issue types to be broken down into components. Issues based on a level -1 issue type must have a parent issue.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectid-hierarchy-get
  * @param options Request options.
  * @deprecated
  */
    async getHierarchy(options) {
        const { headers, errorStrategy, projectId } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectId)}/hierarchy`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectValidationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Validates a project key by confirming the key is a valid string and not in use.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-key-get
  * @param options Request options.
  */
    async validateProjectKey(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/projectvalidate/key`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Validates a project key and, if the key is invalid or in use, generates a valid random string for the project key.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-validprojectkey-get
  * @param options Request options.
  */
    async getValidProjectKey(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/projectvalidate/validProjectKey`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Checks that a project name isn't in use. If the name isn't in use, the passed string is returned. If the name is in use, this operation attempts to generate a valid project name based on the one supplied, usually by adding a sequence number. If a valid project name cannot be generated, a 404 response is returned.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-key-and-name-validation/#api-rest-api-3-projectvalidate-validprojectname-get
  * @param options Request options.
  */
    async getValidProjectName(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/projectvalidate/validProjectName`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ProjectTypeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw), whether or not the instance has a valid license for each type.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-get
  * @param options Request options.
  */
    async getTypes(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/project/type`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns all [project types](https://confluence.atlassian.com/x/Var1Nw) with a valid license.
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-accessible-get
     * @param options Request options.
     */
    async getLicensedTypes(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/project/type/accessible`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-get
  * @param options Request options.
  */
    async getTypeByKey(options) {
        const { headers, errorStrategy, projectTypeKey } = options;
        const request = new Request("GET", `/rest/api/3/project/type/${encodeURIComponent(projectTypeKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [project type](https://confluence.atlassian.com/x/Var1Nw) if it is accessible to the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-types/#api-rest-api-3-project-type-projecttypekey-accessible-get
  * @param options Request options.
  */
    async getAccessibleTypeByKey(options) {
        const { headers, errorStrategy, projectTypeKey } = options;
        const request = new Request("GET", `/rest/api/3/project/type/${encodeURIComponent(projectTypeKey)}/accessible`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectCategoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all project categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-get
  * @param options Request options.
  */
    async getCategories(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/projectCategory`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-post
  * @param options Request options.
  */
    async createCategory(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/projectCategory`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a project category.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-get
  * @param options Request options.
  */
    async getCategory(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/projectCategory/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-put
  * @param options Request options.
  */
    async updateCategory(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/projectCategory/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a project category.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-categories/#api-rest-api-3-projectcategory-id-delete
  * @param options Request options.
  */
    async deleteCategory(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/projectCategory/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ProjectNotificationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new ProjectNotificationSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ProjectNotificationSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Gets a [notification scheme](https://confluence.atlassian.com/x/8YdKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-projects/#api-rest-api-3-project-projectkeyorid-notificationscheme-get
  * @param options Request options.
  * @deprecated
  */
    async getScheme(options) {
        const { headers, errorStrategy, projectKeyOrId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectKeyOrId)}/notificationscheme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectPermissionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new ProjectPermissionSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ProjectPermissionSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Assigns a permission scheme with a project. See [Managing project permissions](https://confluence.atlassian.com/x/yodKLg) for more information about permission schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg)
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-put
  * @param options Request options.
  */
    async assignScheme(options) {
        const { body, headers, errorStrategy, projectKeyOrId, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectKeyOrId)}/permissionscheme`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Gets the [permission scheme](https://confluence.atlassian.com/x/yodKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-permissionscheme-get
  * @param options Request options.
  */
    async getScheme(options) {
        const { headers, errorStrategy, projectKeyOrId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/project/${encodeURIComponent(projectKeyOrId)}/permissionscheme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all [issue security](https://confluence.atlassian.com/x/J4lKLg) levels for the project that the user has access to.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project, however, issue security levels are only returned for authenticated user with *Set Issue Security* [global permission](https://confluence.atlassian.com/x/x4dKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-securitylevel-get
  * @param options Request options.
  */
    async getIssueSecurityLevels(options) {
        const { headers, errorStrategy, projectKeyOrId } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectKeyOrId)}/securitylevel`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectSecurityGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new ProjectSecuritySchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ProjectSecuritySchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the [issue security scheme](https://confluence.atlassian.com/x/J4lKLg) associated with the project.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or the *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-permission-schemes/#api-rest-api-3-project-projectkeyorid-issuesecuritylevelscheme-get
  * @param options Request options.
  */
    async getIssueScheme(options) {
        const { headers, errorStrategy, projectKeyOrId } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectKeyOrId)}/issuesecuritylevelscheme`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ProjectPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) keys for the project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-get
  * @param options Request options.
  */
    async getPropertyKeys(options) {
        const { headers, errorStrategy, projectIdOrKey } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of a [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties).
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, projectIdOrKey, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of the [project property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties). You can use project properties to store custom data against the project.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project in which the property is created.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, projectIdOrKey, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes the [property](https://developer.atlassian.com/cloud/jira/platform/storing-data-without-a-database/#a-id-jira-entity-properties-a-jira-entity-properties) from a project.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) or *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for the project containing the property.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-project-properties/#api-rest-api-3-project-projectidorkey-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, projectIdOrKey, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/project/${encodeURIComponent(projectIdOrKey)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class UserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Search = new UserSearchGroup(implementation, this.getGlobalErrorStrategy);
        this.Property = new UserPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of all users, including active users, inactive users and previously deleted users that have an Atlassian account.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-users-get
  * @param options Request options.
  */
    async getUsersDefault(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/users`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the default [issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If `accountId` is not passed in the request, the calling user's details are returned.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLgl), to get the column details for any user.
   *  Permission to access Jira, to get the calling user's column details.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-get
  * @param options Request options.
  */
    async getDefaultColumns(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user/columns`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user. If an account ID is not passed, the calling user's default columns are set. If no column details are sent, then all default columns are removed.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/user/columns?accountId=5b10ac8d82e05b22cc7d4ef5'`
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-put
  * @param options Request options.
  */
    async setDefaultColumns(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/user/columns`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Resets the default [ issue table columns](https://confluence.atlassian.com/x/XYdKLg) for the user to the system default. If `accountId` is not passed, the calling user's default columns are reset.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set the columns on any user.
   *  Permission to access Jira, to set the calling user's columns.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-columns-delete
  * @param options Request options.
  */
    async resetDefaultColumns(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("DELETE", constructUrl(`/rest/api/3/user/columns`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a user.
  
  Privacy controls are applied to the response based on the user's preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-get
  * @param options Request options.
  */
    async getUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a user. This resource is retained for legacy compatibility. As soon as a more suitable alternative is available this resource will be deprecated.
  
  If the user exists and has access to Jira, the operation returns a 201 status. If the user exists but does not have access to Jira, the operation returns a 400 status.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-post
  * @param options Request options.
  */
    async createUser(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/user`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a user. If the operation completes successfully then the user is removed from Jira's user base. This operation does not delete the user's Atlassian account.
  
  **[Permissions](#permissions) required:** Site administration (that is, membership of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-delete
  * @param options Request options.
  */
    async deleteUser(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the account IDs for the users specified in the `key` or `username` parameters. Note that multiple `key` or `username` parameters can be specified.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-bulk-migration-get
  * @param options Request options.
  */
    async getAccountIdsForUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user/bulk/migration`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
     * Returns a user's email address regardless of the user's profile visibility settings. For Connect apps, this API is only available to apps approved by Atlassian, according to these [guidelines](https://community.developer.atlassian.com/t/guidelines-for-requesting-access-to-email-address/27603). For Forge apps, this API only supports access via asApp() requests.
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-email-get
     * @param options Request options.
     */
    async getEmail(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/email`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the groups to which a user belongs.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-user-groups-get
  * @param options Request options.
  */
    async getGroups(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/groups`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of all users, including active users, inactive users and previously deleted users that have an Atlassian account.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-users/#api-rest-api-3-users-search-get
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/users/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserSearchGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of users who can be assigned issues in one or more projects. The list may be restricted to users whose attributes match a string.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned issues in the projects. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned issues in the projects, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-assignable-multiprojectsearch-get
  * @param options Request options.
  */
    async findUsersAssignableToProjects(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/assignable/multiProjectSearch`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of users that can be assigned to an issue. Use this operation to find the list of users who can be assigned to:
  
   *  a new issue, by providing the `projectKeyOrId`.
   *  an updated issue, by providing the `issueKey`.
   *  to an issue during a transition (workflow action), by providing the `issueKey` and the transition id in `actionDescriptorId`. You can obtain the IDs of an issue's valid transitions using the `transitions` option in the `expand` parameter of [ Get issue](#api-rest-api-3-issue-issueIdOrKey-get).
  
  In all these cases, you can pass an account ID to determine if a user can be assigned to an issue. The user is returned in the response if they can be assigned to the issue or issue transition.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that can be assigned the issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who can be assigned the issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-assignable-search-get
  * @param options Request options.
  */
    async findUsersAssignableToIssues(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user/assignable/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have a set of permissions for a project or issue.
  
  If no search string is provided, a list of all users with the permissions is returned.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission for the project or issue. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission for the project or issue, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get users for any project.
   *  *Administer Projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for a project, to get users for that project.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-permission-search-get
  * @param options Request options.
  */
    async findUsersWithPermissions(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/permission/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of users whose attributes match the query term. The returned object includes the `html` field where the matched query term is highlighted with the HTML strong tag. A list of account IDs can be provided to exclude users from the results.
  
  This operation takes the users in the range defined by `maxResults`, up to the thousandth user, and then returns only the users from that range that match the query term. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the query term, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return search results for an exact name match only.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-picker-get
  * @param options Request options.
  */
    async findUsersForPicker(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/picker`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of users that match the search string and property.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and property. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and property, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  This operation can be accessed anonymously.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls or calls by users without the required permission return empty search results.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-get
  * @param options Request options.
  */
    async findUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user details.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value. For example, if user property `location` is set to value `{"office": {"country": "AU", "city": "Sydney"}}`, then it's possible to use `[location].office.city is "Sydney"` to match the user.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-query-get
  * @param options Request options.
  */
    async findUsersByQuery(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/search/query`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Finds users with a structured query and returns a [paginated](#pagination) list of user keys.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the structured query. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the structured query, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  
  The query statements are:
  
   *  `is assignee of PROJ` Returns the users that are assignees of at least one issue in project *PROJ*.
   *  `is assignee of (PROJ-1, PROJ-2)` Returns users that are assignees on the issues *PROJ-1* or *PROJ-2*.
   *  `is reporter of (PROJ-1, PROJ-2)` Returns users that are reporters on the issues *PROJ-1* or *PROJ-2*.
   *  `is watcher of (PROJ-1, PROJ-2)` Returns users that are watchers on the issues *PROJ-1* or *PROJ-2*.
   *  `is voter of (PROJ-1, PROJ-2)` Returns users that are voters on the issues *PROJ-1* or *PROJ-2*.
   *  `is commenter of (PROJ-1, PROJ-2)` Returns users that have posted a comment on the issues *PROJ-1* or *PROJ-2*.
   *  `is transitioner of (PROJ-1, PROJ-2)` Returns users that have performed a transition on issues *PROJ-1* or *PROJ-2*.
   *  `[propertyKey].entity.property.path is "property value"` Returns users with the entity property value. For example, if user property `location` is set to value `{"office": {"country": "AU", "city": "Sydney"}}`, then it's possible to use `[location].office.city is "Sydney"` to match the user.
  
  The list of issues can be extended as needed, as in *(PROJ-1, PROJ-2, ... PROJ-n)*. Statements can be combined using the `AND` and `OR` operators to form more complex queries. For example:
  
  `is assignee of PROJ AND [propertyKey].entity.property.path is "property value"`
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-search-query-key-get
  * @param options Request options.
  */
    async findUserKeysByQuery(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/search/query/key`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a list of users who fulfill these criteria:
  
   *  their user attributes match a search string.
   *  they have permission to browse issues.
  
  Use this resource to find users who can browse:
  
   *  an issue, by providing the `issueKey`.
   *  any issue in a project, by providing the `projectKey`.
  
  This operation takes the users in the range defined by `startAt` and `maxResults`, up to the thousandth user, and then returns only the users from that range that match the search string and have permission to browse issues. This means the operation usually returns fewer users than specified in `maxResults`. To get all the users who match the search string and have permission to browse issues, use [Get all users](#api-rest-api-3-users-search-get) and filter the records in your code.
  
  Privacy controls are applied to the response based on the users' preferences. This could mean, for example, that the user's email address is hidden. See the [Profile visibility overview](https://developer.atlassian.com/cloud/jira/platform/profile-visibility/) for more details.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Anonymous calls and calls by users without the required permission return empty search results.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-search/#api-rest-api-3-user-viewissue-search-get
  * @param options Request options.
  */
    async findUsersWithBrowsePermission(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/user/viewissue/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class UserPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all properties for a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to access the property keys on any user.
   *  Access to Jira, to access the calling user's property keys.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-get
  * @param options Request options.
  */
    async getPropertyKeys(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the value of a user's property.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to get a property from any user.
   *  Access to Jira, to get a property from the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, propertyKey, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/user/properties/${encodeURIComponent(propertyKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of a user's property. Use this resource to store custom data against a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to set a property on any user.
   *  Access to Jira, to set a property on the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, propertyKey, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/user/properties/${encodeURIComponent(propertyKey)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a property from a user.
  
  Note: This operation does not access the [user properties](https://confluence.atlassian.com/x/8YxjL) created and maintained in Jira.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg), to delete a property from any user.
   *  Access to Jira, to delete a property from the calling user's record.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-user-properties/#api-rest-api-3-user-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, propertyKey, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/user/properties/${encodeURIComponent(propertyKey)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WorkflowGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Transition = new WorkflowTransitionGroup(implementation, this.getGlobalErrorStrategy);
        this.Status = new WorkflowStatusGroup(implementation, this.getGlobalErrorStrategy);
        this.Scheme = new WorkflowSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a workflow. You can define transition rules using the shapes detailed in the following sections. If no transitional rules are specified the default system transition rules are used. Note: This only applies to company-managed scoped workflows. Use [bulk create workflows](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflows-create-post) to create both team and company-managed scoped workflows.
  
  #### Conditions ####
  
  Conditions enable workflow rules that govern whether a transition can execute.
  
  ##### Always false condition #####
  
  A condition that always fails.
  
      {
         "type": "AlwaysFalseCondition"
       }
  
  ##### Block transition until approval #####
  
  A condition that blocks issue transition if there is a pending approval.
  
      {
         "type": "BlockInProgressApprovalCondition"
       }
  
  ##### Compare number custom field condition #####
  
  A condition that allows transition if a comparison between a number custom field and a value is true.
  
      {
         "type": "CompareNumberCFCondition",
         "configuration": {
           "comparator": "=",
           "fieldId": "customfield_10029",
           "fieldValue": 2
         }
       }
  
   *  `comparator` One of the supported comparator: `=`, `>`, and `<`.
   *  `fieldId` The custom numeric field ID. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
       *  `com.pyxis.greenhopper.jira:jsw-story-points`
   *  `fieldValue` The value for comparison.
  
  ##### Hide from user condition #####
  
  A condition that hides a transition from users. The transition can only be triggered from a workflow function or REST API operation.
  
      {
         "type": "RemoteOnlyCondition"
       }
  
  ##### Only assignee condition #####
  
  A condition that allows only the assignee to execute a transition.
  
      {
         "type": "AllowOnlyAssignee"
       }
  
  ##### Only Bamboo notifications workflow condition (deprecated) #####
  
  A condition that makes the transition available only to Bamboo build notifications.
  
      {
         "type": "OnlyBambooNotificationsCondition"
       }
  
  ##### Only reporter condition #####
  
  A condition that allows only the reporter to execute a transition.
  
      {
         "type": "AllowOnlyReporter"
       }
  
  ##### Permission condition #####
  
  A condition that allows only users with a permission to execute a transition.
  
      {
         "type": "PermissionCondition",
         "configuration": {
             "permissionKey": "BROWSE_PROJECTS"
         }
       }
  
   *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
  
  ##### Previous status condition #####
  
  A condition that allows a transition based on whether an issue has or has not transitioned through a status.
  
      {
         "type": "PreviousStatusCondition",
         "configuration": {
           "ignoreLoopTransitions": true,
           "includeCurrentStatus": true,
           "mostRecentStatusOnly": true,
           "reverseCondition": true,
           "previousStatus": {
             "id": "5"
           }
         }
       }
  
  By default this condition allows the transition if the status, as defined by its ID in the `previousStatus` object, matches any previous issue status, unless:
  
   *  `ignoreLoopTransitions` is `true`, then loop transitions (from and to the same status) are ignored.
   *  `includeCurrentStatus` is `true`, then the current issue status is also checked.
   *  `mostRecentStatusOnly` is `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
   *  `reverseCondition` is `true`, then the status must not be present.
  
  ##### Separation of duties condition #####
  
  A condition that prevents a user to perform the transition, if the user has already performed a transition on the issue.
  
      {
         "type": "SeparationOfDutiesCondition",
         "configuration": {
           "fromStatus": {
             "id": "5"
           },
           "toStatus": {
             "id": "6"
           }
         }
       }
  
   *  `fromStatus` OPTIONAL. An object containing the ID of the source status of the transition that is blocked. If omitted any transition to `toStatus` is blocked.
   *  `toStatus` An object containing the ID of the target status of the transition that is blocked.
  
  ##### Subtask blocking condition #####
  
  A condition that blocks transition on a parent issue if any of its subtasks are in any of one or more statuses.
  
      {
         "type": "SubTaskBlockingCondition",
         "configuration": {
           "statuses": [
             {
               "id": "1"
             },
             {
               "id": "3"
             }
           ]
         }
       }
  
   *  `statuses` A list of objects containing status IDs.
  
  ##### User is in any group condition #####
  
  A condition that allows users belonging to any group from a list of groups to execute a transition.
  
      {
         "type": "UserInAnyGroupCondition",
         "configuration": {
           "groups": [
             "administrators",
             "atlassian-addons-admin"
           ]
         }
       }
  
   *  `groups` A list of group names.
  
  ##### User is in any project role condition #####
  
  A condition that allows only users with at least one project roles from a list of project roles to execute a transition.
  
      {
         "type": "InAnyProjectRoleCondition",
         "configuration": {
           "projectRoles": [
             {
               "id": "10002"
             },
             {
               "id": "10003"
             },
             {
               "id": "10012"
             },
             {
               "id": "10013"
             }
           ]
         }
       }
  
   *  `projectRoles` A list of objects containing project role IDs.
  
  ##### User is in custom field condition #####
  
  A condition that allows only users listed in a given custom field to execute the transition.
  
      {
         "type": "UserIsInCustomFieldCondition",
         "configuration": {
           "allowUserInField": false,
           "fieldId": "customfield_10010"
         }
       }
  
   *  `allowUserInField` If `true` only a user who is listed in `fieldId` can perform the transition, otherwise, only a user who is not listed in `fieldId` can perform the transition.
   *  `fieldId` The ID of the field containing the list of users.
  
  ##### User is in group condition #####
  
  A condition that allows users belonging to a group to execute a transition.
  
      {
         "type": "UserInGroupCondition",
         "configuration": {
           "group": "administrators"
         }
       }
  
   *  `group` The name of the group.
  
  ##### User is in group custom field condition #####
  
  A condition that allows users belonging to a group specified in a custom field to execute a transition.
  
      {
         "type": "InGroupCFCondition",
         "configuration": {
           "fieldId": "customfield_10012"
         }
       }
  
   *  `fieldId` The ID of the field. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multigrouppicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:grouppicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
       *  `com.pyxis.greenhopper.jira:gh-epic-status`
  
  ##### User is in project role condition #####
  
  A condition that allows users with a project role to execute a transition.
  
      {
         "type": "InProjectRoleCondition",
         "configuration": {
           "projectRole": {
             "id": "10002"
           }
         }
       }
  
   *  `projectRole` An object containing the ID of a project role.
  
  ##### Value field condition #####
  
  A conditions that allows a transition to execute if the value of a field is equal to a constant value or simply set.
  
      {
         "type": "ValueFieldCondition",
         "configuration": {
           "fieldId": "assignee",
           "fieldValue": "qm:6e1ecee6-8e64-4db6-8c85-916bb3275f51:54b56885-2bd2-4381-8239-78263442520f",
           "comparisonType": "NUMBER",
           "comparator": "="
         }
       }
  
   *  `fieldId` The ID of a field used in the comparison.
   *  `fieldValue` The expected value of the field.
   *  `comparisonType` The type of the comparison. Allowed values: `STRING`, `NUMBER`, `DATE`, `DATE_WITHOUT_TIME`, or `OPTIONID`.
   *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, `!=`.
  
  **Notes:**
  
   *  If you choose the comparison type `STRING`, only `=` and `!=` are valid options.
   *  You may leave `fieldValue` empty when comparison type is `!=` to indicate that a value is required in the field.
   *  For date fields without time format values as `yyyy-MM-dd`, and for those with time as `yyyy-MM-dd HH:mm`. For example, for July 16 2021 use `2021-07-16`, for 8:05 AM use `2021-07-16 08:05`, and for 4 PM: `2021-07-16 16:00`.
  
  #### Validators ####
  
  Validators check that any input made to the transition is valid before the transition is performed.
  
  ##### Date field validator #####
  
  A validator that compares two dates.
  
      {
         "type": "DateFieldValidator",
         "configuration": {
             "comparator": ">",
             "date1": "updated",
             "date2": "created",
             "expression": "1d",
             "includeTime": true
           }
       }
  
   *  `comparator` One of the supported comparator: `>`, `>=`, `=`, `<=`, `<`, or `!=`.
   *  `date1` The date field to validate. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `date2` The second date field. Required, if `expression` is not passed. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `expression` An expression specifying an offset. Required, if `date2` is not passed. Offsets are built with a number, with `-` as prefix for the past, and one of these time units: `d` for day, `w` for week, `m` for month, or `y` for year. For example, -2d means two days into the past and 1w means one week into the future. The `now` keyword enables a comparison with the current date.
   *  `includeTime` If `true`, then the time part of the data is included for the comparison. If the field doesn't have a time part, 00:00:00 is used.
  
  ##### Windows date validator #####
  
  A validator that checks that a date falls on or after a reference date and before or on the reference date plus a number of days.
  
      {
         "type": "WindowsDateValidator",
         "configuration": {
             "date1": "customfield_10009",
             "date2": "created",
             "windowsDays": 5
           }
       }
  
   *  `date1` The date field to validate. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `date2` The reference date. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datepicker`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:datetime`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-end`
       *  `com.atlassian.jpo:jpo-custom-field-baseline-start`
       *  `duedate`
       *  `created`
       *  `updated`
       *  `resolutiondate`
   *  `windowsDays` A positive integer indicating a number of days.
  
  ##### Field required validator #####
  
  A validator that checks fields are not empty. By default, if a field is not included in the current context it's ignored and not validated.
  
      {
           "type": "FieldRequiredValidator",
           "configuration": {
               "ignoreContext": true,
               "errorMessage": "Hey",
               "fieldIds": [
                   "versions",
                   "customfield_10037",
                   "customfield_10003"
               ]
           }
       }
  
   *  `ignoreContext` If `true`, then the context is ignored and all the fields are validated.
   *  `errorMessage` OPTIONAL. The error message displayed when one or more fields are empty. A default error message is shown if an error message is not provided.
   *  `fieldIds` The list of fields to validate.
  
  ##### Field changed validator #####
  
  A validator that checks that a field value is changed. However, this validation can be ignored for users from a list of groups.
  
      {
           "type": "FieldChangedValidator",
           "configuration": {
               "fieldId": "comment",
               "errorMessage": "Hey",
               "exemptedGroups": [
                   "administrators",
                   "atlassian-addons-admin"
               ]
           }
       }
  
   *  `fieldId` The ID of a field.
   *  `errorMessage` OPTIONAL. The error message displayed if the field is not changed. A default error message is shown if the error message is not provided.
   *  `exemptedGroups` OPTIONAL. The list of groups.
  
  ##### Field has single value validator #####
  
  A validator that checks that a multi-select field has only one value. Optionally, the validation can ignore values copied from subtasks.
  
      {
           "type": "FieldHasSingleValueValidator",
           "configuration": {
               "fieldId": "attachment,
               "excludeSubtasks": true
           }
       }
  
   *  `fieldId` The ID of a field.
   *  `excludeSubtasks` If `true`, then values copied from subtasks are ignored.
  
  ##### Parent status validator #####
  
  A validator that checks the status of the parent issue of a subtask. Ìf the issue is not a subtask, no validation is performed.
  
      {
           "type": "ParentStatusValidator",
           "configuration": {
               "parentStatuses": [
                   {
                     "id":"1"
                   },
                   {
                     "id":"2"
                   }
               ]
           }
       }
  
   *  `parentStatus` The list of required parent issue statuses.
  
  ##### Permission validator #####
  
  A validator that checks the user has a permission.
  
      {
         "type": "PermissionValidator",
         "configuration": {
             "permissionKey": "ADMINISTER_PROJECTS"
         }
       }
  
   *  `permissionKey` The permission required to perform the transition. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
  
  ##### Previous status validator #####
  
  A validator that checks if the issue has held a status.
  
      {
         "type": "PreviousStatusValidator",
         "configuration": {
             "mostRecentStatusOnly": false,
             "previousStatus": {
                 "id": "15"
             }
         }
       }
  
   *  `mostRecentStatusOnly` If `true`, then only the issue's preceding status (the one immediately before the current status) is checked.
   *  `previousStatus` An object containing the ID of an issue status.
  
  ##### Regular expression validator #####
  
  A validator that checks the content of a field against a regular expression.
  
      {
         "type": "RegexpFieldValidator",
         "configuration": {
             "regExp": "[0-9]",
             "fieldId": "customfield_10029"
         }
       }
  
   *  `regExp`A regular expression.
   *  `fieldId` The ID of a field. Allowed field types:
      
       *  `com.atlassian.jira.plugin.system.customfieldtypes:select`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multiselect`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:radiobuttons`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:multicheckboxes`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:textarea`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:textfield`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:url`
       *  `com.atlassian.jira.plugin.system.customfieldtypes:float`
       *  `com.pyxis.greenhopper.jira:jsw-story-points`
       *  `com.pyxis.greenhopper.jira:gh-epic-status`
       *  `description`
       *  `summary`
  
  ##### User permission validator #####
  
  A validator that checks if a user has a permission. Obsolete. You may encounter this validator when getting transition rules and can pass it when updating or creating rules, for example, when you want to duplicate the rules from a workflow on a new workflow.
  
      {
           "type": "UserPermissionValidator",
           "configuration": {
               "permissionKey": "BROWSE_PROJECTS",
               "nullAllowed": false,
               "username": "TestUser"
           }
       }
  
   *  `permissionKey` The permission to be validated. Allowed values: [built-in](https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#built-in-permissions) or app defined permissions.
   *  `nullAllowed` If `true`, allows the transition when `username` is empty.
   *  `username` The username to validate against the `permissionKey`.
  
  #### Post functions ####
  
  Post functions carry out any additional processing required after a Jira workflow transition is executed.
  
  ##### Fire issue event function #####
  
  A post function that fires an event that is processed by the listeners.
  
      {
         "type": "FireIssueEventFunction",
         "configuration": {
           "event": {
             "id":"1"
           }
         }
       }
  
  **Note:** If provided, this post function overrides the default `FireIssueEventFunction`. Can be included once in a transition.
  
   *  `event` An object containing the ID of the issue event.
  
  ##### Update issue status #####
  
  A post function that sets issue status to the linked status of the destination workflow status.
  
      {
         "type": "UpdateIssueStatusFunction"
       }
  
  **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
  
  ##### Create comment #####
  
  A post function that adds a comment entered during the transition to an issue.
  
      {
         "type": "CreateCommentFunction"
       }
  
  **Note:** This post function is a default function in global and directed transitions. It can only be added to the initial transition and can only be added once.
  
  ##### Store issue #####
  
  A post function that stores updates to an issue.
  
      {
         "type": "IssueStoreFunction"
       }
  
  **Note:** This post function can only be added to the initial transition and can only be added once.
  
  ##### Assign to current user function #####
  
  A post function that assigns the issue to the current user if the current user has the `ASSIGNABLE_USER` permission.
  
      {
           "type": "AssignToCurrentUserFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Assign to lead function #####
  
  A post function that assigns the issue to the project or component lead developer.
  
      {
           "type": "AssignToLeadFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Assign to reporter function #####
  
  A post function that assigns the issue to the reporter.
  
      {
           "type": "AssignToReporterFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Clear field value function #####
  
  A post function that clears the value from a field.
  
      {
         "type": "ClearFieldValuePostFunction",
         "configuration": {
           "fieldId": "assignee"
         }
       }
  
   *  `fieldId` The ID of the field.
  
  ##### Copy value from other field function #####
  
  A post function that copies the value of one field to another, either within an issue or from parent to subtask.
  
      {
         "type": "CopyValueFromOtherFieldPostFunction",
         "configuration": {
           "sourceFieldId": "assignee",
           "destinationFieldId": "creator",
           "copyType": "same"
         }
       }
  
   *  `sourceFieldId` The ID of the source field.
   *  `destinationFieldId` The ID of the destination field.
   *  `copyType` Use `same` to copy the value from a field inside the issue, or `parent` to copy the value from the parent issue.
  
  ##### Create Crucible review workflow function (deprecated) #####
  
  A post function that creates a Crucible review for all unreviewed code for the issue.
  
      {
           "type": "CreateCrucibleReviewWorkflowFunction"
       }
  
  **Note:** This post function can be included once in a transition.
  
  ##### Set issue security level based on user's project role function #####
  
  A post function that sets the issue's security level if the current user has a project role.
  
      {
         "type": "SetIssueSecurityFromRoleFunction",
         "configuration": {
           "projectRole": {
               "id":"10002"
           },
           "issueSecurityLevel": {
               "id":"10000"
           }
         }
       }
  
   *  `projectRole` An object containing the ID of the project role.
   *  `issueSecurityLevel` OPTIONAL. The object containing the ID of the security level. If not passed, then the security level is set to `none`.
  
  ##### Trigger a webhook function #####
  
  A post function that triggers a webhook.
  
      {
         "type": "TriggerWebhookFunction",
         "configuration": {
           "webhook": {
             "id": "1"
           }
         }
       }
  
   *  `webhook` An object containing the ID of the webhook listener to trigger.
  
  ##### Update issue custom field function #####
  
  A post function that updates the content of an issue custom field.
  
      {
         "type": "UpdateIssueCustomFieldPostFunction",
         "configuration": {
           "mode": "append",
           "fieldId": "customfield_10003",
           "fieldValue": "yikes"
         }
       }
  
   *  `mode` Use `replace` to override the field content with `fieldValue` or `append` to add `fieldValue` to the end of the field content.
   *  `fieldId` The ID of the field.
   *  `fieldValue` The update content.
  
  ##### Update issue field function #####
  
  A post function that updates a simple issue field.
  
      {
         "type": "UpdateIssueFieldFunction",
         "configuration": {
           "fieldId": "assignee",
           "fieldValue": "5f0c277e70b8a90025a00776"
         }
       }
  
   *  `fieldId` The ID of the field. Allowed field types:
      
       *  `assignee`
       *  `description`
       *  `environment`
       *  `priority`
       *  `resolution`
       *  `summary`
       *  `timeoriginalestimate`
       *  `timeestimate`
       *  `timespent`
   *  `fieldValue` The update value.
   *  If the `fieldId` is `assignee`, the `fieldValue` should be one of these values:
      
       *  an account ID.
       *  `automatic`.
       *  a blank string, which sets the value to `unassigned`.
  
  #### Connect rules ####
  
  Connect rules are conditions, validators, and post functions of a transition that are registered by Connect apps. To create a rule registered by the app, the app must be enabled and the rule's module must exist.
  
      {
         "type": "appKey__moduleKey",
         "configuration": {
           "value":"{\"isValid\":\"true\"}"
         }
       }
  
   *  `type` A Connect rule key in a form of `appKey__moduleKey`.
   *  `value` The stringified JSON configuration of a Connect rule.
  
  #### Forge rules ####
  
  Forge transition rules are not yet supported.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-post
  * @param options Request options.
  */
    async createWorkflow(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/workflow`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a workflow.
  
  The workflow cannot be deleted if it is:
  
   *  an active workflow.
   *  a system workflow.
   *  associated with any workflow scheme.
   *  associated with any draft workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-entityid-delete
  * @param options Request options.
  */
    async deleteWorkflow(options) {
        const { headers, errorStrategy, entityId } = options;
        const request = new Request("DELETE", `/rest/api/3/workflow/${encodeURIComponent(entityId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a [paginated](#pagination) list of published classic workflows. When workflow names are specified, details of those workflows are returned. Otherwise, all published classic workflows are returned.
  
  This operation does not return next-gen workflows.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflows/#api-rest-api-3-workflow-search-get
  * @param options Request options.
  */
    async getWorkflows(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/workflow/search`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkflowTransitionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new WorkflowTransitionPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class WorkflowTransitionPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the properties on a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-get
  * @param options Request options.
  */
    async getProperties(options) {
        const { headers, errorStrategy, transitionId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflow/transitions/${encodeURIComponent(transitionId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a workflow transition by changing the property value. Trying to update a property that does not exist results in a new property being added to the transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-put
  * @param options Request options.
  */
    async updateProperty(options) {
        const { body, headers, errorStrategy, transitionId, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/workflow/transitions/${encodeURIComponent(transitionId)}/properties`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a property to a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-post
  * @param options Request options.
  */
    async createProperty(options) {
        const { body, headers, errorStrategy, transitionId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/workflow/transitions/${encodeURIComponent(transitionId)}/properties`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a property from a workflow transition. Transition properties are used to change the behavior of a transition. For more information, see [Transition properties](https://confluence.atlassian.com/x/zIhKLg#Advancedworkflowconfiguration-transitionproperties) and [Workflow properties](https://confluence.atlassian.com/x/JYlKLg).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-transition-properties/#api-rest-api-3-workflow-transitions-transitionid-properties-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, transitionId, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/workflow/transitions/${encodeURIComponent(transitionId)}/properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class WorkflowStatusGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Category = new WorkflowStatusCategoryGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of all statuses associated with active workflows.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-statuses/#api-rest-api-3-status-get
  * @param options Request options.
  */
    async getStatuses(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/status`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a status. The status must be associated with an active workflow to be returned.
  
  If a name is used on more than one status, only the status found first is returned. Therefore, identifying the status by its ID may be preferable.
  
  This operation can be accessed anonymously.
  
  [Permissions](#permissions) required: None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-statuses/#api-rest-api-3-status-idorname-get
  * @param options Request options.
  */
    async getStatus(options) {
        const { headers, errorStrategy, idOrName } = options;
        const request = new Request("GET", `/rest/api/3/status/${encodeURIComponent(idOrName)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkflowStatusCategoryGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of all status categories.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-get
  * @param options Request options.
  */
    async getCategories(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/statuscategory`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a status category. Status categories provided a mechanism for categorizing [statuses](#api-rest-api-3-status-idOrName-get).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-status-categories/#api-rest-api-3-statuscategory-idorkey-get
  * @param options Request options.
  */
    async getCategory(options) {
        const { headers, errorStrategy, idOrKey } = options;
        const request = new Request("GET", `/rest/api/3/statuscategory/${encodeURIComponent(idOrKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkflowSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Project = new WorkflowSchemeProjectGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a [paginated](#pagination) list of all workflow schemes, not including draft workflow schemes.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-post
  * @param options Request options.
  */
    async createScheme(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/workflowscheme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-get
  * @param options Request options.
  */
    async getScheme(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a company-manged project workflow scheme, including the name, default workflow, issue type to project mappings, and more. If the workflow scheme is active (that is, being used by at least one project), then a draft workflow scheme is created or updated instead, provided that `updateDraftIfNeeded` is set to `true`.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-put
  * @param options Request options.
  */
    async updateScheme(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/workflowscheme/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a workflow scheme. Note that a workflow scheme cannot be deleted if it is active (that is, being used by at least one project).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-delete
  * @param options Request options.
  */
    async deleteScheme(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/workflowscheme/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the issue type-workflow mapping for an issue type in a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-get
  * @param options Request options.
  */
    async getWorkflowForIssueType(options) {
        const { headers, errorStrategy, id, issueType, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/issuetype/${encodeURIComponent(issueType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the workflow for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new issue type-workflow mapping. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-put
  * @param options Request options.
  */
    async setWorkflowForIssueType(options) {
        const { body, headers, errorStrategy, id, issueType } = options;
        const request = new Request("PUT", `/rest/api/3/workflowscheme/${encodeURIComponent(id)}/issuetype/${encodeURIComponent(issueType)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the issue type-workflow mapping for an issue type in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the issue type-workflow mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-issuetype-issuetype-delete
  * @param options Request options.
  */
    async deleteWorkflowForIssueType(options) {
        const { headers, errorStrategy, id, issueType, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/issuetype/${encodeURIComponent(issueType)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the workflow-issue type mappings for a workflow scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-get
  * @param options Request options.
  */
    async getIssueTypesForWorkflow(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/workflow`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the issue types for a workflow in a workflow scheme. The workflow can also be set as the default workflow for the workflow scheme. Unmapped issues types are mapped to the default workflow.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request body and a draft workflow scheme is created or updated with the new workflow-issue types mappings. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-put
  * @param options Request options.
  */
    async setIssueTypesForWorkflow(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/workflow`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes the workflow-issue type mapping for a workflow in a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the workflow-issue type mapping deleted. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-workflow-delete
  * @param options Request options.
  */
    async deleteIssueTypesForWorkflow(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/workflow`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the default workflow for a workflow scheme. The default workflow is the workflow that is assigned any issue types that have not been mapped to any other workflow. The default workflow has *All Unassigned Issue Types* listed in its issue types for the workflow scheme in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-get
  * @param options Request options.
  */
    async getDefaultWorkflow(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/default`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the default workflow for a workflow scheme.
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` in the request object and a draft workflow scheme is created or updated with the new default workflow. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-put
  * @param options Request options.
  */
    async updateDefaultWorkflow(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/workflowscheme/${encodeURIComponent(id)}/default`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Resets the default workflow for a workflow scheme. That is, the default workflow is set to Jira's system workflow (the *jira* workflow).
  
  Note that active workflow schemes cannot be edited. If the workflow scheme is active, set `updateDraftIfNeeded` to `true` and a draft workflow scheme is created or updated with the default workflow reset. The draft workflow scheme can be published in Jira.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-schemes/#api-rest-api-3-workflowscheme-id-default-delete
  * @param options Request options.
  */
    async deleteDefaultWorkflow(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/workflowscheme/${encodeURIComponent(id)}/default`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class WorkflowSchemeProjectGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of the workflow schemes associated with a list of projects. Each returned workflow scheme includes a list of the requested projects associated with it. Any team-managed or non-existent projects in the request are ignored and no errors are returned.
  
  If the project is associated with the `Default Workflow Scheme` no ID is returned. This is because the way the `Default Workflow Scheme` is stored means it has no ID.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-get
  * @param options Request options.
  */
    async getProjectAssociations(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/workflowscheme/project`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Assigns a workflow scheme to a project. This operation is performed only when there are no issues in the project.
  
  Workflow schemes can only be assigned to classic projects.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-workflow-scheme-project-associations/#api-rest-api-3-workflowscheme-project-put
  * @param options Request options.
  */
    async assignWorkflow(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/workflowscheme/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DashboardGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Property = new DashboardPropertyGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of dashboards owned by or shared with the user. The list may be filtered to include only favorite or owned dashboards.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-get
  * @param options Request options.
  */
    async getDashboards(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/dashboard`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a dashboard.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-post
  * @param options Request options.
  */
    async createDashboard(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/dashboard`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of dashboards. This operation is similar to [Get dashboards](#api-rest-api-3-dashboard-get) except that the results can be refined to include dashboards that have specific attributes. For example, dashboards with a particular name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The following dashboards that match the query parameters are returned:
  
   *  Dashboards owned by the user. Not returned for anonymous users.
   *  Dashboards shared with a group that the user is a member of. Not returned for anonymous users.
   *  Dashboards shared with a private project that the user can browse. Not returned for anonymous users.
   *  Dashboards shared with a public project.
   *  Dashboards shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-search-get
  * @param options Request options.
  */
    async searchDashboards(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/dashboard/search`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a dashboard.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  
  However, to get a dashboard, the dashboard must be shared with the user or the user must own it. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-get
  * @param options Request options.
  */
    async getDashboard(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/dashboard/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a dashboard, replacing all the dashboard details with those provided.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be updated must be owned by the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-put
  * @param options Request options.
  */
    async updateDashboard(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/dashboard/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be deleted must be owned by the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-delete
  * @param options Request options.
  */
    async deleteDashboard(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/dashboard/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Copies a dashboard. Any values provided in the `dashboard` parameter replace those in the copied dashboard.
  
  **[Permissions](#permissions) required:** None
  
  The dashboard to be copied must be owned by or shared with the user.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-id-copy-post
  * @param options Request options.
  */
    async copyDashboard(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/dashboard/${encodeURIComponent(id)}/copy`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class DashboardPropertyGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the keys of all properties for a dashboard item.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira\\u2019s anonymous access is permitted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-get
  * @param options Request options.
  */
    async getPropertyKeys(options) {
        const { headers, errorStrategy, dashboardId, itemId } = options;
        const request = new Request("GET", `/rest/api/3/dashboard/${encodeURIComponent(dashboardId)}/items/${encodeURIComponent(itemId)}/properties`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the key and value of a dashboard item property.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard or have the dashboard shared with them. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard. The System dashboard is considered to be shared with all other users, and is accessible to anonymous users when Jira\\u2019s anonymous access is permitted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-get
  * @param options Request options.
  */
    async getProperty(options) {
        const { headers, errorStrategy, dashboardId, itemId, propertyKey } = options;
        const request = new Request("GET", `/rest/api/3/dashboard/${encodeURIComponent(dashboardId)}/items/${encodeURIComponent(itemId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the value of a dashboard item property. Use this resource in apps to store custom data against a dashboard item.
  
  A dashboard item enables an app to add user-specific information to a user dashboard. Dashboard items are exposed to users as gadgets that users can add to their dashboards. For more information on how users do this, see [Adding and customizing gadgets](https://confluence.atlassian.com/x/7AeiLQ).
  
  When an app creates a dashboard item it registers a callback to receive the dashboard item ID. The callback fires whenever the item is rendered or, where the item is configurable, the user edits the item. The app then uses this resource to store the item's content or configuration details. For more information on working with dashboard items, see [ Building a dashboard item for a JIRA Connect add-on](https://developer.atlassian.com/server/jira/platform/guide-building-a-dashboard-item-for-a-jira-connect-add-on-33746254/) and the [Dashboard Item](https://developer.atlassian.com/cloud/jira/platform/modules/dashboard-item/) documentation.
  
  There is no resource to set or get dashboard items.
  
  The value of the request body must be a [valid](http://tools.ietf.org/html/rfc4627), non-empty JSON blob. The maximum length is 32768 characters.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-put
  * @param options Request options.
  */
    async setProperty(options) {
        const { body, headers, errorStrategy, dashboardId, itemId, propertyKey } = options;
        const request = new Request("PUT", `/rest/api/3/dashboard/${encodeURIComponent(dashboardId)}/items/${encodeURIComponent(itemId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Deletes a dashboard item property.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** The user must be the owner of the dashboard. Note, users with the *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) are considered owners of the System dashboard.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-dashboards/#api-rest-api-3-dashboard-dashboardid-items-itemid-properties-propertykey-delete
  * @param options Request options.
  */
    async deleteProperty(options) {
        const { headers, errorStrategy, dashboardId, itemId, propertyKey } = options;
        const request = new Request("DELETE", `/rest/api/3/dashboard/${encodeURIComponent(dashboardId)}/items/${encodeURIComponent(itemId)}/properties/${encodeURIComponent(propertyKey)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ApplicationGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Role = new ApplicationRoleGroup(implementation, this.getGlobalErrorStrategy);
    }
}
class ApplicationRoleGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all application roles. In Jira, application roles are managed using the [Application access configuration](https://confluence.atlassian.com/x/3YxjL) page.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-get
  * @param options Request options.
  */
    async getRoles(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/applicationrole`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns an application role.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-application-roles/#api-rest-api-3-applicationrole-key-get
  * @param options Request options.
  */
    async getRole(options) {
        const { headers, errorStrategy, key } = options;
        const request = new Request("GET", `/rest/api/3/applicationrole/${encodeURIComponent(key)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class InstanceGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Changes the value of an application property. For example, you can change the value of the `jira.clone.prefix` from its default value of *CLONE -* to *Clone -* if you prefer sentence case capitalization. Editable properties are described below along with their default values.
  
  #### Advanced settings ####
  
  The advanced settings below are also accessible in [Jira](https://confluence.atlassian.com/x/vYXKM).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.clone.prefix` | The string of text prefixed to the title of a cloned issue. | `CLONE -` |
  | `jira.date.picker.java.format` | The date format for the Java (server-side) generated dates. This must be the same as the `jira.date.picker.javascript.format` format setting. | `d/MMM/yy` |
  | `jira.date.picker.javascript.format` | The date format for the JavaScript (client-side) generated dates. This must be the same as the `jira.date.picker.java.format` format setting. | `%e/%b/%y` |
  | `jira.date.time.picker.java.format` | The date format for the Java (server-side) generated date times. This must be the same as the `jira.date.time.picker.javascript.format` format setting. | `dd/MMM/yy h:mm a` |
  | `jira.date.time.picker.javascript.format` | The date format for the JavaScript (client-side) generated date times. This must be the same as the `jira.date.time.picker.java.format` format setting. | `%e/%b/%y %I:%M %p` |
  | `jira.issue.actions.order` | The default order of actions (such as *Comments* or *Change history*) displayed on the issue view. | `asc` |
  | `jira.view.issue.links.sort.order` | The sort order of the list of issue links on the issue view. | `type, status, priority` |
  | `jira.comment.collapsing.minimum.hidden` | The minimum number of comments required for comment collapsing to occur. A value of `0` disables comment collapsing. | `4` |
  | `jira.newsletter.tip.delay.days` | The number of days before a prompt to sign up to the Jira Insiders newsletter is shown. A value of `-1` disables this feature. | `7` |
  
  
  #### Look and feel ####
  
  The settings listed below adjust the [look and feel](https://confluence.atlassian.com/x/VwCLLg).
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.lf.date.time` | The [ time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `h:mm a` |
  | `jira.lf.date.day` | The [ day format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `EEEE h:mm a` |
  | `jira.lf.date.complete` | The [ date and time format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy h:mm a` |
  | `jira.lf.date.dmy` | The [ date format](https://docs.oracle.com/javase/6/docs/api/index.html?java/text/SimpleDateFormat.html). | `dd/MMM/yy` |
  | `jira.date.time.picker.use.iso8061` | When enabled, sets Monday as the first day of the week in the date picker, as specified by the ISO8601 standard. | `false` |
  | `jira.lf.logo.url` | The URL of the logo image file. | `/images/icon-jira-logo.png` |
  | `jira.lf.logo.show.application.title` | Controls the visibility of the application title on the sidebar. | `false` |
  | `jira.lf.favicon.url` | The URL of the favicon. | `/favicon.ico` |
  | `jira.lf.favicon.hires.url` | The URL of the high-resolution favicon. | `/images/64jira.png` |
  | `jira.lf.navigation.bgcolour` | The background color of the sidebar. | `#0747A6` |
  | `jira.lf.navigation.highlightcolour` | The color of the text and logo of the sidebar. | `#DEEBFF` |
  | `jira.lf.hero.button.base.bg.colour` | The background color of the hero button. | `#3b7fc4` |
  | `jira.title` | The text for the application title. The application title can also be set in *General settings*. | `Jira` |
  | `jira.option.globalsharing` | Whether filters and dashboards can be shared with anyone signed into Jira. | `true` |
  | `xflow.product.suggestions.enabled` | Whether to expose product suggestions for other Atlassian products within Jira. | `true` |
  
  
  #### Other settings ####
  
  | Key | Description | Default value |
  | -- | -- | -- |
  | `jira.issuenav.criteria.autoupdate` | Whether instant updates to search criteria is active. | `true` |
  
  
  *Note: Be careful when changing [application properties and advanced settings](https://confluence.atlassian.com/x/vYXKM).*
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-id-put
  * @param options Request options.
  */
    async setApplicationProperty(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/application-properties/${encodeURIComponent(id)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all application properties or an application property.
  
  If you specify a value for the `key` parameter, then an application property is returned as an object (not in an array). Otherwise, an array of all editable application properties is returned. See [Set application property](#api-rest-api-3-application-properties-id-put) for descriptions of editable properties.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-get
  * @param options Request options.
  */
    async getApplicationProperty(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/application-properties`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the application properties that are accessible on the *Advanced Settings* page. To navigate to the *Advanced Settings* page in Jira, choose the Jira icon > **Jira settings** > **System**, **General Configuration** and then click **Advanced Settings** (in the upper right).
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-application-properties-advanced-settings-get
  * @param options Request options.
  */
    async getAdvancedSettings(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/application-properties/advanced-settings`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the attachment settings, that is, whether attachments are enabled and the maximum attachment size allowed.
  
  Note that there are also [project permissions](https://confluence.atlassian.com/x/yodKLg) that restrict whether users can create and delete attachments.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-issue-attachments/#api-rest-api-3-attachment-meta-get
  * @param options Request options.
  */
    async getAttachmentSettings(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/attachment/meta`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the [global settings](https://confluence.atlassian.com/x/qYXKM) in Jira. These settings determine whether optional features (for example, subtasks, time tracking, and others) are enabled. If time tracking is enabled, this operation also returns the time tracking configuration.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jira-settings/#api-rest-api-3-configuration-get
  * @param options Request options.
  */
    async getGlobalSettings(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/configuration`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns information about the Jira instance.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-server-info/#api-rest-api-3-serverinfo-get
  * @param options Request options.
  */
    async getInfo(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/serverInfo`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns licensing information about the Jira instance.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-instance-information/#api-rest-api-3-instance-license-get
  * @param options Request options.
  */
    async getLicense(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/instance/license`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FilterGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Favourite = new FilterFavouriteGroup(implementation, this.getGlobalErrorStrategy);
        this.Column = new FilterColumnGroup(implementation, this.getGlobalErrorStrategy);
        this.Share = new FilterShareGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a filter. The filter is shared according to the [default share scope](#api-rest-api-3-filter-post). The filter is not selected as a favorite.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-post
  * @param options Request options.
  */
    async createFilter(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/filter`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the filters owned by the user. If `includeFavourites` is `true`, the user's visible favorite filters are also returned.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, a favorite filters is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-my-get
  * @param options Request options.
  */
    async getMyFilters(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/filter/my`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of filters. Use this operation to get:
  
   *  specific filters, by defining `id` only.
   *  filters that match all of the specified attributes. For example, all filters for a user with a particular word in their name. When multiple attributes are specified only filters matching all attributes are returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, only the following filters that match the query parameters are returned:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-search-get
  * @param options Request options.
  */
    async searchFilters(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/filter/search`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a filter.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, the filter is only returned where it is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-get
  * @param options Request options.
  */
    async getFilter(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/filter/${encodeURIComponent(id)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a filter. Use this operation to update a filter's name, description, JQL, or sharing.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-put
  * @param options Request options.
  */
    async updateFilter(options) {
        const { body, headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/filter/${encodeURIComponent(id)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Delete a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however filters can only be deleted by the creator of the filter or a user with *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-delete
  * @param options Request options.
  */
    async deleteFilter(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/filter/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class FilterFavouriteGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the visible favorite filters of the user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** A favorite filter is only visible to the user where the filter is:
  
   *  owned by the user.
   *  shared with a group that the user is a member of.
   *  shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  shared with a public project.
   *  shared with the public.
  
  For example, if the user favorites a public filter that is subsequently made private that filter is not returned by this operation.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-favourite-get
  * @param options Request options.
  */
    async getFilters(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/filter/favourite`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Add a filter as a favorite for the user.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, the user can only favorite:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-favourite-put
  * @param options Request options.
  */
    async addFilter(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/filter/${encodeURIComponent(id)}/favourite`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a filter as a favorite for the user. Note that this operation only removes filters visible to the user from the user's favorites list. For example, if the user favorites a public filter that is subsequently made private (and is therefore no longer visible on their favorites list) they cannot remove it from their favorites list.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-favourite-delete
  * @param options Request options.
  */
    async removeFilter(options) {
        const { headers, errorStrategy, id, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/filter/${encodeURIComponent(id)}/favourite`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FilterColumnGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the columns configured for a filter. The column configuration is used when the filter's results are viewed in *List View* with the *Columns* set to *Filter*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, column details are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-get
  * @param options Request options.
  */
    async getColumns(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/filter/${encodeURIComponent(id)}/columns`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the columns for a filter. Only navigable fields can be set as columns. Use [Get fields](#api-rest-api-3-field-get) to get the list fields in Jira. A navigable field has `navigable` set to `true`.
  
  The parameters for this resource are expressed as HTML form data. For example, in curl:
  
  `curl -X PUT -d columns=summary -d columns=description https://your-domain.atlassian.net/rest/api/3/filter/10000/columns`
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only set for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-put
  * @param options Request options.
  */
    async setColumns(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("PUT", `/rest/api/3/filter/${encodeURIComponent(id)}/columns`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Reset the user's column configuration for the filter to the default.
  
  **[Permissions](#permissions) required:** Permission to access Jira, however, columns are only reset for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filters/#api-rest-api-3-filter-id-columns-delete
  * @param options Request options.
  */
    async resetColumns(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("DELETE", `/rest/api/3/filter/${encodeURIComponent(id)}/columns`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class FilterShareGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Permission = new FilterSharePermissionGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the default sharing settings for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-get
  * @param options Request options.
  */
    async getDefaultScope(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/filter/defaultShareScope`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Sets the default sharing for new filters and dashboards for a user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-defaultsharescope-put
  * @param options Request options.
  */
    async setDefaultScope(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("PUT", `/rest/api/3/filter/defaultShareScope`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class FilterSharePermissionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the share permissions for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, share permissions are only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-get
  * @param options Request options.
  */
    async getPermissions(options) {
        const { headers, errorStrategy, id } = options;
        const request = new Request("GET", `/rest/api/3/filter/${encodeURIComponent(id)}/permission`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Add a share permissions to a filter. If you add a global share permission (one for all logged-in users or the public) it will overwrite all share permissions for the filter.
  
  Be aware that this operation uses different objects for updating share permissions compared to [Update filter](#api-rest-api-3-filter-id-put).
  
  **[Permissions](#permissions) required:** *Share dashboards and filters* [global permission](https://confluence.atlassian.com/x/x4dKLg) and the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-post
  * @param options Request options.
  */
    async addPermission(options) {
        const { body, headers, errorStrategy, id } = options;
        const request = new Request("POST", `/rest/api/3/filter/${encodeURIComponent(id)}/permission`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a share permission for a filter. A filter can be shared with groups, projects, all logged-in users, or the public. Sharing with all logged-in users or the public is known as a global share permission.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None, however, a share permission is only returned for:
  
   *  filters owned by the user.
   *  filters shared with a group that the user is a member of.
   *  filters shared with a private project that the user has *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg) for.
   *  filters shared with a public project.
   *  filters shared with the public.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-get
  * @param options Request options.
  */
    async getPermission(options) {
        const { headers, errorStrategy, id, permissionId } = options;
        const request = new Request("GET", `/rest/api/3/filter/${encodeURIComponent(id)}/permission/${encodeURIComponent(permissionId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a share permission from a filter.
  
  **[Permissions](#permissions) required:** Permission to access Jira and the user must own the filter.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-filter-sharing/#api-rest-api-3-filter-id-permission-permissionid-delete
  * @param options Request options.
  */
    async deletePermission(options) {
        const { headers, errorStrategy, id, permissionId } = options;
        const request = new Request("DELETE", `/rest/api/3/filter/${encodeURIComponent(id)}/permission/${encodeURIComponent(permissionId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class GroupGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.User = new GroupUserGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Creates a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-post
  * @param options Request options.
  */
    async createGroup(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/group`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* strategic [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-delete
  * @param options Request options.
  */
    async removeGroup(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("DELETE", constructUrl(`/rest/api/3/group`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns a list of groups whose names contain a query string. A list of group names can be provided to exclude groups from the results.
  
  The primary use case for this resource is to populate a group picker suggestions list. To this end, the returned object includes the `html` field where the matched query term is highlighted in the group name with the HTML strong tag. Also, the groups list is wrapped in a response object that contains a header for use in the picker, specifically *Showing X of Y matching groups*.
  
  The list returns with the groups sorted. If no groups match the list criteria, an empty list is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse projects* [project permission](https://confluence.atlassian.com/x/yodKLg). Anonymous calls and calls by users without the required permission return an empty list.
  
  *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg). Without this permission, calls where query is not an exact match to an existing group will return an empty list.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-groups-picker-get
  * @param options Request options.
  */
    async findGroups(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/groups/picker`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class GroupUserGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of all users in a group.
  
  Note that users are ordered by username, however the username is not returned in the results due to privacy reasons.
  
  **[Permissions](#permissions) required:** either of:
  
   *  *Browse users and groups* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-member-get
  * @param options Request options.
  */
    async getUsers(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/group/member`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a user to a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-user-post
  * @param options Request options.
  */
    async addUser(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/group/user`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a user from a group.
  
  **[Permissions](#permissions) required:** Site administration (that is, member of the *site-admin* [group](https://confluence.atlassian.com/x/24xjL)).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-groups/#api-rest-api-3-group-user-delete
  * @param options Request options.
  */
    async removeUser(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/group/user`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class GroupAndUserPickerGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a list of users and groups matching a string. The string is used:
  
   *  for users, to find a case-insensitive match with display name and e-mail address. Note that if a user has hidden their email address in their user profile, partial matches of the email address will not find the user. An exact match is required.
   *  for groups, to find a case-sensitive match with group name.
  
  For example, if the string *tin* is used, records with the display name *Tina*, email address *sarah@tinplatetraining.com*, and the group *accounting* would be returned.
  
  Optionally, the search can be refined to:
  
   *  the projects and issue types associated with a custom field, such as a user picker. The search can then be further refined to return only users and groups that have permission to view specific:
      
       *  projects.
       *  issue types.
      
      If multiple projects or issue types are specified, they must be a subset of those enabled for the custom field or no results are returned. For example, if a field is enabled for projects A, B, and C then the search could be limited to projects B and C. However, if the search is limited to projects B and D, nothing is returned.
   *  not return Connect app users and groups.
   *  return groups that have a case-insensitive match with the query.
  
  The primary use case for this resource is to populate a picker field suggestion list with users or groups. To this end, the returned object includes an `html` field for each list. This field highlights the matched query term in the item name with the HTML strong tag. Also, each list is wrapped in a response object that contains a header for use in a picker, specifically *Showing X of Y matching groups*.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Browse users and groups* [global permission](https://confluence.atlassian.com/x/yodKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-group-and-user-picker/#api-rest-api-3-groupuserpicker-get
  * @param options Request options.
  */
    async findUsersAndGroups(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/groupuserpicker`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class JqlGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Parses and validates JQL queries.
  
  Validation is performed in context of the current user.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-parse-post
  * @param options Request options.
  */
    async parseQuery(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/jql/parse`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Converts one or more JQL queries with user identifiers (username or user key) to equivalent JQL queries with account IDs.
  
  You may wish to use this operation if your system stores JQL queries and you want to make them GDPR-compliant. For more information about GDPR-related changes, see the [migration guide](https://developer.atlassian.com/cloud/jira/platform/deprecation-notice-user-privacy-api-migration-guide/).
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-pdcleaner-post
  * @param options Request options.
  */
    async convertUserIdentifiersToAccountIdsInQueries(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/jql/pdcleaner`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns reference data for JQL searches. This is a downloadable version of the documentation provided in [Advanced searching - fields reference](https://confluence.atlassian.com/x/gwORLQ) and [Advanced searching - functions reference](https://confluence.atlassian.com/x/hgORLQ), along with a list of JQL-reserved words. Use this information to assist with the programmatic creation of JQL queries or the validation of queries built in a custom query builder.
  
  To filter visible field details by project or collapse non-unique fields by field type then [Get field reference data (POST)](#api-rest-api-3-jql-autocompletedata-post) can be used.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-jql/#api-rest-api-3-jql-autocompletedata-get
  * @param options Request options.
  */
    async getReferenceData(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/jql/autocompletedata`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class LabelGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
     * Returns a [paginated](#pagination) list of labels.
     * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-labels/#api-rest-api-3-label-get
     * @param options Request options.
     */
    async getLabels(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/label`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PermissionGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new PermissionSchemeGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a list of permissions indicating which permissions the user has. Details of the user's permissions can be obtained in a global, project, issue or comment context.
  
  The user is reported as having a project permission:
  
   *  in the global context, if the user has the project permission in any project.
   *  for a project, where the project permission is determined using issue data, if the user meets the permission's criteria for any issue in the project. Otherwise, if the user has the project permission in the project.
   *  for an issue, where a project permission is determined using issue data, if the user has the permission in the issue. Otherwise, if the user has the project permission in the project containing the issue.
   *  for a comment, where the user has both the permission to browse the comment and the project permission for the comment's parent issue. Only the BROWSE\_PROJECTS permission is supported. If a `commentId` is provided whose `permissions` does not equal BROWSE\_PROJECTS, a 400 error will be returned.
  
  This means that users may be shown as having an issue permission (such as EDIT\_ISSUES) in the global context or a project context but may not have the permission for any or all issues. For example, if Reporters have the EDIT\_ISSUES permission a user would be shown as having this permission in the global context or the context of a project, because any user can be a reporter. However, if they are not the user who reported the issue queried they would not have EDIT\_ISSUES permission for that issue.
  
  For [Jira Service Management project permissions](https://support.atlassian.com/jira-cloud-administration/docs/customize-jira-service-management-permissions/), this will be evaluated similarly to a user in the customer portal. For example, if the BROWSE\_PROJECTS permission is granted to Service Project Customer - Portal Access, any users with access to the customer portal will have the BROWSE\_PROJECTS permission.
  
  Global permissions are unaffected by context.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-mypermissions-get
  * @param options Request options.
  */
    async getMyPermissions(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/mypermissions`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all permissions, including:
  
   *  global permissions.
   *  project permissions.
   *  global permissions added by plugins.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-get
  * @param options Request options.
  */
    async getPermissions(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/permissions`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns:
  
   *  for a list of global permissions, the global permissions granted to a user.
   *  for a list of project permissions and lists of projects and issues, for each project permission a list of the projects and issues a user can access or manipulate.
  
  If no account ID is provided, the operation returns details for the logged in user.
  
  Note that:
  
   *  Invalid project and issue IDs are ignored.
   *  A maximum of 1000 projects and 1000 issues can be checked.
   *  Null values in `globalPermissions`, `projectPermissions`, `projectPermissions.projects`, and `projectPermissions.issues` are ignored.
   *  Empty strings in `projectPermissions.permissions` are ignored.
  
  **Deprecation notice:** The required OAuth 2.0 scopes will be updated on June 15, 2024.
  
   *  **Classic**: `read:jira-work`
   *  **Granular**: `read:permission:jira`
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg) to check the permissions for other users, otherwise none. However, Connect apps can make a call from the app server to the product to obtain permission details for any user, without admin permission. This Connect app ability doesn't apply to calls made using AP.request() in a browser.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-check-post
  * @param options Request options.
  */
    async getBulkPermissions(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/permissions/check`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns all the projects where the user is granted a list of project permissions.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permissions/#api-rest-api-3-permissions-project-post
  * @param options Request options.
  */
    async getPermittedProjects(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/permissions/project`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class PermissionSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Grant = new PermissionSchemeGrantGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns all permission schemes.
  
  ### About permission schemes and grants ###
  
  A permission scheme is a collection of permission grants. A permission grant consists of a `holder` and a `permission`.
  
  #### Holder object ####
  
  The `holder` object contains information about the user or group being granted the permission. For example, the *Administer projects* permission is granted to a group named *Teams in space administrators*. In this case, the type is `"type": "group"`, and the parameter is the group name, `"parameter": "Teams in space administrators"` and the value is group ID, `"value": "ca85fac0-d974-40ca-a615-7af99c48d24f"`.
  
  The `holder` object is defined by the following properties:
  
   *  `type` Identifies the user or group (see the list of types below).
   *  `parameter` As a group's name can change, use of `value` is recommended. The value of this property depends on the `type`. For example, if the `type` is a group, then you need to specify the group name.
   *  `value` The value of this property depends on the `type`. If the `type` is a group, then you need to specify the group ID. For other `type` it has the same value as `parameter`
  
  The following `types` are available. The expected values for `parameter` and `value` are given in parentheses (some types may not have a `parameter` or `value`):
  
   *  `anyone` Grant for anonymous users.
   *  `applicationRole` Grant for users with access to the specified application (application name, application name). See [Update product access settings](https://confluence.atlassian.com/x/3YxjL) for more information.
   *  `assignee` Grant for the user currently assigned to an issue.
   *  `group` Grant for the specified group (`parameter` : group name, `value` : group ID).
   *  `groupCustomField` Grant for a user in the group selected in the specified custom field (`parameter` : custom field ID, `value` : custom field ID).
   *  `projectLead` Grant for a project lead.
   *  `projectRole` Grant for the specified project role (`parameter` :project role ID, `value` : project role ID).
   *  `reporter` Grant for the user who reported the issue.
   *  `sd.customer.portal.only` Jira Service Desk only. Grants customers permission to access the customer portal but not Jira. See [Customizing Jira Service Desk permissions](https://confluence.atlassian.com/x/24dKLg) for more information.
   *  `user` Grant for the specified user (`parameter` : user ID - historically this was the userkey but that is deprecated and the account ID should be used, `value` : user ID).
   *  `userCustomField` Grant for a user selected in the specified custom field (`parameter` : custom field ID, `value` : custom field ID).
  
  #### Built-in permissions ####
  
  The [built-in Jira permissions](https://confluence.atlassian.com/x/yodKLg) are listed below. Apps can also define custom permissions. See the [project permission](https://developer.atlassian.com/cloud/jira/platform/modules/project-permission/) and [global permission](https://developer.atlassian.com/cloud/jira/platform/modules/global-permission/) module documentation for more information.
  
  **Project permissions**
  
   *  `ADMINISTER_PROJECTS`
   *  `BROWSE_PROJECTS`
   *  `MANAGE_SPRINTS_PERMISSION` (Jira Software only)
   *  `SERVICEDESK_AGENT` (Jira Service Desk only)
   *  `VIEW_DEV_TOOLS` (Jira Software only)
   *  `VIEW_READONLY_WORKFLOW`
  
  **Issue permissions**
  
   *  `ASSIGNABLE_USER`
   *  `ASSIGN_ISSUES`
   *  `CLOSE_ISSUES`
   *  `CREATE_ISSUES`
   *  `DELETE_ISSUES`
   *  `EDIT_ISSUES`
   *  `LINK_ISSUES`
   *  `MODIFY_REPORTER`
   *  `MOVE_ISSUES`
   *  `RESOLVE_ISSUES`
   *  `SCHEDULE_ISSUES`
   *  `SET_ISSUE_SECURITY`
   *  `TRANSITION_ISSUES`
  
  **Voters and watchers permissions**
  
   *  `MANAGE_WATCHERS`
   *  `VIEW_VOTERS_AND_WATCHERS`
  
  **Comments permissions**
  
   *  `ADD_COMMENTS`
   *  `DELETE_ALL_COMMENTS`
   *  `DELETE_OWN_COMMENTS`
   *  `EDIT_ALL_COMMENTS`
   *  `EDIT_OWN_COMMENTS`
  
  **Attachments permissions**
  
   *  `CREATE_ATTACHMENTS`
   *  `DELETE_ALL_ATTACHMENTS`
   *  `DELETE_OWN_ATTACHMENTS`
  
  **Time tracking permissions**
  
   *  `DELETE_ALL_WORKLOGS`
   *  `DELETE_OWN_WORKLOGS`
   *  `EDIT_ALL_WORKLOGS`
   *  `EDIT_OWN_WORKLOGS`
   *  `WORK_ON_ISSUES`
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/permissionscheme`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a new permission scheme. You can create a permission scheme with or without defining a set of permission grants.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-post
  * @param options Request options.
  */
    async createScheme(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/permissionscheme`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-get
  * @param options Request options.
  */
    async getScheme(options) {
        const { headers, errorStrategy, schemeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a permission scheme. Below are some important things to note when using this resource:
  
   *  If a permissions list is present in the request, then it is set in the permission scheme, overwriting *all existing* grants.
   *  If you want to update only the name and description, then do not send a permissions list in the request.
   *  Sending an empty list will remove all permission grants from the permission scheme.
  
  If you want to add or delete a permission grant instead of updating the whole list, see [Create permission grant](#api-rest-api-3-permissionscheme-schemeId-permission-post) or [Delete permission scheme entity](#api-rest-api-3-permissionscheme-schemeId-permission-permissionId-delete).
  
  See [About permission schemes and grants](#about-permission-schemes) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-put
  * @param options Request options.
  */
    async updateScheme(options) {
        const { body, headers, errorStrategy, schemeId, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-delete
  * @param options Request options.
  */
    async deleteScheme(options) {
        const { headers, errorStrategy, schemeId } = options;
        const request = new Request("DELETE", `/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class PermissionSchemeGrantGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all permission grants for a permission scheme.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-get
  * @param options Request options.
  */
    async getGrants(options) {
        const { headers, errorStrategy, schemeId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}/permission`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a permission grant in a permission scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-post
  * @param options Request options.
  */
    async createGrant(options) {
        const { body, headers, errorStrategy, schemeId, ...queryParams } = options;
        const request = new Request("POST", constructUrl(`/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}/permission`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a permission grant.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-get
  * @param options Request options.
  */
    async getGrant(options) {
        const { headers, errorStrategy, schemeId, permissionId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}/permission/${encodeURIComponent(permissionId)}`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a permission grant from a permission scheme. See [About permission schemes and grants](../api-group-permission-schemes/#about-permission-schemes-and-grants) for more details.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-permission-schemes/#api-rest-api-3-permissionscheme-schemeid-permission-permissionid-delete
  * @param options Request options.
  */
    async deleteGrant(options) {
        const { headers, errorStrategy, schemeId, permissionId } = options;
        const request = new Request("DELETE", `/rest/api/3/permissionscheme/${encodeURIComponent(schemeId)}/permission/${encodeURIComponent(permissionId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class MyselfGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns the value of a preference of the current user.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default this is not set and the user takes the locale of the instance.
   *  *jira.user.timezone* The time zone of the user. By default this is not set and the user takes the timezone of the instance.
  
  These system preferences keys will be deprecated by 15/07/2024. You can still retrieve these keys, but it will not have any impact on Notification behaviour.
  
   *  *user.notifications.watcher* Whether the user gets notified when they are watcher.
   *  *user.notifications.assignee* Whether the user gets notified when they are assignee.
   *  *user.notifications.reporter* Whether the user gets notified when they are reporter.
   *  *user.notifications.mentions* Whether the user gets notified when they are mentions.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-get
  * @param options Request options.
  */
    async getPreference(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/mypreferences`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a preference for the user or updates a preference's value by sending a plain text string. For example, `false`. An arbitrary preference can be created with the value containing up to 255 characters. In addition, the following keys define system preferences that can be set or created:
  
   *  *user.notifications.mimetype* The mime type used in notifications sent to the user. Defaults to `html`.
   *  *user.default.share.private* Whether new [ filters](https://confluence.atlassian.com/x/eQiiLQ) are set to private. Defaults to `true`.
   *  *user.keyboard.shortcuts.disabled* Whether keyboard shortcuts are disabled. Defaults to `false`.
   *  *user.autowatch.disabled* Whether the user automatically watches issues they create or add a comment to. By default, not set: the user takes the instance autowatch setting.
   *  *user.notifiy.own.changes* Whether the user gets notified of their own changes.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  These system preferences keys will be deprecated by 15/07/2024. You can still use these keys to create arbitrary preferences, but it will not have any impact on Notification behaviour.
  
   *  *user.notifications.watcher* Whether the user gets notified when they are watcher.
   *  *user.notifications.assignee* Whether the user gets notified when they are assignee.
   *  *user.notifications.reporter* Whether the user gets notified when they are reporter.
   *  *user.notifications.mentions* Whether the user gets notified when they are mentions.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-put
  * @param options Request options.
  */
    async setPreference(options) {
        const { body, headers, errorStrategy, ...queryParams } = options;
        const request = new Request("PUT", constructUrl(`/rest/api/3/mypreferences`, queryParams), constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a preference of the user, which restores the default value of system defined settings.
  
  Note that these keys are deprecated:
  
   *  *jira.user.locale* The locale of the user. By default, not set. The user takes the instance locale.
   *  *jira.user.timezone* The time zone of the user. By default, not set. The user takes the instance timezone.
  
  Use [ Update a user profile](https://developer.atlassian.com/cloud/admin/user-management/rest/#api-users-account-id-manage-profile-patch) from the user management REST API to manage timezone and locale instead.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-delete
  * @param options Request options.
  */
    async deletePreference(options) {
        const { headers, errorStrategy, ...queryParams } = options;
        const request = new Request("DELETE", constructUrl(`/rest/api/3/mypreferences`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Returns the locale for the user.
  
  If the user has no language preference set (which is the default setting) or this resource is accessed anonymous, the browser locale detected by Jira is returned. Jira detects the browser locale using the *Accept-Language* header in the request. However, if this doesn't match a locale available Jira, the site default locale is returned.
  
  This operation can be accessed anonymously.
  
  **[Permissions](#permissions) required:** None.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-mypreferences-locale-get
  * @param options Request options.
  */
    async getLocale(options) {
        const { headers, errorStrategy } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", `/rest/api/3/mypreferences/locale`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns details for the current user.
  
  **[Permissions](#permissions) required:** Permission to access Jira.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-myself/#api-rest-api-3-myself-get
  * @param options Request options.
  */
    async getCurrentUser(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/myself`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
}
class ScreenGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Scheme = new ScreenSchemeGroup(implementation, this.getGlobalErrorStrategy);
        this.Tab = new ScreenTabGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns a [paginated](#pagination) list of the screens a field is used in.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-field-fieldid-screens-get
  * @param options Request options.
  */
    async getScreensForField(options) {
        const { headers, errorStrategy, fieldId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/field/${encodeURIComponent(fieldId)}/screens`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns a [paginated](#pagination) list of all screens or those specified by one or more screen IDs.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-get
  * @param options Request options.
  */
    async getScreens(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/screens`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a screen with a default field tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-post
  * @param options Request options.
  */
    async createScreen(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/screens`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a field to the default tab of the default screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-addtodefault-fieldid-post
  * @param options Request options.
  */
    async addFieldToDefaultScreen(options) {
        const { headers, errorStrategy, fieldId } = options;
        const request = new Request("POST", `/rest/api/3/screens/addToDefault/${encodeURIComponent(fieldId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Returns the fields that can be added to a tab on a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-availablefields-get
  * @param options Request options.
  */
    async getAvailableScreenFields(options) {
        const { headers, errorStrategy, screenId } = options;
        const request = new Request("GET", `/rest/api/3/screens/${encodeURIComponent(screenId)}/availableFields`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a screen. Only screens used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-put
  * @param options Request options.
  */
    async updateScreen(options) {
        const { body, headers, errorStrategy, screenId } = options;
        const request = new Request("PUT", `/rest/api/3/screens/${encodeURIComponent(screenId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a screen. A screen cannot be deleted if it is used in a screen scheme, workflow, or workflow draft.
  
  Only screens used in classic projects can be deleted.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-delete
  * @param options Request options.
  */
    async deleteScreen(options) {
        const { headers, errorStrategy, screenId } = options;
        const request = new Request("DELETE", `/rest/api/3/screens/${encodeURIComponent(screenId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ScreenSchemeGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns a [paginated](#pagination) list of screen schemes.
  
  Only screen schemes used in classic projects are returned.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-get
  * @param options Request options.
  */
    async getSchemes(options) {
        const { headers, errorStrategy, ...queryParams } = (options !== null && options !== void 0 ? options : {});
        const request = new Request("GET", constructUrl(`/rest/api/3/screenscheme`, queryParams, true), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a screen scheme.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-post
  * @param options Request options.
  */
    async createScheme(options) {
        const { body, headers, errorStrategy } = options;
        const request = new Request("POST", `/rest/api/3/screenscheme`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates a screen scheme. Only screen schemes used in classic projects can be updated.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-put
  * @param options Request options.
  */
    async updateScheme(options) {
        const { body, headers, errorStrategy, screenSchemeId } = options;
        const request = new Request("PUT", `/rest/api/3/screenscheme/${encodeURIComponent(screenSchemeId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a screen scheme. A screen scheme cannot be deleted if it is used in an issue type screen scheme.
  
  Only screens schemes used in classic projects can be deleted.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screen-schemes/#api-rest-api-3-screenscheme-screenschemeid-delete
  * @param options Request options.
  */
    async deleteScheme(options) {
        const { headers, errorStrategy, screenSchemeId } = options;
        const request = new Request("DELETE", `/rest/api/3/screenscheme/${encodeURIComponent(screenSchemeId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ScreenTabGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
        this.Field = new ScreenTabFieldGroup(implementation, this.getGlobalErrorStrategy);
    }
    /**
  * Returns the list of tabs for a screen.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-get
  * @param options Request options.
  */
    async getTabs(options) {
        const { headers, errorStrategy, screenId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Creates a tab for a screen.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-post
  * @param options Request options.
  */
    async createTab(options) {
        const { body, headers, errorStrategy, screenId } = options;
        const request = new Request("POST", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Updates the name of a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-put
  * @param options Request options.
  */
    async updateTab(options) {
        const { body, headers, errorStrategy, screenId, tabId } = options;
        const request = new Request("PUT", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Deletes a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-delete
  * @param options Request options.
  */
    async deleteTab(options) {
        const { headers, errorStrategy, screenId, tabId } = options;
        const request = new Request("DELETE", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Moves a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-move-pos-post
  * @param options Request options.
  */
    async moveTab(options) {
        const { headers, errorStrategy, screenId, tabId, pos } = options;
        const request = new Request("POST", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}/move/${encodeURIComponent(pos)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
class ScreenTabFieldGroup {
    constructor(implementation, getGlobalErrorStrategy) {
        this.implementation = implementation;
        this.getGlobalErrorStrategy = getGlobalErrorStrategy;
    }
    /**
  * Returns all fields for a screen tab.
  
  **[Permissions](#permissions) required:**
  
   *  *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
   *  *Administer projects* [project permission](https://confluence.atlassian.com/x/yodKLg) when the project key is specified, providing that the screen is associated with the project through a Screen Scheme and Issue Type Screen Scheme.
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-get
  * @param options Request options.
  */
    async getFields(options) {
        const { headers, errorStrategy, screenId, tabId, ...queryParams } = options;
        const request = new Request("GET", constructUrl(`/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}/fields`, queryParams), constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Adds a field to a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-post
  * @param options Request options.
  */
    async addField(options) {
        const { body, headers, errorStrategy, screenId, tabId } = options;
        const request = new Request("POST", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}/fields`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers);
    }
    /**
  * Removes a field from a screen tab.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-delete
  * @param options Request options.
  */
    async removeField(options) {
        const { headers, errorStrategy, screenId, tabId, id } = options;
        const request = new Request("DELETE", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}/fields/${encodeURIComponent(id)}`, constructHeaders(undefined, headers));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
    /**
  * Moves a screen tab field.
  
  If `after` and `position` are provided in the request, `position` is ignored.
  
  **[Permissions](#permissions) required:** *Administer Jira* [global permission](https://confluence.atlassian.com/x/x4dKLg).
  * Documentation: https://developer.atlassian.com/cloud/jira/platform/rest/v3/api-group-screens/#api-rest-api-3-screens-screenid-tabs-tabid-fields-id-move-post
  * @param options Request options.
  */
    async moveField(options) {
        const { body, headers, errorStrategy, screenId, tabId, id } = options;
        const request = new Request("POST", `/rest/api/3/screens/${encodeURIComponent(screenId)}/tabs/${encodeURIComponent(tabId)}/fields/${encodeURIComponent(id)}/move`, constructHeaders(body, headers), JSON.stringify(body));
        request.setBufferImplementation(this.implementation);
        return await executeHttpCall(this.implementation, request, errorStrategyBuilderConstructor, this.getGlobalErrorStrategy(), errorStrategy, errorMessageBuilder, customErrorHandlers, true);
    }
}
//# sourceMappingURL=index.js.map